# -*- coding: utf-8 -*-
"""
Created on Thu Jun 18 12:50:34 2015
Function providing the mass attenuation coefficients (MAC), the mass energy absorption
coefficients (MEAC), the linear attenuation coefficients (LAC) and the atomic cross sections (CS)
for elements with atomic number Z in [1,100] range and energies in [0.001,20] MeV range.
Hard-wire tables extracted from NIST (J. Hubbell and S.M. Seltzer).
Adaptation of the Matlab PhotonAttenuation package written by Jarek Tuszynski.
@author: vilches
"""
import numpy as np
from scipy.interpolate import interp1d, pchip_interpolate
import re

# X-ray photon energy is in MeV
energy = np.array(
    [
        1.000e-3,
        1.500e-3,
        2.000e-3,
        3.000e-3,
        4.000e-3,
        5.000e-3,
        6.000e-3,
        8.000e-3,
        1.000e-2,
        1.500e-2,
        2.000e-2,
        3.000e-2,
        4.000e-2,
        5.000e-2,
        6.000e-2,
        8.000e-2,
        1.000e-1,
        1.500e-1,
        2.000e-1,
        3.000e-1,
        4.000e-1,
        5.000e-1,
        6.000e-1,
        8.000e-1,
        1.000,
        1.250,
        1.500,
        2.000,
        3.000,
        4.000,
        5.000,
        6.000,
        8.000,
        1.000e1,
        1.500e1,
        2.000e1,
    ]
)
# Hard-wire the table of x-ray mass attenuation coefficients (MAC) in cm2/g for elements with Z = [1,[100]
mac = np.array(
    [
        [
            7.217,
            2.148,
            1.059,
            5.612e-1,
            4.546e-1,
            4.193e-1,
            4.042e-1,
            3.914e-1,
            3.854e-1,
            3.764e-1,
            3.695e-1,
            3.570e-1,
            3.458e-1,
            3.355e-1,
            3.260e-1,
            3.091e-1,
            2.944e-1,
            2.651e-1,
            2.429e-1,
            2.112e-1,
            1.893e-1,
            1.729e-1,
            1.599e-1,
            1.405e-1,
            1.263e-1,
            1.129e-1,
            1.027e-1,
            8.769e-2,
            6.921e-2,
            5.806e-2,
            5.049e-2,
            4.498e-2,
            3.746e-2,
            3.254e-2,
            2.539e-2,
            2.153e-2,
        ],
        [
            6.084e1,
            1.676e1,
            6.863,
            2.007,
            9.329e-1,
            5.766e-1,
            4.195e-1,
            2.933e-1,
            2.476e-1,
            2.092e-1,
            1.960e-1,
            1.838e-1,
            1.763e-1,
            1.703e-1,
            1.651e-1,
            1.562e-1,
            1.486e-1,
            1.336e-1,
            1.224e-1,
            1.064e-1,
            9.535e-2,
            8.707e-2,
            8.054e-2,
            7.076e-2,
            6.362e-2,
            5.688e-2,
            5.173e-2,
            4.422e-2,
            3.503e-2,
            2.949e-2,
            2.577e-2,
            2.307e-2,
            1.940e-2,
            1.703e-2,
            1.363e-2,
            1.183e-2,
        ],
        [
            2.339e2,
            6.668e1,
            2.707e1,
            7.549,
            3.114,
            1.619,
            9.875e-1,
            5.054e-1,
            3.395e-1,
            2.176e-1,
            1.856e-1,
            1.644e-1,
            1.551e-1,
            1.488e-1,
            1.438e-1,
            1.356e-1,
            1.289e-1,
            1.158e-1,
            1.060e-1,
            9.210e-2,
            8.249e-2,
            7.532e-2,
            6.968e-2,
            6.121e-2,
            5.503e-2,
            4.921e-2,
            4.476e-2,
            3.830e-2,
            3.043e-2,
            2.572e-2,
            2.257e-2,
            2.030e-2,
            1.725e-2,
            1.529e-2,
            1.252e-2,
            1.109e-2,
        ],
        [
            6.041e2,
            1.797e2,
            7.469e1,
            2.127e1,
            8.685,
            4.369,
            2.527,
            1.124,
            6.466e-1,
            3.070e-1,
            2.251e-1,
            1.792e-1,
            1.640e-1,
            1.554e-1,
            1.493e-1,
            1.401e-1,
            1.328e-1,
            1.190e-1,
            1.089e-1,
            9.463e-2,
            8.471e-2,
            7.739e-2,
            7.155e-2,
            6.286e-2,
            5.652e-2,
            5.054e-2,
            4.597e-2,
            3.938e-2,
            3.138e-2,
            2.664e-2,
            2.347e-2,
            2.121e-2,
            1.819e-2,
            1.627e-2,
            1.361e-2,
            1.227e-2,
        ],
        [
            1.229e3,
            3.766e2,
            1.597e2,
            4.667e1,
            1.927e1,
            9.683,
            5.538,
            2.346,
            1.255,
            4.827e-1,
            3.014e-1,
            2.063e-1,
            1.793e-1,
            1.665e-1,
            1.583e-1,
            1.472e-1,
            1.391e-1,
            1.243e-1,
            1.136e-1,
            9.862e-2,
            8.834e-2,
            8.065e-2,
            7.460e-2,
            6.549e-2,
            5.890e-2,
            5.266e-2,
            4.791e-2,
            4.108e-2,
            3.284e-2,
            2.798e-2,
            2.476e-2,
            2.248e-2,
            1.945e-2,
            1.755e-2,
            1.495e-2,
            1.368e-2,
        ],
        [
            2.211e3,
            7.002e2,
            3.026e2,
            9.033e1,
            3.778e1,
            1.912e1,
            1.095e1,
            4.576,
            2.373,
            8.071e-1,
            4.420e-1,
            2.562e-1,
            2.076e-1,
            1.871e-1,
            1.753e-1,
            1.610e-1,
            1.514e-1,
            1.347e-1,
            1.229e-1,
            1.066e-1,
            9.546e-2,
            8.715e-2,
            8.058e-2,
            7.076e-2,
            6.361e-2,
            5.690e-2,
            5.179e-2,
            4.442e-2,
            3.562e-2,
            3.047e-2,
            2.708e-2,
            2.469e-2,
            2.154e-2,
            1.959e-2,
            1.698e-2,
            1.575e-2,
        ],
        [
            3.311e3,
            1.083e3,
            4.769e2,
            1.456e2,
            6.166e1,
            3.144e1,
            1.809e1,
            7.562,
            3.879,
            1.236,
            6.178e-1,
            3.066e-1,
            2.288e-1,
            1.980e-1,
            1.817e-1,
            1.639e-1,
            1.529e-1,
            1.353e-1,
            1.233e-1,
            1.068e-1,
            9.557e-2,
            8.719e-2,
            8.063e-2,
            7.081e-2,
            6.364e-2,
            5.693e-2,
            5.180e-2,
            4.450e-2,
            3.579e-2,
            3.073e-2,
            2.742e-2,
            2.511e-2,
            2.209e-2,
            2.024e-2,
            1.782e-2,
            1.673e-2,
        ],
        [
            4.590e3,
            1.549e3,
            6.949e2,
            2.171e2,
            9.315e1,
            4.790e1,
            2.770e1,
            1.163e1,
            5.952,
            1.836,
            8.651e-1,
            3.779e-1,
            2.585e-1,
            2.132e-1,
            1.907e-1,
            1.678e-1,
            1.551e-1,
            1.361e-1,
            1.237e-1,
            1.070e-1,
            9.566e-2,
            8.729e-2,
            8.070e-2,
            7.087e-2,
            6.372e-2,
            5.697e-2,
            5.185e-2,
            4.459e-2,
            3.597e-2,
            3.100e-2,
            2.777e-2,
            2.552e-2,
            2.263e-2,
            2.089e-2,
            1.866e-2,
            1.770e-2,
        ],
        [
            5.649e3,
            1.979e3,
            9.047e2,
            2.888e2,
            1.256e2,
            6.514e1,
            3.789e1,
            1.602e1,
            8.205,
            2.492,
            1.133,
            4.487e-1,
            2.828e-1,
            2.214e-1,
            1.920e-1,
            1.639e-1,
            1.496e-1,
            1.298e-1,
            1.176e-1,
            1.015e-1,
            9.073e-2,
            8.274e-2,
            7.649e-2,
            6.717e-2,
            6.037e-2,
            5.399e-2,
            4.915e-2,
            4.228e-2,
            3.422e-2,
            2.960e-2,
            2.663e-2,
            2.457e-2,
            2.195e-2,
            2.039e-2,
            1.846e-2,
            1.769e-2,
        ],
        [
            7.409e3,
            2.666e3,
            1.243e3,
            4.051e2,
            1.785e2,
            9.339e1,
            5.467e1,
            2.328e1,
            1.197e1,
            3.613,
            1.606,
            5.923e-1,
            3.473e-1,
            2.579e-1,
            2.161e-1,
            1.781e-1,
            1.600e-1,
            1.370e-1,
            1.236e-1,
            1.064e-1,
            9.502e-2,
            8.664e-2,
            8.006e-2,
            7.029e-2,
            6.316e-2,
            5.646e-2,
            5.145e-2,
            4.430e-2,
            3.594e-2,
            3.122e-2,
            2.818e-2,
            2.610e-2,
            2.348e-2,
            2.197e-2,
            2.013e-2,
            1.946e-2,
        ],
        [
            6.542e2,
            3.194e3,
            1.521e3,
            5.070e2,
            2.261e2,
            1.194e2,
            7.030e1,
            3.018e1,
            1.557e1,
            4.694,
            2.057,
            7.197e-1,
            3.969e-1,
            2.804e-1,
            2.268e-1,
            1.796e-1,
            1.585e-1,
            1.335e-1,
            1.199e-1,
            1.029e-1,
            9.185e-2,
            8.372e-2,
            7.736e-2,
            6.788e-2,
            6.100e-2,
            5.454e-2,
            4.968e-2,
            4.282e-2,
            3.487e-2,
            3.037e-2,
            2.753e-2,
            2.559e-2,
            2.319e-2,
            2.181e-2,
            2.023e-2,
            1.970e-2,
        ],
        [
            9.225e2,
            4.004e3,
            1.932e3,
            6.585e2,
            2.974e2,
            1.583e2,
            9.381e1,
            4.061e1,
            2.105e1,
            6.358,
            2.763,
            9.306e-1,
            4.881e-1,
            3.292e-1,
            2.570e-1,
            1.951e-1,
            1.686e-1,
            1.394e-1,
            1.245e-1,
            1.065e-1,
            9.492e-2,
            8.647e-2,
            7.988e-2,
            7.008e-2,
            6.296e-2,
            5.629e-2,
            5.129e-2,
            4.426e-2,
            3.613e-2,
            3.159e-2,
            2.873e-2,
            2.681e-2,
            2.445e-2,
            2.313e-2,
            2.168e-2,
            2.127e-2,
        ],
        [
            1.185e3,
            4.022e2,
            2.263e3,
            7.880e2,
            3.605e2,
            1.934e2,
            1.153e2,
            5.033e1,
            2.623e1,
            7.955,
            3.441,
            1.128,
            5.685e-1,
            3.681e-1,
            2.778e-1,
            2.018e-1,
            1.704e-1,
            1.378e-1,
            1.223e-1,
            1.042e-1,
            9.276e-2,
            8.445e-2,
            7.802e-2,
            6.841e-2,
            6.146e-2,
            5.496e-2,
            5.006e-2,
            4.324e-2,
            3.541e-2,
            3.106e-2,
            2.836e-2,
            2.655e-2,
            2.437e-2,
            2.318e-2,
            2.195e-2,
            2.168e-2,
        ],
        [
            1.570e3,
            5.355e2,
            2.777e3,
            9.784e2,
            4.529e2,
            2.450e2,
            1.470e2,
            6.468e1,
            3.389e1,
            1.034e1,
            4.464,
            1.436,
            7.012e-1,
            4.385e-1,
            3.207e-1,
            2.228e-1,
            1.835e-1,
            1.448e-1,
            1.275e-1,
            1.082e-1,
            9.614e-2,
            8.748e-2,
            8.077e-2,
            7.082e-2,
            6.361e-2,
            5.688e-2,
            5.183e-2,
            4.480e-2,
            3.678e-2,
            3.240e-2,
            2.967e-2,
            2.788e-2,
            2.574e-2,
            2.462e-2,
            2.352e-2,
            2.338e-2,
        ],
        [
            1.913e3,
            6.547e2,
            3.018e2,
            1.118e3,
            5.242e2,
            2.860e2,
            1.726e2,
            7.660e1,
            4.035e1,
            1.239e1,
            5.352,
            1.700,
            8.096e-1,
            4.916e-1,
            3.494e-1,
            2.324e-1,
            1.865e-1,
            1.432e-1,
            1.250e-1,
            1.055e-1,
            9.359e-2,
            8.511e-2,
            7.854e-2,
            6.884e-2,
            6.182e-2,
            5.526e-2,
            5.039e-2,
            4.358e-2,
            3.590e-2,
            3.172e-2,
            2.915e-2,
            2.747e-2,
            2.552e-2,
            2.452e-2,
            2.364e-2,
            2.363e-2,
        ],
        [
            2.429e3,
            8.342e2,
            3.853e2,
            1.339e3,
            6.338e2,
            3.487e2,
            2.116e2,
            9.465e1,
            5.012e1,
            1.550e1,
            6.708,
            2.113,
            9.872e-1,
            5.849e-1,
            4.053e-1,
            2.585e-1,
            2.020e-1,
            1.506e-1,
            1.302e-1,
            1.091e-1,
            9.665e-2,
            8.781e-2,
            8.102e-2,
            7.098e-2,
            6.373e-2,
            5.697e-2,
            5.193e-2,
            4.498e-2,
            3.715e-2,
            3.293e-2,
            3.036e-2,
            2.872e-2,
            2.682e-2,
            2.589e-2,
            2.517e-2,
            2.529e-2,
        ],
        [
            2.832e3,
            9.771e2,
            4.520e2,
            1.473e3,
            7.037e2,
            3.901e2,
            2.384e2,
            1.075e2,
            5.725e1,
            1.784e1,
            7.739,
            2.425,
            1.117,
            6.483e-1,
            4.395e-1,
            2.696e-1,
            2.050e-1,
            1.480e-1,
            1.266e-1,
            1.054e-1,
            9.311e-2,
            8.453e-2,
            7.795e-2,
            6.826e-2,
            6.128e-2,
            5.478e-2,
            4.994e-2,
            4.328e-2,
            3.585e-2,
            3.188e-2,
            2.950e-2,
            2.798e-2,
            2.628e-2,
            2.549e-2,
            2.496e-2,
            2.520e-2,
        ],
        [
            3.184e3,
            1.105e3,
            5.120e2,
            1.703e2,
            7.572e2,
            4.225e2,
            2.593e2,
            1.180e2,
            6.316e1,
            1.983e1,
            8.629,
            2.697,
            1.228,
            7.012e-1,
            4.664e-1,
            2.760e-1,
            2.043e-1,
            1.427e-1,
            1.205e-1,
            9.953e-2,
            8.776e-2,
            7.958e-2,
            7.335e-2,
            6.419e-2,
            5.762e-2,
            5.150e-2,
            4.695e-2,
            4.074e-2,
            3.384e-2,
            3.019e-2,
            2.802e-2,
            2.667e-2,
            2.517e-2,
            2.451e-2,
            2.418e-2,
            2.453e-2,
        ],
        [
            4.058e3,
            1.418e3,
            6.592e2,
            2.198e2,
            9.256e2,
            5.189e2,
            3.205e2,
            1.469e2,
            7.907e1,
            2.503e1,
            1.093e1,
            3.413,
            1.541,
            8.679e-1,
            5.678e-1,
            3.251e-1,
            2.345e-1,
            1.582e-1,
            1.319e-1,
            1.080e-1,
            9.495e-2,
            8.600e-2,
            7.922e-2,
            6.929e-2,
            6.216e-2,
            5.556e-2,
            5.068e-2,
            4.399e-2,
            3.666e-2,
            3.282e-2,
            3.054e-2,
            2.915e-2,
            2.766e-2,
            2.704e-2,
            2.687e-2,
            2.737e-2,
        ],
        [
            4.867e3,
            1.714e3,
            7.999e2,
            2.676e2,
            1.218e2,
            6.026e2,
            3.731e2,
            1.726e2,
            9.341e1,
            2.979e1,
            1.306e1,
            4.080,
            1.830,
            1.019,
            6.578e-1,
            3.656e-1,
            2.571e-1,
            1.674e-1,
            1.376e-1,
            1.116e-1,
            9.783e-2,
            8.851e-2,
            8.148e-2,
            7.122e-2,
            6.388e-2,
            5.709e-2,
            5.207e-2,
            4.524e-2,
            3.780e-2,
            3.395e-2,
            3.170e-2,
            3.035e-2,
            2.892e-2,
            2.839e-2,
            2.838e-2,
            2.903e-2,
        ],
        [
            5.238e3,
            1.858e3,
            8.706e2,
            2.922e2,
            1.332e2,
            6.305e2,
            3.933e2,
            1.828e2,
            9.952e1,
            3.202e1,
            1.409e1,
            4.409,
            1.969,
            1.087,
            6.932e-1,
            3.753e-1,
            2.577e-1,
            1.619e-1,
            1.310e-1,
            1.052e-1,
            9.193e-2,
            8.305e-2,
            7.639e-2,
            6.675e-2,
            5.985e-2,
            5.347e-2,
            4.878e-2,
            4.243e-2,
            3.554e-2,
            3.202e-2,
            2.999e-2,
            2.878e-2,
            2.756e-2,
            2.715e-2,
            2.732e-2,
            2.804e-2,
        ],
        [
            5.869e3,
            2.096e3,
            9.860e2,
            3.323e2,
            1.517e2,
            6.838e2,
            4.323e2,
            2.023e2,
            1.107e2,
            3.587e1,
            1.585e1,
            4.972,
            2.214,
            1.213,
            7.661e-1,
            4.052e-1,
            2.721e-1,
            1.649e-1,
            1.314e-1,
            1.043e-1,
            9.081e-2,
            8.191e-2,
            7.529e-2,
            6.572e-2,
            5.891e-2,
            5.263e-2,
            4.801e-2,
            4.180e-2,
            3.512e-2,
            3.173e-2,
            2.982e-2,
            2.868e-2,
            2.759e-2,
            2.727e-2,
            2.762e-2,
            2.844e-2,
        ],
        [
            6.495e3,
            2.342e3,
            1.106e3,
            3.743e2,
            1.712e2,
            9.291e1,
            4.687e2,
            2.217e2,
            1.218e2,
            3.983e1,
            1.768e1,
            5.564,
            2.472,
            1.347,
            8.438e-1,
            4.371e-1,
            2.877e-1,
            1.682e-1,
            1.318e-1,
            1.034e-1,
            8.965e-2,
            8.074e-2,
            7.414e-2,
            6.466e-2,
            5.794e-2,
            5.175e-2,
            4.722e-2,
            4.115e-2,
            3.466e-2,
            3.141e-2,
            2.960e-2,
            2.855e-2,
            2.759e-2,
            2.738e-2,
            2.786e-2,
            2.877e-2,
        ],
        [
            7.405e3,
            2.694e3,
            1.277e3,
            4.339e2,
            1.988e2,
            1.080e2,
            5.160e2,
            2.513e2,
            1.386e2,
            4.571e1,
            2.038e1,
            6.434,
            2.856,
            1.550,
            9.639e-1,
            4.905e-1,
            3.166e-1,
            1.788e-1,
            1.378e-1,
            1.067e-1,
            9.213e-2,
            8.281e-2,
            7.598e-2,
            6.620e-2,
            5.930e-2,
            5.295e-2,
            4.832e-2,
            4.213e-2,
            3.559e-2,
            3.235e-2,
            3.057e-2,
            2.956e-2,
            2.869e-2,
            2.855e-2,
            2.920e-2,
            3.026e-2,
        ],
        [
            8.093e3,
            2.984e3,
            1.421e3,
            4.851e2,
            2.229e2,
            1.212e2,
            7.350e1,
            2.734e2,
            1.514e2,
            5.027e1,
            2.253e1,
            7.141,
            3.169,
            1.714,
            1.060,
            5.306e-1,
            3.367e-1,
            1.838e-1,
            1.391e-1,
            1.062e-1,
            9.133e-2,
            8.192e-2,
            7.509e-2,
            6.537e-2,
            5.852e-2,
            5.224e-2,
            4.769e-2,
            4.162e-2,
            3.524e-2,
            3.213e-2,
            3.045e-2,
            2.952e-2,
            2.875e-2,
            2.871e-2,
            2.951e-2,
            3.068e-2,
        ],
        [
            9.085e3,
            3.399e3,
            1.626e3,
            5.576e2,
            2.567e2,
            1.398e2,
            8.484e1,
            3.056e2,
            1.706e2,
            5.708e1,
            2.568e1,
            8.176,
            3.629,
            1.958,
            1.205,
            5.952e-1,
            3.717e-1,
            1.964e-1,
            1.460e-1,
            1.099e-1,
            9.400e-2,
            8.414e-2,
            7.704e-2,
            6.699e-2,
            5.995e-2,
            5.350e-2,
            4.883e-2,
            4.265e-2,
            3.621e-2,
            3.312e-2,
            3.146e-2,
            3.057e-2,
            2.991e-2,
            2.994e-2,
            3.092e-2,
            3.224e-2,
        ],
        [
            9.796e3,
            3.697e3,
            1.779e3,
            6.129e2,
            2.830e2,
            1.543e2,
            9.370e1,
            3.248e2,
            1.841e2,
            6.201e1,
            2.803e1,
            8.962,
            3.981,
            2.144,
            1.314,
            6.414e-1,
            3.949e-1,
            2.023e-1,
            1.476e-1,
            1.094e-1,
            9.311e-2,
            8.315e-2,
            7.604e-2,
            6.604e-2,
            5.906e-2,
            5.270e-2,
            4.810e-2,
            4.204e-2,
            3.580e-2,
            3.283e-2,
            3.127e-2,
            3.045e-2,
            2.991e-2,
            3.002e-2,
            3.115e-2,
            3.256e-2,
        ],
        [
            9.855e3,
            4.234e3,
            2.049e3,
            7.094e2,
            3.282e2,
            1.793e2,
            1.090e2,
            4.952e1,
            2.090e2,
            7.081e1,
            3.220e1,
            1.034e1,
            4.600,
            2.474,
            1.512,
            7.306e-1,
            4.440e-1,
            2.208e-1,
            1.582e-1,
            1.154e-1,
            9.765e-2,
            8.698e-2,
            7.944e-2,
            6.891e-2,
            6.160e-2,
            5.494e-2,
            5.015e-2,
            4.387e-2,
            3.745e-2,
            3.444e-2,
            3.289e-2,
            3.210e-2,
            3.164e-2,
            3.185e-2,
            3.320e-2,
            3.476e-2,
        ],
        [
            1.057e4,
            4.418e3,
            2.154e3,
            7.488e2,
            3.473e2,
            1.899e2,
            1.156e2,
            5.255e1,
            2.159e2,
            7.405e1,
            3.379e1,
            1.092e1,
            4.862,
            2.613,
            1.593,
            7.630e-1,
            4.584e-1,
            2.217e-1,
            1.559e-1,
            1.119e-1,
            9.413e-2,
            8.362e-2,
            7.625e-2,
            6.605e-2,
            5.901e-2,
            5.261e-2,
            4.803e-2,
            4.205e-2,
            3.599e-2,
            3.318e-2,
            3.177e-2,
            3.108e-2,
            3.074e-2,
            3.103e-2,
            3.247e-2,
            3.408e-2,
        ],
        [
            1.553e3,
            4.825e3,
            2.375e3,
            8.311e2,
            3.865e2,
            2.118e2,
            1.290e2,
            5.875e1,
            2.331e2,
            8.117e1,
            3.719e1,
            1.207e1,
            5.384,
            2.892,
            1.760,
            8.364e-1,
            4.973e-1,
            2.341e-1,
            1.617e-1,
            1.141e-1,
            9.539e-2,
            8.450e-2,
            7.695e-2,
            6.656e-2,
            5.941e-2,
            5.296e-2,
            4.834e-2,
            4.235e-2,
            3.634e-2,
            3.360e-2,
            3.225e-2,
            3.160e-2,
            3.138e-2,
            3.175e-2,
            3.335e-2,
            3.509e-2,
        ],
        [
            1.697e3,
            5.087e3,
            2.515e3,
            8.857e2,
            4.130e2,
            2.266e2,
            1.382e2,
            6.302e1,
            3.421e1,
            8.537e1,
            3.928e1,
            1.281e1,
            5.726,
            3.076,
            1.868,
            8.823e-1,
            5.197e-1,
            2.387e-1,
            1.619e-1,
            1.123e-1,
            9.325e-2,
            8.236e-2,
            7.487e-2,
            6.466e-2,
            5.767e-2,
            5.139e-2,
            4.692e-2,
            4.113e-2,
            3.538e-2,
            3.280e-2,
            3.156e-2,
            3.099e-2,
            3.086e-2,
            3.130e-2,
            3.300e-2,
            3.479e-2,
        ],
        [
            1.893e3,
            5.475e3,
            2.711e3,
            9.613e2,
            4.497e2,
            2.472e2,
            1.509e2,
            6.890e1,
            3.742e1,
            9.152e1,
            4.222e1,
            1.385e1,
            6.207,
            3.335,
            2.023,
            9.501e-1,
            5.550e-1,
            2.491e-1,
            1.661e-1,
            1.131e-1,
            9.327e-2,
            8.212e-2,
            7.452e-2,
            6.426e-2,
            5.727e-2,
            5.101e-2,
            4.657e-2,
            4.086e-2,
            3.524e-2,
            3.275e-2,
            3.158e-2,
            3.107e-2,
            3.103e-2,
            3.156e-2,
            3.340e-2,
            3.528e-2,
        ],
        [
            2.121e3,
            5.227e3,
            2.931e3,
            1.049e3,
            4.920e2,
            2.709e2,
            1.656e2,
            7.573e1,
            4.115e1,
            9.856e1,
            4.564e1,
            1.506e1,
            6.760,
            3.635,
            2.203,
            1.030,
            5.971e-1,
            2.622e-1,
            1.719e-1,
            1.150e-1,
            9.414e-2,
            8.259e-2,
            7.483e-2,
            6.440e-2,
            5.735e-2,
            5.106e-2,
            4.661e-2,
            4.093e-2,
            3.539e-2,
            3.296e-2,
            3.187e-2,
            3.141e-2,
            3.146e-2,
            3.207e-2,
            3.405e-2,
            3.603e-2,
        ],
        [
            2.317e3,
            5.336e3,
            3.098e3,
            1.116e3,
            5.252e2,
            2.896e2,
            1.773e2,
            8.116e1,
            4.414e1,
            1.033e2,
            4.818e1,
            1.596e1,
            7.184,
            3.864,
            2.341,
            1.090,
            6.278e-1,
            2.703e-1,
            1.742e-1,
            1.144e-1,
            9.299e-2,
            8.129e-2,
            7.350e-2,
            6.314e-2,
            5.619e-2,
            4.999e-2,
            4.564e-2,
            4.010e-2,
            3.476e-2,
            3.247e-2,
            3.145e-2,
            3.105e-2,
            3.119e-2,
            3.186e-2,
            3.395e-2,
            3.599e-2,
        ],
        [
            2.624e3,
            1.002e3,
            3.407e3,
            1.231e3,
            5.815e2,
            3.213e2,
            1.968e2,
            9.026e1,
            4.912e1,
            1.119e2,
            5.266e1,
            1.753e1,
            7.900,
            4.264,
            2.582,
            1.198,
            6.861e-1,
            2.899e-1,
            1.838e-1,
            1.186e-1,
            9.563e-2,
            8.328e-2,
            7.515e-2,
            6.443e-2,
            5.728e-2,
            5.094e-2,
            4.650e-2,
            4.089e-2,
            3.552e-2,
            3.327e-2,
            3.229e-2,
            3.194e-2,
            3.218e-2,
            3.293e-2,
            3.521e-2,
            3.738e-2,
        ],
        [
            2.854e3,
            1.093e3,
            3.599e3,
            1.305e3,
            6.186e2,
            3.425e2,
            2.101e2,
            9.651e1,
            5.257e1,
            1.168e2,
            5.548e1,
            1.854e1,
            8.389,
            4.523,
            2.739,
            1.267,
            7.221e-1,
            2.998e-1,
            1.872e-1,
            1.186e-1,
            9.480e-2,
            8.226e-2,
            7.410e-2,
            6.340e-2,
            5.631e-2,
            5.005e-2,
            4.569e-2,
            4.020e-2,
            3.501e-2,
            3.286e-2,
            3.196e-2,
            3.168e-2,
            3.199e-2,
            3.280e-2,
            3.518e-2,
            3.741e-2,
        ],
        [
            3.174e3,
            1.219e3,
            3.410e3,
            1.418e3,
            6.748e2,
            3.744e2,
            2.300e2,
            1.058e2,
            5.766e1,
            1.909e1,
            5.980e1,
            2.009e1,
            9.112,
            4.918,
            2.979,
            1.375,
            7.799e-1,
            3.187e-1,
            1.960e-1,
            1.219e-1,
            9.670e-2,
            8.360e-2,
            7.510e-2,
            6.412e-2,
            5.689e-2,
            5.053e-2,
            4.613e-2,
            4.061e-2,
            3.545e-2,
            3.335e-2,
            3.250e-2,
            3.227e-2,
            3.267e-2,
            3.357e-2,
            3.610e-2,
            3.845e-2,
        ],
        [
            3.494e3,
            1.347e3,
            2.589e3,
            1.525e3,
            7.297e2,
            4.058e2,
            2.496e2,
            1.150e2,
            6.274e1,
            2.079e1,
            6.386e1,
            2.157e1,
            9.818,
            5.306,
            3.214,
            1.481,
            8.365e-1,
            3.369e-1,
            2.042e-1,
            1.247e-1,
            9.811e-2,
            8.443e-2,
            7.570e-2,
            6.447e-2,
            5.714e-2,
            5.072e-2,
            4.630e-2,
            4.079e-2,
            3.569e-2,
            3.365e-2,
            3.286e-2,
            3.268e-2,
            3.317e-2,
            3.414e-2,
            3.683e-2,
            3.927e-2,
        ],
        [
            3.864e3,
            1.493e3,
            7.422e2,
            1.654e3,
            7.936e2,
            4.424e2,
            2.725e2,
            1.258e2,
            6.871e1,
            2.279e1,
            6.855e1,
            2.330e1,
            1.065e1,
            5.764,
            3.493,
            1.607,
            9.047e-1,
            3.595e-1,
            2.149e-1,
            1.289e-1,
            1.006e-1,
            8.613e-2,
            7.703e-2,
            6.546e-2,
            5.795e-2,
            5.141e-2,
            4.692e-2,
            4.137e-2,
            3.628e-2,
            3.428e-2,
            3.355e-2,
            3.341e-2,
            3.399e-2,
            3.504e-2,
            3.790e-2,
            4.048e-2,
        ],
        [
            4.210e3,
            1.631e3,
            8.115e2,
            1.772e3,
            8.507e2,
            4.755e2,
            2.935e2,
            1.356e2,
            7.417e1,
            2.463e1,
            7.237e1,
            2.485e1,
            1.139e1,
            6.173,
            3.744,
            1.721,
            9.658e-1,
            3.790e-1,
            2.237e-1,
            1.318e-1,
            1.018e-1,
            8.693e-2,
            7.756e-2,
            6.571e-2,
            5.810e-2,
            5.150e-2,
            4.700e-2,
            4.146e-2,
            3.644e-2,
            3.451e-2,
            3.384e-2,
            3.374e-2,
            3.441e-2,
            3.554e-2,
            3.855e-2,
            4.122e-2,
        ],
        [
            4.600e3,
            1.786e3,
            8.893e2,
            1.906e3,
            9.164e2,
            5.134e2,
            3.172e2,
            1.469e2,
            8.038e1,
            2.672e1,
            7.712e1,
            2.666e1,
            1.223e1,
            6.644,
            4.032,
            1.852,
            1.037,
            4.023e-1,
            2.344e-1,
            1.357e-1,
            1.040e-1,
            8.831e-2,
            7.858e-2,
            6.642e-2,
            5.866e-2,
            5.196e-2,
            4.741e-2,
            4.185e-2,
            3.686e-2,
            3.498e-2,
            3.436e-2,
            3.432e-2,
            3.508e-2,
            3.628e-2,
            3.944e-2,
            4.224e-2,
        ],
        [
            4.942e3,
            1.925e3,
            9.593e2,
            2.011e3,
            9.703e2,
            5.450e2,
            3.373e2,
            1.565e2,
            8.576e1,
            2.854e1,
            8.054e1,
            2.810e1,
            1.294e1,
            7.037,
            4.274,
            1.962,
            1.096,
            4.208e-1,
            2.423e-1,
            1.379e-1,
            1.047e-1,
            8.848e-2,
            7.851e-2,
            6.619e-2,
            5.837e-2,
            5.167e-2,
            4.713e-2,
            4.163e-2,
            3.675e-2,
            3.496e-2,
            3.439e-2,
            3.440e-2,
            3.523e-2,
            3.650e-2,
            3.978e-2,
            4.264e-2,
        ],
        [
            5.356e3,
            2.092e3,
            1.044e3,
            1.862e3,
            1.036e3,
            5.836e2,
            3.619e2,
            1.683e2,
            9.231e1,
            3.076e1,
            1.410e1,
            2.993e1,
            1.381e1,
            7.521,
            4.571,
            2.099,
            1.169,
            4.449e-1,
            2.534e-1,
            1.418e-1,
            1.066e-1,
            8.968e-2,
            7.935e-2,
            6.674e-2,
            5.876e-2,
            5.197e-2,
            4.740e-2,
            4.189e-2,
            3.705e-2,
            3.532e-2,
            3.482e-2,
            3.487e-2,
            3.578e-2,
            3.712e-2,
            4.055e-2,
            4.353e-2,
        ],
        [
            5.718e3,
            2.240e3,
            1.120e3,
            1.963e3,
            1.095e3,
            6.165e2,
            3.832e2,
            1.785e2,
            9.800e1,
            3.270e1,
            1.499e1,
            3.139e1,
            1.452e1,
            7.926,
            4.822,
            2.215,
            1.232,
            4.647e-1,
            2.618e-1,
            1.440e-1,
            1.074e-1,
            8.992e-2,
            7.933e-2,
            6.647e-2,
            5.846e-2,
            5.166e-2,
            4.710e-2,
            4.164e-2,
            3.692e-2,
            3.527e-2,
            3.482e-2,
            3.491e-2,
            3.591e-2,
            3.730e-2,
            4.084e-2,
            4.387e-2,
        ],
        [
            6.169e3,
            2.426e3,
            1.214e3,
            4.441e2,
            1.170e3,
            6.589e2,
            4.101e2,
            1.915e2,
            1.053e2,
            3.518e1,
            1.613e1,
            3.330e1,
            1.544e1,
            8.448,
            5.147,
            2.365,
            1.314,
            4.916e-1,
            2.742e-1,
            1.485e-1,
            1.097e-1,
            9.134e-2,
            8.035e-2,
            6.711e-2,
            5.894e-2,
            5.204e-2,
            4.744e-2,
            4.197e-2,
            3.728e-2,
            3.568e-2,
            3.529e-2,
            3.542e-2,
            3.650e-2,
            3.797e-2,
            4.166e-2,
            4.481e-2,
        ],
        [
            6.538e3,
            2.579e3,
            1.292e3,
            4.730e2,
            1.227e3,
            6.912e2,
            4.308e2,
            2.017e2,
            1.110e2,
            3.715e1,
            1.704e1,
            3.465e1,
            1.614e1,
            8.850,
            5.399,
            2.481,
            1.377,
            5.115e-1,
            2.827e-1,
            1.506e-1,
            1.103e-1,
            9.134e-2,
            8.010e-2,
            6.669e-2,
            5.849e-2,
            5.159e-2,
            4.702e-2,
            4.162e-2,
            3.704e-2,
            3.552e-2,
            3.518e-2,
            3.537e-2,
            3.651e-2,
            3.802e-2,
            4.181e-2,
            4.501e-2,
        ],
        [
            7.039e3,
            2.790e3,
            1.401e3,
            5.136e2,
            1.305e3,
            7.385e2,
            4.610e2,
            2.164e2,
            1.193e2,
            3.998e1,
            1.836e1,
            3.668e1,
            1.720e1,
            9.444,
            5.766,
            2.651,
            1.470,
            5.426e-1,
            2.972e-1,
            1.560e-1,
            1.131e-1,
            9.321e-2,
            8.153e-2,
            6.766e-2,
            5.921e-2,
            5.217e-2,
            4.754e-2,
            4.209e-2,
            3.754e-2,
            3.606e-2,
            3.577e-2,
            3.601e-2,
            3.723e-2,
            3.882e-2,
            4.276e-2,
            4.609e-2,
        ],
        [
            7.350e3,
            2.931e3,
            1.473e3,
            5.414e2,
            1.170e3,
            7.685e2,
            4.793e2,
            2.254e2,
            1.244e2,
            4.178e1,
            1.920e1,
            3.765e1,
            1.778e1,
            9.779,
            5.975,
            2.751,
            1.524,
            5.593e-1,
            3.038e-1,
            1.571e-1,
            1.129e-1,
            9.250e-2,
            8.064e-2,
            6.670e-2,
            5.826e-2,
            5.129e-2,
            4.673e-2,
            4.139e-2,
            3.698e-2,
            3.559e-2,
            3.536e-2,
            3.563e-2,
            3.691e-2,
            3.853e-2,
            4.253e-2,
            4.587e-2,
        ],
        [
            7.809e3,
            3.131e3,
            1.578e3,
            5.808e2,
            1.231e3,
            8.134e2,
            5.072e2,
            2.391e2,
            1.321e2,
            4.445e1,
            2.044e1,
            3.949e1,
            1.873e1,
            1.030e1,
            6.306,
            2.907,
            1.609,
            5.876e-1,
            3.167e-1,
            1.614e-1,
            1.149e-1,
            9.371e-2,
            8.138e-2,
            6.707e-2,
            5.849e-2,
            5.144e-2,
            4.684e-2,
            4.151e-2,
            3.715e-2,
            3.582e-2,
            3.564e-2,
            3.596e-2,
            3.730e-2,
            3.898e-2,
            4.311e-2,
            4.654e-2,
        ],
        [
            8.157e3,
            3.296e3,
            1.665e3,
            6.143e2,
            9.393e2,
            8.471e2,
            5.294e2,
            2.500e2,
            1.384e2,
            4.664e1,
            2.146e1,
            4.121e1,
            1.942e1,
            1.070e1,
            6.564,
            3.029,
            1.676,
            6.091e-1,
            3.260e-1,
            1.639e-1,
            1.156e-1,
            9.374e-2,
            8.113e-2,
            6.662e-2,
            5.800e-2,
            5.095e-2,
            4.638e-2,
            4.112e-2,
            3.686e-2,
            3.561e-2,
            3.548e-2,
            3.583e-2,
            3.724e-2,
            3.895e-2,
            4.315e-2,
            4.662e-2,
        ],
        [
            8.582e3,
            3.491e3,
            1.767e3,
            6.536e2,
            3.169e2,
            8.846e2,
            5.569e2,
            2.631e2,
            1.459e2,
            4.923e1,
            2.268e1,
            7.631,
            2.027e1,
            1.120e1,
            6.879,
            3.176,
            1.758,
            6.361e-1,
            3.381e-1,
            1.677e-1,
            1.172e-1,
            9.453e-2,
            8.153e-2,
            6.670e-2,
            5.797e-2,
            5.086e-2,
            4.628e-2,
            4.105e-2,
            3.686e-2,
            3.567e-2,
            3.559e-2,
            3.598e-2,
            3.745e-2,
            3.921e-2,
            4.351e-2,
            4.704e-2,
        ],
        [
            8.434e3,
            3.608e3,
            1.832e3,
            6.792e2,
            3.297e2,
            9.014e2,
            5.721e2,
            2.702e2,
            1.501e2,
            5.078e1,
            2.341e1,
            7.878,
            2.064e1,
            1.145e1,
            7.041,
            3.255,
            1.801,
            6.492e-1,
            3.429e-1,
            1.679e-1,
            1.163e-1,
            9.328e-2,
            8.022e-2,
            6.538e-2,
            5.669e-2,
            4.967e-2,
            4.518e-2,
            4.009e-2,
            3.606e-2,
            3.494e-2,
            3.492e-2,
            3.534e-2,
            3.683e-2,
            3.860e-2,
            4.290e-2,
            4.642e-2,
        ],
        [
            9.096e3,
            3.919e3,
            1.997e3,
            7.420e2,
            3.607e2,
            8.430e2,
            6.173e2,
            2.922e2,
            1.626e2,
            5.512e1,
            2.543e1,
            8.561,
            2.210e1,
            1.232e1,
            7.579,
            3.510,
            1.942,
            6.978e-1,
            3.663e-1,
            1.771e-1,
            1.217e-1,
            9.701e-2,
            8.313e-2,
            6.749e-2,
            5.841e-2,
            5.111e-2,
            4.647e-2,
            4.124e-2,
            3.716e-2,
            3.607e-2,
            3.608e-2,
            3.655e-2,
            3.815e-2,
            4.002e-2,
            4.455e-2,
            4.823e-2,
        ],
        [
            9.413e3,
            4.085e3,
            2.088e3,
            7.780e2,
            3.787e2,
            6.392e2,
            6.376e2,
            3.032e2,
            1.690e2,
            5.743e1,
            2.652e1,
            8.930,
            2.270e1,
            1.272e1,
            7.825,
            3.633,
            2.011,
            7.202e-1,
            3.760e-1,
            1.797e-1,
            1.223e-1,
            9.699e-2,
            8.281e-2,
            6.696e-2,
            5.785e-2,
            5.054e-2,
            4.594e-2,
            4.078e-2,
            3.681e-2,
            3.577e-2,
            3.583e-2,
            3.634e-2,
            3.797e-2,
            3.987e-2,
            4.445e-2,
            4.815e-2,
        ],
        [
            9.365e3,
            4.335e3,
            2.226e3,
            8.319e2,
            4.055e2,
            2.303e2,
            6.711e2,
            3.214e2,
            1.793e2,
            6.104e1,
            2.822e1,
            9.507,
            2.381e1,
            1.340e1,
            8.248,
            3.836,
            2.124,
            7.589e-1,
            3.941e-1,
            1.863e-1,
            1.257e-1,
            9.912e-2,
            8.431e-2,
            6.789e-2,
            5.854e-2,
            5.108e-2,
            4.641e-2,
            4.121e-2,
            3.725e-2,
            3.625e-2,
            3.635e-2,
            3.689e-2,
            3.860e-2,
            4.057e-2,
            4.529e-2,
            4.910e-2,
        ],
        [
            8.543e3,
            4.499e3,
            2.319e3,
            8.696e2,
            4.246e2,
            2.414e2,
            6.898e2,
            3.334e2,
            1.860e2,
            6.347e1,
            2.938e1,
            9.904,
            2.457e1,
            1.379e1,
            8.511,
            3.963,
            2.196,
            7.828e-1,
            4.046e-1,
            1.891e-1,
            1.265e-1,
            9.923e-2,
            8.410e-2,
            6.744e-2,
            5.803e-2,
            5.058e-2,
            4.592e-2,
            4.078e-2,
            3.692e-2,
            3.598e-2,
            3.612e-2,
            3.669e-2,
            3.844e-2,
            4.042e-2,
            4.518e-2,
            4.902e-2,
        ],
        [
            9.087e3,
            4.772e3,
            2.464e3,
            9.267e2,
            4.531e2,
            2.578e2,
            6.319e2,
            3.529e2,
            1.967e2,
            6.731e1,
            3.119e1,
            1.052e1,
            2.579e1,
            1.447e1,
            8.962,
            4.177,
            2.315,
            8.239e-1,
            4.239e-1,
            1.961e-1,
            1.301e-1,
            1.015e-1,
            8.570e-2,
            6.843e-2,
            5.876e-2,
            5.110e-2,
            4.640e-2,
            4.122e-2,
            3.737e-2,
            3.646e-2,
            3.664e-2,
            3.726e-2,
            3.907e-2,
            4.113e-2,
            4.603e-2,
            4.996e-2,
        ],
        [
            9.711e3,
            5.033e3,
            2.607e3,
            9.857e2,
            4.811e2,
            2.740e2,
            4.908e2,
            3.732e2,
            2.082e2,
            7.143e1,
            3.312e1,
            1.119e1,
            5.215,
            1.520e1,
            9.447,
            4.409,
            2.445,
            8.687e-1,
            4.452e-1,
            2.039e-1,
            1.342e-1,
            1.041e-1,
            8.757e-2,
            6.962e-2,
            5.961e-2,
            5.181e-2,
            4.701e-2,
            4.177e-2,
            3.792e-2,
            3.705e-2,
            3.727e-2,
            3.792e-2,
            3.981e-2,
            4.194e-2,
            4.699e-2,
            5.103e-2,
        ],
        [
            1.058e4,
            5.090e3,
            2.768e3,
            1.047e3,
            5.131e2,
            2.924e2,
            5.145e2,
            3.950e2,
            2.209e2,
            7.597e1,
            3.526e1,
            1.192e1,
            5.557,
            1.599e1,
            9.977,
            4.664,
            2.588,
            9.180e-1,
            4.687e-1,
            2.126e-1,
            1.389e-1,
            1.071e-1,
            8.976e-2,
            7.105e-2,
            6.070e-2,
            5.268e-2,
            4.779e-2,
            4.244e-2,
            3.858e-2,
            3.774e-2,
            3.800e-2,
            3.870e-2,
            4.067e-2,
            4.288e-2,
            4.809e-2,
            5.226e-2,
        ],
        [
            6.627e3,
            5.273e3,
            2.878e3,
            1.093e3,
            5.366e2,
            3.061e2,
            1.927e2,
            4.094e2,
            2.300e2,
            7.925e1,
            3.684e1,
            1.247e1,
            5.809,
            1.650e1,
            1.033e1,
            4.839,
            2.687,
            9.522e-1,
            4.844e-1,
            2.178e-1,
            1.412e-1,
            1.083e-1,
            9.040e-2,
            7.127e-2,
            6.072e-2,
            5.262e-2,
            4.769e-2,
            4.236e-2,
            3.856e-2,
            3.776e-2,
            3.806e-2,
            3.879e-2,
            4.081e-2,
            4.304e-2,
            4.832e-2,
            5.257e-2,
        ],
        [
            2.056e3,
            5.553e3,
            3.048e3,
            1.162e3,
            5.709e2,
            3.260e2,
            2.053e2,
            4.314e2,
            2.440e2,
            8.411e1,
            3.916e1,
            1.327e1,
            6.181,
            1.735e1,
            1.087e1,
            5.107,
            2.840,
            1.005,
            5.098e-1,
            2.273e-1,
            1.462e-1,
            1.115e-1,
            9.276e-2,
            7.280e-2,
            6.188e-2,
            5.350e-2,
            4.849e-2,
            4.308e-2,
            3.925e-2,
            3.849e-2,
            3.882e-2,
            3.959e-2,
            4.169e-2,
            4.401e-2,
            4.946e-2,
            5.380e-2,
        ],
        [
            2.107e3,
            5.358e3,
            3.120e3,
            1.193e3,
            5.873e2,
            3.356e2,
            2.115e2,
            4.401e2,
            2.499e2,
            8.633e1,
            4.025e1,
            1.365e1,
            6.362,
            1.774e1,
            1.107e1,
            5.212,
            2.901,
            1.027,
            5.192e-1,
            2.296e-1,
            1.466e-1,
            1.112e-1,
            9.218e-2,
            7.201e-2,
            6.106e-2,
            5.271e-2,
            4.773e-2,
            4.240e-2,
            3.868e-2,
            3.797e-2,
            3.833e-2,
            3.912e-2,
            4.124e-2,
            4.355e-2,
            4.899e-2,
            5.335e-2,
        ],
        [
            2.216e3,
            5.624e3,
            3.278e3,
            1.256e3,
            6.193e2,
            3.542e2,
            2.234e2,
            3.989e2,
            2.629e2,
            9.087e1,
            4.242e1,
            1.441e1,
            6.716,
            1.850e1,
            1.155e1,
            5.455,
            3.040,
            1.076,
            5.425e-1,
            2.380e-1,
            1.509e-1,
            1.139e-1,
            9.404e-2,
            7.312e-2,
            6.186e-2,
            5.331e-2,
            4.822e-2,
            4.285e-2,
            3.913e-2,
            3.845e-2,
            3.885e-2,
            3.967e-2,
            4.185e-2,
            4.422e-2,
            4.980e-2,
            5.423e-2,
        ],
        [
            2.291e3,
            5.041e3,
            3.360e3,
            1.292e3,
            6.380e2,
            3.653e2,
            2.305e2,
            4.068e2,
            2.693e2,
            9.335e1,
            4.363e1,
            1.484e1,
            6.920,
            3.859,
            1.175e1,
            5.573,
            3.109,
            1.100,
            5.534e-1,
            2.410e-1,
            1.517e-1,
            1.139e-1,
            9.371e-2,
            7.252e-2,
            6.120e-2,
            5.262e-2,
            4.759e-2,
            4.228e-2,
            3.865e-2,
            3.802e-2,
            3.844e-2,
            3.928e-2,
            4.147e-2,
            4.384e-2,
            4.943e-2,
            5.385e-2,
        ],
        [
            2.396e3,
            5.314e3,
            3.507e3,
            1.354e3,
            6.697e2,
            3.838e2,
            2.423e2,
            3.133e2,
            2.815e2,
            9.802e1,
            4.588e1,
            1.563e1,
            7.288,
            4.064,
            1.223e1,
            5.826,
            3.253,
            1.151,
            5.775e-1,
            2.498e-1,
            1.562e-1,
            1.167e-1,
            9.562e-2,
            7.365e-2,
            6.196e-2,
            5.321e-2,
            4.808e-2,
            4.272e-2,
            3.908e-2,
            3.848e-2,
            3.894e-2,
            3.981e-2,
            4.206e-2,
            4.449e-2,
            5.017e-2,
            5.470e-2,
        ],
        [
            2.494e3,
            5.550e3,
            3.467e3,
            1.405e3,
            6.953e2,
            3.988e2,
            2.520e2,
            3.269e2,
            2.902e2,
            1.016e2,
            4.765e1,
            1.625e1,
            7.582,
            4.227,
            1.259e1,
            6.012,
            3.360,
            1.189,
            5.953e-1,
            2.558e-1,
            1.590e-1,
            1.181e-1,
            9.644e-2,
            7.393e-2,
            6.204e-2,
            5.318e-2,
            4.801e-2,
            4.265e-2,
            3.905e-2,
            3.848e-2,
            3.896e-2,
            3.986e-2,
            4.214e-2,
            4.460e-2,
            5.033e-2,
            5.492e-2,
        ],
        [
            2.616e3,
            5.847e3,
            3.590e3,
            1.465e3,
            7.264e2,
            4.170e2,
            2.636e2,
            1.271e2,
            3.012e2,
            1.060e2,
            4.980e1,
            1.701e1,
            7.940,
            4.425,
            1.309e1,
            6.244,
            3.492,
            1.236,
            6.178e-1,
            2.639e-1,
            1.629e-1,
            1.205e-1,
            9.800e-2,
            7.477e-2,
            6.257e-2,
            5.351e-2,
            4.828e-2,
            4.289e-2,
            3.930e-2,
            3.877e-2,
            3.927e-2,
            4.020e-2,
            4.253e-2,
            4.504e-2,
            5.088e-2,
            5.551e-2,
        ],
        [
            2.748e3,
            6.069e3,
            3.523e3,
            1.526e3,
            7.587e2,
            4.359e2,
            2.757e2,
            1.330e2,
            3.129e2,
            1.106e2,
            5.204e1,
            1.780e1,
            8.315,
            4.634,
            1.362e1,
            6.478,
            3.628,
            1.285,
            6.415e-1,
            2.724e-1,
            1.672e-1,
            1.230e-1,
            9.968e-2,
            7.569e-2,
            6.317e-2,
            5.392e-2,
            4.860e-2,
            4.317e-2,
            3.958e-2,
            3.907e-2,
            3.961e-2,
            4.056e-2,
            4.294e-2,
            4.549e-2,
            5.141e-2,
            5.613e-2,
        ],
        [
            2.899e3,
            3.937e3,
            3.686e3,
            1.594e3,
            7.946e2,
            4.569e2,
            2.892e2,
            1.397e2,
            2.830e2,
            1.157e2,
            5.453e1,
            1.868e1,
            8.735,
            4.867,
            1.409e1,
            6.741,
            3.780,
            1.340,
            6.682e-1,
            2.822e-1,
            1.722e-1,
            1.261e-1,
            1.018e-1,
            7.693e-2,
            6.404e-2,
            5.455e-2,
            4.912e-2,
            4.362e-2,
            4.002e-2,
            3.954e-2,
            4.010e-2,
            4.108e-2,
            4.352e-2,
            4.612e-2,
            5.216e-2,
            5.698e-2,
        ],
        [
            3.017e3,
            1.350e3,
            3.797e3,
            1.640e3,
            8.193e2,
            4.717e2,
            2.988e2,
            1.444e2,
            2.893e2,
            1.193e2,
            5.628e1,
            1.932e1,
            9.040,
            5.038,
            3.147,
            6.909,
            3.881,
            1.378,
            6.860e-1,
            2.882e-1,
            1.749e-1,
            1.274e-1,
            1.025e-1,
            7.710e-2,
            6.397e-2,
            5.439e-2,
            4.895e-2,
            4.347e-2,
            3.989e-2,
            3.944e-2,
            4.002e-2,
            4.101e-2,
            4.347e-2,
            4.609e-2,
            5.218e-2,
            5.700e-2,
        ],
        [
            3.187e3,
            1.424e3,
            3.452e3,
            1.710e3,
            8.560e2,
            4.934e2,
            3.129e2,
            1.513e2,
            2.211e2,
            1.247e2,
            5.881e1,
            2.023e1,
            9.472,
            5.279,
            3.297,
            7.161,
            4.033,
            1.433,
            7.130e-1,
            2.981e-1,
            1.799e-1,
            1.305e-1,
            1.046e-1,
            7.829e-2,
            6.478e-2,
            5.496e-2,
            4.941e-2,
            4.385e-2,
            4.028e-2,
            3.985e-2,
            4.045e-2,
            4.147e-2,
            4.398e-2,
            4.664e-2,
            5.282e-2,
            5.773e-2,
        ],
        [
            3.335e3,
            1.489e3,
            3.598e3,
            1.768e3,
            8.859e2,
            5.113e2,
            3.244e2,
            1.571e2,
            2.301e2,
            1.290e2,
            6.087e1,
            2.098e1,
            9.828,
            5.478,
            3.420,
            7.352,
            4.154,
            1.477,
            7.339e-1,
            3.054e-1,
            1.834e-1,
            1.324e-1,
            1.058e-1,
            7.880e-2,
            6.502e-2,
            5.505e-2,
            4.944e-2,
            4.387e-2,
            4.030e-2,
            3.989e-2,
            4.052e-2,
            4.155e-2,
            4.409e-2,
            4.677e-2,
            5.301e-2,
            5.796e-2,
        ],
        [
            3.510e3,
            1.566e3,
            3.771e3,
            1.838e3,
            9.222e2,
            5.328e2,
            3.382e2,
            1.639e2,
            2.379e2,
            1.340e2,
            6.334e1,
            2.187e1,
            1.025e1,
            5.717,
            3.569,
            7.587,
            4.302,
            1.531,
            7.598e-1,
            3.149e-1,
            1.881e-1,
            1.352e-1,
            1.076e-1,
            7.981e-2,
            6.567e-2,
            5.545e-2,
            4.977e-2,
            4.413e-2,
            4.057e-2,
            4.018e-2,
            4.082e-2,
            4.188e-2,
            4.446e-2,
            4.717e-2,
            5.350e-2,
            5.852e-2,
        ],
        [
            3.683e3,
            1.643e3,
            3.922e3,
            1.902e3,
            9.564e2,
            5.534e2,
            3.514e2,
            1.705e2,
            9.691e1,
            1.389e2,
            6.573e1,
            2.273e1,
            1.067e1,
            5.949,
            3.713,
            7.810,
            4.438,
            1.581,
            7.844e-1,
            3.238e-1,
            1.925e-1,
            1.378e-1,
            1.093e-1,
            8.066e-2,
            6.618e-2,
            5.577e-2,
            5.000e-2,
            4.433e-2,
            4.075e-2,
            4.038e-2,
            4.103e-2,
            4.210e-2,
            4.472e-2,
            4.747e-2,
            5.384e-2,
            5.893e-2,
        ],
        [
            3.872e3,
            1.729e3,
            3.773e3,
            1.972e3,
            9.943e2,
            5.759e2,
            3.660e2,
            1.778e2,
            1.011e2,
            1.440e2,
            6.835e1,
            2.367e1,
            1.112e1,
            6.206,
            3.872,
            8.069,
            4.587,
            1.637,
            8.119e-1,
            3.339e-1,
            1.976e-1,
            1.409e-1,
            1.114e-1,
            8.179e-2,
            6.688e-2,
            5.627e-2,
            5.038e-2,
            4.463e-2,
            4.105e-2,
            4.068e-2,
            4.137e-2,
            4.246e-2,
            4.511e-2,
            4.790e-2,
            5.437e-2,
            5.953e-2,
        ],
        [
            4.032e3,
            1.801e3,
            2.218e3,
            1.938e3,
            1.023e3,
            5.936e2,
            3.776e2,
            1.836e2,
            1.045e2,
            1.478e2,
            7.039e1,
            2.443e1,
            1.149e1,
            6.414,
            4.002,
            8.290,
            4.696,
            1.680,
            8.327e-1,
            3.414e-1,
            2.011e-1,
            1.428e-1,
            1.125e-1,
            8.224e-2,
            6.705e-2,
            5.625e-2,
            5.034e-2,
            4.458e-2,
            4.100e-2,
            4.065e-2,
            4.134e-2,
            4.244e-2,
            4.511e-2,
            4.791e-2,
            5.442e-2,
            5.956e-2,
        ],
        [
            4.243e3,
            1.898e3,
            1.032e3,
            2.011e3,
            1.063e3,
            6.178e2,
            3.935e2,
            1.914e2,
            1.090e2,
            1.530e2,
            7.317e1,
            2.546e1,
            1.199e1,
            6.693,
            4.176,
            8.585,
            4.855,
            1.740,
            8.628e-1,
            3.525e-1,
            2.068e-1,
            1.463e-1,
            1.149e-1,
            8.357e-2,
            6.794e-2,
            5.688e-2,
            5.083e-2,
            4.501e-2,
            4.139e-2,
            4.104e-2,
            4.174e-2,
            4.286e-2,
            4.558e-2,
            4.844e-2,
            5.502e-2,
            6.024e-2,
        ],
        [
            4.433e3,
            1.986e3,
            1.081e3,
            1.965e3,
            1.100e3,
            6.402e2,
            4.083e2,
            1.987e2,
            1.132e2,
            1.578e2,
            7.574e1,
            2.641e1,
            1.245e1,
            6.954,
            4.339,
            8.731,
            4.993,
            1.795,
            8.896e-1,
            3.625e-1,
            2.118e-1,
            1.492e-1,
            1.168e-1,
            8.456e-2,
            6.857e-2,
            5.727e-2,
            5.112e-2,
            4.522e-2,
            4.160e-2,
            4.124e-2,
            4.196e-2,
            4.310e-2,
            4.584e-2,
            4.872e-2,
            5.537e-2,
            6.064e-2,
        ],
        [
            4.652e3,
            2.089e3,
            1.137e3,
            2.049e3,
            1.144e3,
            6.661e2,
            4.253e2,
            2.072e2,
            1.181e2,
            1.637e2,
            7.883e1,
            2.752e1,
            1.298e1,
            7.256,
            4.528,
            2.185,
            5.158,
            1.860,
            9.214e-1,
            3.744e-1,
            2.180e-1,
            1.530e-1,
            1.194e-1,
            8.603e-2,
            6.953e-2,
            5.794e-2,
            5.167e-2,
            4.570e-2,
            4.201e-2,
            4.166e-2,
            4.239e-2,
            4.355e-2,
            4.633e-2,
            4.926e-2,
            5.598e-2,
            6.136e-2,
        ],
        [
            4.830e3,
            2.174e3,
            1.184e3,
            2.117e3,
            1.179e3,
            6.869e2,
            4.387e2,
            2.140e2,
            1.221e2,
            1.681e2,
            8.123e1,
            2.841e1,
            1.342e1,
            7.504,
            4.683,
            2.259,
            5.279,
            1.909,
            9.456e-1,
            3.834e-1,
            2.224e-1,
            1.555e-1,
            1.210e-1,
            8.679e-2,
            6.993e-2,
            5.814e-2,
            5.179e-2,
            4.575e-2,
            4.207e-2,
            4.172e-2,
            4.246e-2,
            4.362e-2,
            4.643e-2,
            4.937e-2,
            5.613e-2,
            6.154e-2,
        ],
        [
            5.008e3,
            2.259e3,
            1.231e3,
            2.188e3,
            1.212e3,
            7.068e2,
            4.518e2,
            2.208e2,
            1.260e2,
            1.497e2,
            8.361e1,
            2.929e1,
            1.385e1,
            7.751,
            4.838,
            2.332,
            5.398,
            1.957,
            9.696e-1,
            3.923e-1,
            2.267e-1,
            1.580e-1,
            1.226e-1,
            8.751e-2,
            7.031e-2,
            5.832e-2,
            5.187e-2,
            4.581e-2,
            4.210e-2,
            4.175e-2,
            4.248e-2,
            4.366e-2,
            4.647e-2,
            4.943e-2,
            5.622e-2,
            6.162e-2,
        ],
        [
            5.210e3,
            2.356e3,
            1.285e3,
            1.965e3,
            1.251e3,
            7.304e2,
            4.672e2,
            2.287e2,
            1.306e2,
            1.116e2,
            8.636e1,
            3.032e1,
            1.436e1,
            8.041,
            5.021,
            2.419,
            5.549,
            2.014,
            9.985e-1,
            4.031e-1,
            2.323e-1,
            1.614e-1,
            1.248e-1,
            8.870e-2,
            7.102e-2,
            5.876e-2,
            5.222e-2,
            4.606e-2,
            4.234e-2,
            4.197e-2,
            4.272e-2,
            4.391e-2,
            4.675e-2,
            4.972e-2,
            5.658e-2,
            6.206e-2,
        ],
        [
            5.441e3,
            2.468e3,
            1.348e3,
            2.053e3,
            1.296e3,
            7.580e2,
            4.855e2,
            2.378e2,
            1.360e2,
            1.160e2,
            8.952e1,
            3.152e1,
            1.495e1,
            8.379,
            5.233,
            2.522,
            5.739,
            2.082,
            1.033,
            4.163e-1,
            2.391e-1,
            1.656e-1,
            1.277e-1,
            9.036e-2,
            7.214e-2,
            5.955e-2,
            5.285e-2,
            4.659e-2,
            4.279e-2,
            4.242e-2,
            4.317e-2,
            4.437e-2,
            4.725e-2,
            5.025e-2,
            5.721e-2,
            6.276e-2,
        ],
        [
            5.724e3,
            2.604e3,
            1.423e3,
            2.155e3,
            1.299e3,
            7.931e2,
            5.085e2,
            2.494e2,
            1.427e2,
            1.219e2,
            9.352e1,
            3.303e1,
            1.569e1,
            8.802,
            5.499,
            2.649,
            5.991,
            2.170,
            1.078,
            4.335e-1,
            2.483e-1,
            1.714e-1,
            1.318e-1,
            9.286e-2,
            7.391e-2,
            6.087e-2,
            5.394e-2,
            4.749e-2,
            4.362e-2,
            4.323e-2,
            4.399e-2,
            4.522e-2,
            4.816e-2,
            5.124e-2,
            5.835e-2,
            6.398e-2,
        ],
        [
            5.868e3,
            2.731e3,
            1.495e3,
            2.250e3,
            1.275e3,
            8.251e2,
            5.299e2,
            2.601e2,
            1.490e2,
            1.279e2,
            9.704e1,
            3.442e1,
            1.638e1,
            9.196,
            5.748,
            2.769,
            6.174,
            2.249,
            1.118,
            4.491e-1,
            2.565e-1,
            1.765e-1,
            1.354e-1,
            9.495e-2,
            7.538e-2,
            6.189e-2,
            5.479e-2,
            4.821e-2,
            4.424e-2,
            4.383e-2,
            4.461e-2,
            4.585e-2,
            4.883e-2,
            5.195e-2,
            5.918e-2,
            6.493e-2,
        ],
        [
            5.826e3,
            2.719e3,
            1.490e3,
            1.554e3,
            1.266e3,
            8.163e2,
            5.240e2,
            2.577e2,
            1.477e2,
            1.259e2,
            9.563e1,
            3.408e1,
            1.624e1,
            9.125,
            5.706,
            2.749,
            6.086,
            2.215,
            1.101,
            4.420e-1,
            2.518e-1,
            1.728e-1,
            1.322e-1,
            9.230e-2,
            7.303e-2,
            5.984e-2,
            5.290e-2,
            4.649e-2,
            4.264e-2,
            4.224e-2,
            4.298e-2,
            4.418e-2,
            4.705e-2,
            5.007e-2,
            5.704e-2,
            6.260e-2,
        ],
        [
            6.238e3,
            2.846e3,
            1.562e3,
            1.994e3,
            1.322e3,
            8.489e2,
            5.451e2,
            2.684e2,
            1.539e2,
            5.573e1,
            9.933e1,
            3.550e1,
            1.694e1,
            9.525,
            5.959,
            2.871,
            1.655,
            2.295,
            1.141,
            4.577e-1,
            2.601e-1,
            1.780e-1,
            1.358e-1,
            9.444e-2,
            7.450e-2,
            6.087e-2,
            5.376e-2,
            4.721e-2,
            4.324e-2,
            4.283e-2,
            4.358e-2,
            4.479e-2,
            4.769e-2,
            5.077e-2,
            5.786e-2,
            6.350e-2,
        ],
        [
            6.201e3,
            2.950e3,
            1.620e3,
            6.664e2,
            1.367e3,
            8.741e2,
            5.613e2,
            2.769e2,
            1.589e2,
            5.760e1,
            1.023e2,
            3.664e1,
            1.750e1,
            9.850,
            6.166,
            2.971,
            1.712,
            2.355,
            1.172,
            4.696e-1,
            2.662e-1,
            1.817e-1,
            1.383e-1,
            9.579e-2,
            7.535e-2,
            6.141e-2,
            5.415e-2,
            4.751e-2,
            4.348e-2,
            4.304e-2,
            4.379e-2,
            4.500e-2,
            4.793e-2,
            5.102e-2,
            5.815e-2,
            6.383e-2,
        ],
        [
            6.469e3,
            3.082e3,
            1.696e3,
            6.981e2,
            1.426e3,
            8.687e2,
            5.829e2,
            2.878e2,
            1.653e2,
            6.002e1,
            1.062e2,
            3.811e1,
            1.823e1,
            1.027e1,
            6.433,
            3.100,
            1.786,
            2.434,
            1.213,
            4.859e-1,
            2.749e-1,
            1.872e-1,
            1.421e-1,
            9.804e-2,
            7.686e-2,
            6.251e-2,
            5.504e-2,
            4.822e-2,
            4.409e-2,
            4.363e-2,
            4.438e-2,
            4.560e-2,
            4.856e-2,
            5.171e-2,
            5.895e-2,
            6.473e-2,
        ],
        [
            6.614e3,
            3.161e3,
            1.742e3,
            7.180e2,
            1.253e3,
            8.878e2,
            5.945e2,
            2.939e2,
            1.689e2,
            6.141e1,
            9.368e1,
            3.892e1,
            1.865e1,
            1.052e1,
            6.592,
            3.178,
            1.830,
            2.472,
            1.234,
            4.939e-1,
            2.789e-1,
            1.895e-1,
            1.435e-1,
            9.861e-2,
            7.709e-2,
            6.251e-2,
            5.498e-2,
            4.812e-2,
            4.396e-2,
            4.347e-2,
            4.421e-2,
            4.542e-2,
            4.836e-2,
            5.149e-2,
            5.871e-2,
            6.447e-2,
        ],
        [
            6.530e3,
            3.327e3,
            1.834e3,
            7.558e2,
            1.315e3,
            8.759e2,
            6.217e2,
            3.074e2,
            1.769e2,
            6.442e1,
            7.025e1,
            4.077e1,
            1.957e1,
            1.105e1,
            6.929,
            3.342,
            1.924,
            2.575,
            1.288,
            5.152e-1,
            2.904e-1,
            1.969e-1,
            1.487e-1,
            1.018e-1,
            7.937e-2,
            6.420e-2,
            5.637e-2,
            4.927e-2,
            4.496e-2,
            4.445e-2,
            4.519e-2,
            4.641e-2,
            4.943e-2,
            5.261e-2,
            6.000e-2,
            6.592e-2,
        ],
        [
            6.626e3,
            3.382e3,
            1.865e3,
            7.692e2,
            1.329e3,
            8.891e2,
            6.284e2,
            3.108e2,
            1.791e2,
            6.528e1,
            7.106e1,
            4.128e1,
            1.983e1,
            1.121e1,
            7.035,
            3.395,
            1.954,
            2.591,
            1.298,
            5.192e-1,
            2.922e-1,
            1.976e-1,
            1.490e-1,
            1.016e-1,
            7.896e-2,
            6.370e-2,
            5.587e-2,
            4.878e-2,
            4.447e-2,
            4.392e-2,
            4.463e-2,
            4.583e-2,
            4.879e-2,
            5.195e-2,
            5.927e-2,
            6.512e-2,
        ],
        [
            6.950e3,
            3.490e3,
            1.960e3,
            8.090e2,
            1.390e3,
            9.320e2,
            6.570e2,
            3.250e2,
            1.870e2,
            6.840e1,
            7.450e1,
            4.310e1,
            2.080e1,
            1.180e1,
            7.390,
            3.570,
            2.050,
            2.700,
            1.350,
            5.410e-1,
            3.040e-1,
            2.050e-1,
            1.540e-1,
            1.050e-1,
            8.130e-2,
            6.540e-2,
            5.730e-2,
            4.990e-2,
            4.550e-2,
            4.490e-2,
            4.560e-2,
            4.680e-2,
            4.980e-2,
            5.300e-2,
            6.050e-2,
            6.650e-2,
        ],
        [
            7.190e3,
            3.620e3,
            2.040e3,
            8.390e2,
            1.430e3,
            9.650e2,
            6.760e2,
            3.350e2,
            1.940e2,
            7.060e1,
            7.710e1,
            4.450e1,
            2.150e1,
            1.220e1,
            7.650,
            3.700,
            2.130,
            2.770,
            1.390,
            5.570e-1,
            3.120e-1,
            2.100e-1,
            1.580e-1,
            1.070e-1,
            8.260e-2,
            6.630e-2,
            5.800e-2,
            5.050e-2,
            4.590e-2,
            4.530e-2,
            4.600e-2,
            4.720e-2,
            5.020e-2,
            5.350e-2,
            6.100e-2,
            6.710e-2,
        ],
        [
            7.370e3,
            3.730e3,
            2.100e3,
            8.640e2,
            1.050e3,
            9.900e2,
            6.640e2,
            3.430e2,
            1.980e2,
            7.240e1,
            7.940e1,
            4.550e1,
            2.200e1,
            1.250e1,
            7.860e0,
            3.800e0,
            2.190e0,
            2.820e0,
            1.420e0,
            5.680e-1,
            3.180e-1,
            2.140e-1,
            1.600e-1,
            1.080e-1,
            8.330e-2,
            6.670e-2,
            5.820e-2,
            5.060e-2,
            4.600e-2,
            4.530e-2,
            4.600e-2,
            4.710e-2,
            5.020e-2,
            5.340e-2,
            6.100e-2,
            6.700e-2,
        ],
        [
            7.540e3,
            3.830e3,
            2.150e3,
            8.890e2,
            1.040e3,
            1.020e3,
            6.790e2,
            3.510e2,
            2.030e2,
            7.410e1,
            8.140e1,
            4.650e1,
            2.260e1,
            1.280e1,
            8.070e0,
            3.910e0,
            2.250e0,
            2.870e0,
            1.440e0,
            5.790e-1,
            3.240e-1,
            2.180e-1,
            1.630e-1,
            1.090e-1,
            8.410e-2,
            6.710e-2,
            5.850e-2,
            5.080e-2,
            4.610e-2,
            4.530e-2,
            4.600e-2,
            4.710e-2,
            5.010e-2,
            5.340e-2,
            6.100e-2,
            6.700e-2,
        ],
        [
            7.840e3,
            3.950e3,
            2.250e3,
            9.290e2,
            4.840e2,
            1.060e3,
            6.680e2,
            3.640e2,
            2.100e2,
            7.710e1,
            8.390e1,
            4.830e1,
            2.350e1,
            1.340e1,
            8.420e0,
            4.080e0,
            2.350e0,
            2.970e0,
            1.500e0,
            6.000e-1,
            3.360e-1,
            2.250e-1,
            1.680e-1,
            1.130e-1,
            8.620e-2,
            6.870e-2,
            5.970e-2,
            5.180e-2,
            4.690e-2,
            4.610e-2,
            4.680e-2,
            4.790e-2,
            5.090e-2,
            5.420e-2,
            6.190e-2,
            6.810e-2,
        ],
        [
            7.890e3,
            4.060e3,
            2.310e3,
            9.540e2,
            4.970e2,
            9.270e2,
            6.850e2,
            3.720e2,
            2.150e2,
            7.890e1,
            8.580e1,
            4.920e1,
            2.400e1,
            1.370e1,
            8.640e0,
            4.190e0,
            2.410e0,
            3.030e0,
            1.520e0,
            6.110e-1,
            3.420e-1,
            2.290e-1,
            1.710e-1,
            1.140e-1,
            8.700e-2,
            6.910e-2,
            6.000e-2,
            5.200e-2,
            4.700e-2,
            4.620e-2,
            4.680e-2,
            4.790e-2,
            5.090e-2,
            5.420e-2,
            6.190e-2,
            6.810e-2,
        ],
        [
            7.790e3,
            4.220e3,
            2.400e3,
            9.920e2,
            5.170e2,
            9.590e2,
            7.110e2,
            3.830e2,
            2.220e2,
            8.160e1,
            4.010e1,
            5.080e1,
            2.490e1,
            1.420e1,
            8.970e0,
            4.360e0,
            2.510e0,
            3.120e0,
            1.570e0,
            6.310e-1,
            3.520e-1,
            2.360e-1,
            1.750e-1,
            1.170e-1,
            8.890e-2,
            7.040e-2,
            6.110e-2,
            5.280e-2,
            4.760e-2,
            4.670e-2,
            4.740e-2,
            4.840e-2,
            5.150e-2,
            5.480e-2,
            6.260e-2,
            6.890e-2,
        ],
        [
            7.130e3,
            4.320e3,
            2.460e3,
            1.010e3,
            5.290e2,
            9.770e2,
            7.250e2,
            3.890e2,
            2.260e2,
            8.310e1,
            4.090e1,
            5.170e1,
            2.540e1,
            1.450e1,
            9.160e0,
            4.450e0,
            2.570e0,
            3.140e0,
            1.590e0,
            6.400e-1,
            3.570e-1,
            2.390e-1,
            1.770e-1,
            1.180e-1,
            8.940e-2,
            7.070e-2,
            6.120e-2,
            5.280e-2,
            4.750e-2,
            4.660e-2,
            4.720e-2,
            4.820e-2,
            5.120e-2,
            5.450e-2,
            6.230e-2,
            6.860e-2,
        ],
    ]
)
# Hard-wire table of x-ray mass energy absorption coefficients (MEAC) in cm2/g for elements with Z = [1,92]
meac = np.array(
    [
        [
            6.820,
            1.752,
            6.643e-1,
            1.693e-1,
            6.549e-2,
            3.278e-2,
            1.996e-2,
            1.160e-2,
            9.849e-3,
            1.102e-2,
            1.355e-2,
            1.863e-2,
            2.315e-2,
            2.709e-2,
            3.053e-2,
            3.620e-2,
            4.063e-2,
            4.813e-2,
            5.254e-2,
            5.695e-2,
            5.860e-2,
            5.900e-2,
            5.875e-2,
            5.739e-2,
            5.556e-2,
            5.311e-2,
            5.075e-2,
            4.650e-2,
            3.992e-2,
            3.523e-2,
            3.174e-2,
            2.905e-2,
            2.515e-2,
            2.247e-2,
            1.837e-2,
            1.606e-2,
        ],
        [
            6.045e1,
            1.638e1,
            6.503,
            1.681,
            6.379e-1,
            3.061e-1,
            1.671e-1,
            6.446e-2,
            3.260e-2,
            1.246e-2,
            9.410e-3,
            1.003e-2,
            1.190e-2,
            1.375e-2,
            1.544e-2,
            1.826e-2,
            2.047e-2,
            2.424e-2,
            2.647e-2,
            2.868e-2,
            2.951e-2,
            2.971e-2,
            2.959e-2,
            2.890e-2,
            2.797e-2,
            2.674e-2,
            2.555e-2,
            2.343e-2,
            2.019e-2,
            1.790e-2,
            1.622e-2,
            1.493e-2,
            1.308e-2,
            1.183e-2,
            9.948e-3,
            8.914e-3,
        ],
        [
            2.335e2,
            6.629e1,
            2.672e1,
            7.249,
            2.840,
            1.364,
            7.477e-1,
            2.888e-1,
            1.387e-1,
            3.910e-2,
            1.885e-2,
            1.138e-2,
            1.131e-2,
            1.237e-2,
            1.361e-2,
            1.588e-2,
            1.776e-2,
            2.098e-2,
            2.290e-2,
            2.481e-2,
            2.552e-2,
            2.569e-2,
            2.559e-2,
            2.499e-2,
            2.419e-2,
            2.312e-2,
            2.210e-2,
            2.028e-2,
            1.753e-2,
            1.561e-2,
            1.422e-2,
            1.316e-2,
            1.167e-2,
            1.066e-2,
            9.182e-3,
            8.385e-3,
        ],
        [
            6.035e2,
            1.791e2,
            7.422e1,
            2.090e1,
            8.367,
            4.081,
            2.260,
            8.839e-1,
            4.255e-1,
            1.143e-1,
            4.780e-2,
            1.898e-2,
            1.438e-2,
            1.401e-2,
            1.468e-2,
            1.658e-2,
            1.836e-2,
            2.157e-2,
            2.353e-2,
            2.548e-2,
            2.620e-2,
            2.639e-2,
            2.627e-2,
            2.565e-2,
            2.483e-2,
            2.373e-2,
            2.268e-2,
            2.083e-2,
            1.806e-2,
            1.617e-2,
            1.479e-2,
            1.377e-2,
            1.233e-2,
            1.138e-2,
            1.001e-2,
            9.294e-3,
        ],
        [
            1.228e3,
            3.759e2,
            1.591e2,
            4.617e1,
            1.886e1,
            9.332,
            5.223,
            2.072,
            1.006,
            2.698e-1,
            1.084e-1,
            3.506e-2,
            2.084e-2,
            1.737e-2,
            1.680e-2,
            1.785e-2,
            1.940e-2,
            2.255e-2,
            2.453e-2,
            2.654e-2,
            2.731e-2,
            2.749e-2,
            2.737e-2,
            2.671e-2,
            2.586e-2,
            2.472e-2,
            2.362e-2,
            2.171e-2,
            1.889e-2,
            1.698e-2,
            1.562e-2,
            1.461e-2,
            1.322e-2,
            1.232e-2,
            1.104e-2,
            1.039e-2,
        ],
        [
            2.209e3,
            6.990e2,
            3.016e2,
            8.963e1,
            3.723e1,
            1.866e1,
            1.054e1,
            4.242,
            2.078,
            5.627e-1,
            2.238e-1,
            6.614e-2,
            3.343e-2,
            2.397e-2,
            2.098e-2,
            2.037e-2,
            2.147e-2,
            2.449e-2,
            2.655e-2,
            2.870e-2,
            2.950e-2,
            2.969e-2,
            2.956e-2,
            2.885e-2,
            2.792e-2,
            2.669e-2,
            2.551e-2,
            2.345e-2,
            2.048e-2,
            1.849e-2,
            1.710e-2,
            1.607e-2,
            1.468e-2,
            1.380e-2,
            1.258e-2,
            1.198e-2,
        ],
        [
            3.306e3,
            1.080e3,
            4.755e2,
            1.447e2,
            6.094e1,
            3.086e1,
            1.759e1,
            7.170,
            3.545,
            9.715e-1,
            3.867e-1,
            1.099e-1,
            5.051e-2,
            3.217e-2,
            2.548e-2,
            2.211e-2,
            2.231e-2,
            2.472e-2,
            2.665e-2,
            2.873e-2,
            2.952e-2,
            2.969e-2,
            2.956e-2,
            2.886e-2,
            2.792e-2,
            2.669e-2,
            2.550e-2,
            2.347e-2,
            2.057e-2,
            1.867e-2,
            1.734e-2,
            1.639e-2,
            1.512e-2,
            1.434e-2,
            1.332e-2,
            1.285e-2,
        ],
        [
            4.576e3,
            1.545e3,
            6.926e2,
            2.158e2,
            9.221e1,
            4.715e1,
            2.708e1,
            1.116e1,
            5.565,
            1.545,
            6.179e-1,
            1.729e-1,
            7.530e-2,
            4.414e-2,
            3.207e-2,
            2.468e-2,
            2.355e-2,
            2.506e-2,
            2.679e-2,
            2.877e-2,
            2.953e-2,
            2.971e-2,
            2.957e-2,
            2.887e-2,
            2.794e-2,
            2.669e-2,
            2.551e-2,
            2.350e-2,
            2.066e-2,
            1.882e-2,
            1.757e-2,
            1.668e-2,
            1.553e-2,
            1.483e-2,
            1.396e-2,
            1.360e-2,
        ],
        [
            5.615e3,
            1.969e3,
            9.005e2,
            2.870e2,
            1.244e2,
            6.424e1,
            3.716e1,
            1.548e1,
            7.776,
            2.186,
            8.796e-1,
            2.451e-1,
            1.036e-1,
            5.747e-2,
            3.903e-2,
            2.676e-2,
            2.394e-2,
            2.417e-2,
            2.554e-2,
            2.729e-2,
            2.800e-2,
            2.815e-2,
            2.801e-2,
            2.734e-2,
            2.645e-2,
            2.527e-2,
            2.416e-2,
            2.226e-2,
            1.964e-2,
            1.797e-2,
            1.685e-2,
            1.607e-2,
            1.508e-2,
            1.451e-2,
            1.382e-2,
            1.357e-2,
        ],
        [
            7.326e3,
            2.645e3,
            1.234e3,
            4.021e2,
            1.767e2,
            9.214e1,
            5.369e1,
            2.260e1,
            1.143e1,
            3.253,
            1.317,
            3.676e-1,
            1.528e-1,
            8.182e-2,
            5.287e-2,
            3.273e-2,
            2.733e-2,
            2.590e-2,
            2.697e-2,
            2.862e-2,
            2.931e-2,
            2.946e-2,
            2.930e-2,
            2.860e-2,
            2.766e-2,
            2.641e-2,
            2.526e-2,
            2.330e-2,
            2.061e-2,
            1.894e-2,
            1.784e-2,
            1.709e-2,
            1.616e-2,
            1.564e-2,
            1.508e-2,
            1.491e-2,
        ],
        [
            6.522e2,
            3.151e3,
            1.504e3,
            5.023e2,
            2.238e2,
            1.178e2,
            6.915e1,
            2.941e1,
            1.499e1,
            4.313,
            1.759,
            4.928e-1,
            2.031e-1,
            1.063e-1,
            6.625e-2,
            3.761e-2,
            2.931e-2,
            2.579e-2,
            2.635e-2,
            2.771e-2,
            2.833e-2,
            2.845e-2,
            2.830e-2,
            2.760e-2,
            2.669e-2,
            2.549e-2,
            2.437e-2,
            2.249e-2,
            1.997e-2,
            1.842e-2,
            1.743e-2,
            1.675e-2,
            1.595e-2,
            1.552e-2,
            1.508e-2,
            1.496e-2,
        ],
        [
            9.203e2,
            3.918e3,
            1.899e3,
            6.499e2,
            2.937e2,
            1.561e2,
            9.227e1,
            3.965e1,
            2.036e1,
            5.925,
            2.432,
            6.855e-1,
            2.815e-1,
            1.451e-1,
            8.820e-2,
            4.671e-2,
            3.410e-2,
            2.766e-2,
            2.761e-2,
            2.871e-2,
            2.928e-2,
            2.938e-2,
            2.921e-2,
            2.848e-2,
            2.753e-2,
            2.629e-2,
            2.514e-2,
            2.322e-2,
            2.067e-2,
            1.915e-2,
            1.819e-2,
            1.756e-2,
            1.683e-2,
            1.646e-2,
            1.614e-2,
            1.609e-2,
        ],
        [
            1.183e3,
            4.001e2,
            2.204e3,
            7.732e2,
            3.545e2,
            1.902e2,
            1.133e2,
            4.918e1,
            2.543e1,
            7.487,
            3.094,
            8.778e-1,
            3.601e-1,
            1.840e-1,
            1.099e-1,
            5.511e-2,
            3.794e-2,
            2.827e-2,
            2.745e-2,
            2.816e-2,
            2.862e-2,
            2.868e-2,
            2.851e-2,
            2.778e-2,
            2.686e-2,
            2.565e-2,
            2.451e-2,
            2.266e-2,
            2.024e-2,
            1.882e-2,
            1.795e-2,
            1.739e-2,
            1.678e-2,
            1.650e-2,
            1.631e-2,
            1.633e-2,
        ],
        [
            1.567e3,
            5.331e2,
            2.669e3,
            9.516e2,
            4.427e2,
            2.400e2,
            1.439e2,
            6.313e1,
            3.289e1,
            9.794,
            4.076,
            1.164,
            4.782e-1,
            2.430e-1,
            1.434e-1,
            6.896e-2,
            4.513e-2,
            3.086e-2,
            2.905e-2,
            2.932e-2,
            2.968e-2,
            2.971e-2,
            2.951e-2,
            2.875e-2,
            2.778e-2,
            2.652e-2,
            2.535e-2,
            2.345e-2,
            2.101e-2,
            1.963e-2,
            1.878e-2,
            1.827e-2,
            1.773e-2,
            1.753e-2,
            1.746e-2,
            1.757e-2,
        ],
        [
            1.910e3,
            6.522e2,
            2.996e2,
            1.074e3,
            5.079e2,
            2.782e2,
            1.682e2,
            7.457e1,
            3.912e1,
            1.179e1,
            4.939,
            1.422,
            5.850e-1,
            2.965e-1,
            1.735e-1,
            8.083e-2,
            5.068e-2,
            3.188e-2,
            2.899e-2,
            2.870e-2,
            2.892e-2,
            2.891e-2,
            2.869e-2,
            2.793e-2,
            2.698e-2,
            2.575e-2,
            2.462e-2,
            2.279e-2,
            2.049e-2,
            1.921e-2,
            1.846e-2,
            1.801e-2,
            1.760e-2,
            1.747e-2,
            1.754e-2,
            1.771e-2,
        ],
        [
            2.426e3,
            8.314e2,
            3.828e2,
            1.265e3,
            6.066e2,
            3.360e2,
            2.046e2,
            9.171e1,
            4.847e1,
            1.477e1,
            6.235,
            1.809,
            7.466e-1,
            3.779e-1,
            2.199e-1,
            1.000e-1,
            6.052e-2,
            3.516e-2,
            3.080e-2,
            2.983e-2,
            2.991e-2,
            2.984e-2,
            2.959e-2,
            2.878e-2,
            2.780e-2,
            2.652e-2,
            2.535e-2,
            2.349e-2,
            2.118e-2,
            1.993e-2,
            1.923e-2,
            1.884e-2,
            1.850e-2,
            1.845e-2,
            1.864e-2,
            1.889e-2,
        ],
        [
            2.829e3,
            9.742e2,
            4.494e2,
            1.361e3,
            6.626e2,
            3.711e2,
            2.282e2,
            1.034e2,
            5.510e1,
            1.700e1,
            7.227,
            2.114,
            8.756e-1,
            4.433e-1,
            2.570e-1,
            1.148e-1,
            6.745e-2,
            3.639e-2,
            3.067e-2,
            2.898e-2,
            2.887e-2,
            2.874e-2,
            2.847e-2,
            2.767e-2,
            2.671e-2,
            2.549e-2,
            2.436e-2,
            2.258e-2,
            2.043e-2,
            1.931e-2,
            1.871e-2,
            1.839e-2,
            1.819e-2,
            1.824e-2,
            1.861e-2,
            1.899e-2,
        ],
        [
            3.180e3,
            1.102e3,
            5.093e2,
            1.682e2,
            6.979e2,
            3.953e2,
            2.449e2,
            1.125e2,
            6.038e1,
            1.886e1,
            8.074,
            2.382,
            9.907e-1,
            5.020e-1,
            2.904e-1,
            1.280e-1,
            7.344e-2,
            3.703e-2,
            2.998e-2,
            2.757e-2,
            2.727e-2,
            2.708e-2,
            2.679e-2,
            2.601e-2,
            2.510e-2,
            2.394e-2,
            2.288e-2,
            2.123e-2,
            1.927e-2,
            1.827e-2,
            1.777e-2,
            1.753e-2,
            1.742e-2,
            1.754e-2,
            1.800e-2,
            1.842e-2,
        ],
        [
            4.053e3,
            1.415e3,
            6.563e2,
            2.174e2,
            8.304e2,
            4.752e2,
            2.974e2,
            1.383e2,
            7.490e1,
            2.370e1,
            1.023e1,
            3.045,
            1.272,
            6.454e-1,
            3.730e-1,
            1.628e-1,
            9.161e-2,
            4.346e-2,
            3.378e-2,
            3.015e-2,
            2.959e-2,
            2.929e-2,
            2.895e-2,
            2.807e-2,
            2.707e-2,
            2.581e-2,
            2.467e-2,
            2.290e-2,
            2.084e-2,
            1.985e-2,
            1.935e-2,
            1.914e-2,
            1.910e-2,
            1.928e-2,
            1.983e-2,
            2.029e-2,
        ],
        [
            4.861e3,
            1.710e3,
            7.966e2,
            2.650e2,
            1.197e2,
            5.373e2,
            3.387e2,
            1.600e2,
            8.744e1,
            2.804e1,
            1.220e1,
            3.665,
            1.538,
            7.822e-1,
            4.520e-1,
            1.958e-1,
            1.085e-1,
            4.876e-2,
            3.639e-2,
            3.146e-2,
            3.060e-2,
            3.019e-2,
            2.979e-2,
            2.884e-2,
            2.780e-2,
            2.650e-2,
            2.532e-2,
            2.352e-2,
            2.147e-2,
            2.052e-2,
            2.007e-2,
            1.992e-2,
            1.997e-2,
            2.022e-2,
            2.088e-2,
            2.140e-2,
        ],
        [
            5.231e3,
            1.853e3,
            8.672e2,
            2.896e2,
            1.311e2,
            5.436e2,
            3.474e2,
            1.661e2,
            9.175e1,
            2.988e1,
            1.311e1,
            3.975,
            1.677,
            8.552e-1,
            4.944e-1,
            2.132e-1,
            1.167e-1,
            4.998e-2,
            3.586e-2,
            2.997e-2,
            2.887e-2,
            2.837e-2,
            2.795e-2,
            2.703e-2,
            2.603e-2,
            2.480e-2,
            2.370e-2,
            2.202e-2,
            2.016e-2,
            1.933e-2,
            1.897e-2,
            1.887e-2,
            1.900e-2,
            1.929e-2,
            2.000e-2,
            2.052e-2,
        ],
        [
            5.860e3,
            2.091e3,
            9.824e2,
            3.295e2,
            1.494e2,
            5.657e2,
            3.691e2,
            1.793e2,
            1.001e2,
            3.311e1,
            1.465e1,
            4.488,
            1.904,
            9.737e-1,
            5.634e-1,
            2.422e-1,
            1.312e-1,
            5.393e-2,
            3.726e-2,
            3.007e-2,
            2.864e-2,
            2.804e-2,
            2.756e-2,
            2.661e-2,
            2.561e-2,
            2.439e-2,
            2.330e-2,
            2.166e-2,
            1.989e-2,
            1.913e-2,
            1.884e-2,
            1.879e-2,
            1.899e-2,
            1.933e-2,
            2.013e-2,
            2.067e-2,
        ],
        [
            6.483e3,
            2.336e3,
            1.102e3,
            3.713e2,
            1.688e2,
            9.089e1,
            3.841e2,
            1.908e2,
            1.077e2,
            3.627e1,
            1.620e1,
            5.015,
            2.140,
            1.098,
            6.364e-1,
            2.731e-1,
            1.469e-1,
            5.821e-2,
            3.879e-2,
            3.019e-2,
            2.843e-2,
            2.770e-2,
            2.717e-2,
            2.618e-2,
            2.518e-2,
            2.396e-2,
            2.289e-2,
            2.130e-2,
            1.961e-2,
            1.892e-2,
            1.869e-2,
            1.869e-2,
            1.896e-2,
            1.937e-2,
            2.022e-2,
            2.079e-2,
        ],
        [
            7.388e3,
            2.687e3,
            1.272e3,
            4.305e2,
            1.961e2,
            1.057e2,
            4.027e2,
            2.087e2,
            1.193e2,
            4.093e1,
            1.846e1,
            5.780,
            2.482,
            1.278,
            7.420e-1,
            3.182e-1,
            1.701e-1,
            6.536e-2,
            4.211e-2,
            3.160e-2,
            2.938e-2,
            2.849e-2,
            2.788e-2,
            2.680e-2,
            2.576e-2,
            2.450e-2,
            2.340e-2,
            2.178e-2,
            2.011e-2,
            1.947e-2,
            1.929e-2,
            1.933e-2,
            1.970e-2,
            2.016e-2,
            2.112e-2,
            2.174e-2,
        ],
        [
            8.069e3,
            2.975e3,
            1.415e3,
            4.815e2,
            2.201e2,
            1.188e2,
            7.150e1,
            2.177e2,
            1.262e2,
            4.414e1,
            2.015e1,
            6.382,
            2.757,
            1.425,
            8.294e-1,
            3.558e-1,
            1.894e-1,
            7.085e-2,
            4.421e-2,
            3.196e-2,
            2.932e-2,
            2.827e-2,
            2.760e-2,
            2.647e-2,
            2.541e-2,
            2.416e-2,
            2.307e-2,
            2.149e-2,
            1.989e-2,
            1.933e-2,
            1.920e-2,
            1.930e-2,
            1.973e-2,
            2.025e-2,
            2.127e-2,
            2.193e-2,
        ],
        [
            9.052e3,
            3.388e3,
            1.620e3,
            5.535e2,
            2.536e2,
            1.372e2,
            8.265e1,
            2.316e2,
            1.369e2,
            4.896e1,
            2.260e1,
            7.251,
            3.155,
            1.638,
            9.555e-1,
            4.104e-1,
            2.177e-1,
            7.961e-2,
            4.825e-2,
            3.361e-2,
            3.039e-2,
            2.914e-2,
            2.836e-2,
            2.714e-2,
            2.603e-2,
            2.472e-2,
            2.360e-2,
            2.199e-2,
            2.042e-2,
            1.990e-2,
            1.983e-2,
            1.997e-2,
            2.050e-2,
            2.108e-2,
            2.221e-2,
            2.292e-2,
        ],
        [
            9.750e3,
            3.682e3,
            1.771e3,
            6.084e2,
            2.796e2,
            1.515e2,
            9.138e1,
            2.322e2,
            1.413e2,
            5.178e1,
            2.421e1,
            7.873,
            3.450,
            1.799,
            1.052,
            4.528e-1,
            2.397e-1,
            8.597e-2,
            5.071e-2,
            3.406e-2,
            3.034e-2,
            2.890e-2,
            2.805e-2,
            2.677e-2,
            2.564e-2,
            2.434e-2,
            2.323e-2,
            2.165e-2,
            2.016e-2,
            1.971e-2,
            1.969e-2,
            1.988e-2,
            2.048e-2,
            2.110e-2,
            2.230e-2,
            2.303e-2,
        ],
        [
            9.797e3,
            4.214e3,
            2.039e3,
            7.042e2,
            3.244e2,
            1.761e2,
            1.064e2,
            4.758e1,
            1.524e2,
            5.734e1,
            2.722e1,
            8.982,
            3.967,
            2.078,
            1.219,
            5.259e-1,
            2.781e-1,
            9.812e-2,
            5.649e-2,
            3.659e-2,
            3.209e-2,
            3.036e-2,
            2.937e-2,
            2.795e-2,
            2.674e-2,
            2.536e-2,
            2.420e-2,
            2.257e-2,
            2.107e-2,
            2.066e-2,
            2.070e-2,
            2.094e-2,
            2.163e-2,
            2.234e-2,
            2.368e-2,
            2.446e-2,
        ],
        [
            1.049e4,
            4.393e3,
            2.142e3,
            7.430e2,
            3.432e2,
            1.866e2,
            1.128e2,
            5.054e1,
            1.484e2,
            5.788e1,
            2.788e1,
            9.349,
            4.163,
            2.192,
            1.290,
            5.581e-1,
            2.949e-1,
            1.027e-1,
            5.781e-2,
            3.617e-2,
            3.121e-2,
            2.933e-2,
            2.826e-2,
            2.681e-2,
            2.562e-2,
            2.428e-2,
            2.316e-2,
            2.160e-2,
            2.023e-2,
            1.989e-2,
            1.998e-2,
            2.027e-2,
            2.100e-2,
            2.174e-2,
            2.309e-2,
            2.387e-2,
        ],
        [
            1.548e3,
            4.791e3,
            2.359e3,
            8.244e2,
            3.820e2,
            2.082e2,
            1.261e2,
            5.660e1,
            1.497e2,
            6.099e1,
            2.986e1,
            1.018e1,
            4.570,
            2.419,
            1.429,
            6.203e-1,
            3.278e-1,
            1.128e-1,
            6.225e-2,
            3.764e-2,
            3.195e-2,
            2.979e-2,
            2.861e-2,
            2.704e-2,
            2.580e-2,
            2.443e-2,
            2.329e-2,
            2.174e-2,
            2.041e-2,
            2.014e-2,
            2.028e-2,
            2.061e-2,
            2.143e-2,
            2.223e-2,
            2.367e-2,
            2.451e-2,
        ],
        [
            1.692e3,
            5.044e3,
            2.496e3,
            8.782e2,
            4.082e2,
            2.229e2,
            1.352e2,
            6.082e1,
            3.250e1,
            6.135e1,
            3.059e1,
            1.061e1,
            4.810,
            2.560,
            1.518,
            6.613e-1,
            3.497e-1,
            1.193e-1,
            6.463e-2,
            3.782e-2,
            3.156e-2,
            2.920e-2,
            2.793e-2,
            2.631e-2,
            2.506e-2,
            2.371e-2,
            2.260e-2,
            2.110e-2,
            1.986e-2,
            1.966e-2,
            1.985e-2,
            2.021e-2,
            2.108e-2,
            2.191e-2,
            2.339e-2,
            2.425e-2,
        ],
        [
            1.887e3,
            5.420e3,
            2.688e3,
            9.527e2,
            4.445e2,
            2.433e2,
            1.477e2,
            6.660e1,
            3.564e1,
            6.256e1,
            3.178e1,
            1.126e1,
            5.152,
            2.759,
            1.642,
            7.184e-1,
            3.803e-1,
            1.288e-1,
            6.865e-2,
            3.891e-2,
            3.193e-2,
            2.930e-2,
            2.790e-2,
            2.618e-2,
            2.489e-2,
            2.353e-2,
            2.242e-2,
            2.094e-2,
            1.977e-2,
            1.962e-2,
            1.987e-2,
            2.027e-2,
            2.120e-2,
            2.208e-2,
            2.364e-2,
            2.452e-2,
        ],
        [
            2.116e3,
            5.164e3,
            2.902e3,
            1.039e3,
            4.862e2,
            2.667e2,
            1.622e2,
            7.330e1,
            3.928e1,
            6.371e1,
            3.310e1,
            1.198e1,
            5.537,
            2.983,
            1.783,
            7.837e-1,
            4.155e-1,
            1.399e-1,
            7.350e-2,
            4.043e-2,
            3.261e-2,
            2.966e-2,
            2.813e-2,
            2.628e-2,
            2.494e-2,
            2.355e-2,
            2.243e-2,
            2.096e-2,
            1.984e-2,
            1.974e-2,
            2.005e-2,
            2.049e-2,
            2.148e-2,
            2.241e-2,
            2.404e-2,
            2.495e-2,
        ],
        [
            2.312e3,
            5.260e3,
            3.062e3,
            1.104e3,
            5.187e2,
            2.851e2,
            1.737e2,
            7.865e1,
            4.221e1,
            6.270e1,
            3.352e1,
            1.240e1,
            5.796,
            3.143,
            1.886,
            8.332e-1,
            4.426e-1,
            1.483e-1,
            7.695e-2,
            4.113e-2,
            3.261e-2,
            2.941e-2,
            2.775e-2,
            2.581e-2,
            2.446e-2,
            2.306e-2,
            2.195e-2,
            2.052e-2,
            1.947e-2,
            1.944e-2,
            1.978e-2,
            2.025e-2,
            2.130e-2,
            2.226e-2,
            2.394e-2,
            2.487e-2,
        ],
        [
            2.618e3,
            9.964e2,
            3.360e3,
            1.216e3,
            5.740e2,
            3.163e2,
            1.930e2,
            8.756e1,
            4.706e1,
            6.336e1,
            3.502e1,
            1.328e1,
            6.267,
            3.431,
            2.068,
            9.185e-1,
            4.890e-1,
            1.634e-1,
            8.378e-2,
            4.360e-2,
            3.398e-2,
            3.036e-2,
            2.851e-2,
            2.640e-2,
            2.496e-2,
            2.350e-2,
            2.237e-2,
            2.092e-2,
            1.991e-2,
            1.995e-2,
            2.036e-2,
            2.090e-2,
            2.207e-2,
            2.314e-2,
            2.507e-2,
            2.618e-2,
        ],
        [
            2.848e3,
            1.087e3,
            3.541e3,
            1.288e3,
            6.101e2,
            3.371e2,
            2.060e2,
            9.371e1,
            5.044e1,
            6.112e1,
            3.509e1,
            1.365e1,
            6.538,
            3.596,
            2.178,
            9.729e-1,
            5.192e-1,
            1.731e-1,
            8.787e-2,
            4.459e-2,
            3.414e-2,
            3.023e-2,
            2.825e-2,
            2.603e-2,
            2.456e-2,
            2.310e-2,
            2.197e-2,
            2.055e-2,
            1.961e-2,
            1.969e-2,
            2.014e-2,
            2.071e-2,
            2.192e-2,
            2.302e-2,
            2.497e-2,
            2.610e-2,
        ],
        [
            3.168e3,
            1.213e3,
            3.347e3,
            1.397e3,
            6.648e2,
            3.682e2,
            2.255e2,
            1.028e2,
            5.541e1,
            1.775e1,
            3.581e1,
            1.436e1,
            6.963,
            3.858,
            2.349,
            1.056,
            5.649e-1,
            1.881e-1,
            9.465e-2,
            4.690e-2,
            3.531e-2,
            3.098e-2,
            2.878e-2,
            2.638e-2,
            2.484e-2,
            2.332e-2,
            2.217e-2,
            2.074e-2,
            1.983e-2,
            1.996e-2,
            2.045e-2,
            2.105e-2,
            2.231e-2,
            2.343e-2,
            2.538e-2,
            2.645e-2,
        ],
        [
            3.487e3,
            1.341e3,
            2.539e3,
            1.500e3,
            7.181e2,
            3.988e2,
            2.446e2,
            1.118e2,
            6.037e1,
            1.938e1,
            3.602e1,
            1.493e1,
            7.346,
            4.103,
            2.511,
            1.135,
            6.093e-1,
            2.028e-1,
            1.013e-1,
            4.906e-2,
            3.634e-2,
            3.156e-2,
            2.917e-2,
            2.660e-2,
            2.498e-2,
            2.342e-2,
            2.225e-2,
            2.082e-2,
            1.995e-2,
            2.013e-2,
            2.066e-2,
            2.130e-2,
            2.260e-2,
            2.377e-2,
            2.578e-2,
            2.684e-2,
        ],
        [
            3.857e3,
            1.487e3,
            7.365e2,
            1.623e3,
            7.798e2,
            4.344e2,
            2.670e2,
            1.224e2,
            6.619e1,
            2.130e1,
            3.620e1,
            1.558e1,
            7.790,
            4.388,
            2.699,
            1.228,
            6.616e-1,
            2.203e-1,
            1.093e-1,
            5.186e-2,
            3.779e-2,
            3.249e-2,
            2.986e-2,
            2.708e-2,
            2.537e-2,
            2.375e-2,
            2.254e-2,
            2.109e-2,
            2.026e-2,
            2.048e-2,
            2.107e-2,
            2.174e-2,
            2.311e-2,
            2.432e-2,
            2.638e-2,
            2.746e-2,
        ],
        [
            4.203e3,
            1.625e3,
            8.057e2,
            1.734e3,
            8.344e2,
            4.664e2,
            2.873e2,
            1.320e2,
            7.150e1,
            2.308e1,
            3.555e1,
            1.600e1,
            8.129,
            4.621,
            2.859,
            1.310,
            7.080e-1,
            2.361e-1,
            1.164e-1,
            5.420e-2,
            3.885e-2,
            3.311e-2,
            3.025e-2,
            2.726e-2,
            2.547e-2,
            2.380e-2,
            2.257e-2,
            2.112e-2,
            2.033e-2,
            2.061e-2,
            2.123e-2,
            2.193e-2,
            2.335e-2,
            2.460e-2,
            2.670e-2,
            2.778e-2,
        ],
        [
            4.592e3,
            1.780e3,
            8.832e2,
            1.859e3,
            8.970e2,
            5.027e2,
            3.103e2,
            1.429e2,
            7.754e1,
            2.508e1,
            3.493e1,
            1.648e1,
            8.511,
            4.884,
            3.040,
            1.403,
            7.608e-1,
            2.542e-1,
            1.247e-1,
            5.705e-2,
            4.026e-2,
            3.396e-2,
            3.085e-2,
            2.764e-2,
            2.575e-2,
            2.402e-2,
            2.276e-2,
            2.130e-2,
            2.054e-2,
            2.086e-2,
            2.153e-2,
            2.227e-2,
            2.375e-2,
            2.503e-2,
            2.718e-2,
            2.828e-2,
        ],
        [
            4.935e3,
            1.918e3,
            9.531e2,
            1.956e3,
            9.475e2,
            5.328e2,
            3.295e2,
            1.522e2,
            8.275e1,
            2.684e1,
            3.293e1,
            1.664e1,
            8.757,
            5.074,
            3.178,
            1.477,
            8.042e-1,
            2.693e-1,
            1.316e-1,
            5.919e-2,
            4.117e-2,
            3.437e-2,
            3.104e-2,
            2.764e-2,
            2.567e-2,
            2.390e-2,
            2.263e-2,
            2.118e-2,
            2.046e-2,
            2.084e-2,
            2.153e-2,
            2.231e-2,
            2.382e-2,
            2.513e-2,
            2.731e-2,
            2.840e-2,
        ],
        [
            5.348e3,
            2.085e3,
            1.037e3,
            1.805e3,
            1.009e3,
            5.694e2,
            3.530e2,
            1.635e2,
            8.908e1,
            2.898e1,
            1.290e1,
            1.693e1,
            9.075,
            5.312,
            3.348,
            1.568,
            8.572e-1,
            2.880e-1,
            1.403e-1,
            6.214e-2,
            4.257e-2,
            3.521e-2,
            3.159e-2,
            2.797e-2,
            2.589e-2,
            2.406e-2,
            2.276e-2,
            2.129e-2,
            2.061e-2,
            2.103e-2,
            2.178e-2,
            2.258e-2,
            2.415e-2,
            2.549e-2,
            2.774e-2,
            2.884e-2,
        ],
        [
            5.709e3,
            2.233e3,
            1.113e3,
            1.894e3,
            1.063e3,
            6.000e2,
            3.731e2,
            1.733e2,
            9.456e1,
            3.085e1,
            1.376e1,
            1.689e1,
            9.251,
            5.477,
            3.476,
            1.641,
            9.012e-1,
            3.037e-1,
            1.475e-1,
            6.445e-2,
            4.355e-2,
            3.567e-2,
            3.182e-2,
            2.796e-2,
            2.581e-2,
            2.393e-2,
            2.262e-2,
            2.115e-2,
            2.052e-2,
            2.098e-2,
            2.176e-2,
            2.259e-2,
            2.419e-2,
            2.556e-2,
            2.783e-2,
            2.893e-2,
        ],
        [
            6.160e3,
            2.419e3,
            1.207e3,
            4.382e2,
            1.132e3,
            6.396e2,
            3.985e2,
            1.857e2,
            1.015e2,
            3.322e1,
            1.484e1,
            1.699e1,
            9.520,
            5.706,
            3.649,
            1.737,
            9.581e-1,
            3.241e-1,
            1.571e-1,
            6.776e-2,
            4.517e-2,
            3.663e-2,
            3.247e-2,
            2.834e-2,
            2.608e-2,
            2.413e-2,
            2.278e-2,
            2.131e-2,
            2.071e-2,
            2.122e-2,
            2.204e-2,
            2.290e-2,
            2.456e-2,
            2.597e-2,
            2.831e-2,
            2.943e-2,
        ],
        [
            6.529e3,
            2.571e3,
            1.285e3,
            4.668e2,
            1.182e3,
            6.688e2,
            4.175e2,
            1.953e2,
            1.070e2,
            3.511e1,
            1.571e1,
            1.669e1,
            9.611,
            5.833,
            3.759,
            1.804,
            1.000,
            3.397e-1,
            1.644e-1,
            7.007e-2,
            4.611e-2,
            3.704e-2,
            3.262e-2,
            2.828e-2,
            2.594e-2,
            2.395e-2,
            2.259e-2,
            2.112e-2,
            2.056e-2,
            2.111e-2,
            2.196e-2,
            2.284e-2,
            2.453e-2,
            2.595e-2,
            2.832e-2,
            2.944e-2,
        ],
        [
            7.029e3,
            2.782e3,
            1.393e3,
            5.073e2,
            1.252e3,
            7.122e2,
            4.457e2,
            2.092e2,
            1.149e2,
            3.780e1,
            1.695e1,
            1.660e1,
            9.869,
            6.066,
            3.938,
            1.907,
            1.062,
            3.622e-1,
            1.751e-1,
            7.392e-2,
            4.803e-2,
            3.822e-2,
            3.347e-2,
            2.881e-2,
            2.632e-2,
            2.425e-2,
            2.284e-2,
            2.135e-2,
            2.082e-2,
            2.142e-2,
            2.232e-2,
            2.324e-2,
            2.499e-2,
            2.647e-2,
            2.889e-2,
            3.005e-2,
        ],
        [
            7.340e3,
            2.922e3,
            1.466e3,
            5.350e2,
            1.118e3,
            7.383e2,
            4.619e2,
            2.174e2,
            1.197e2,
            3.952e1,
            1.776e1,
            1.594e1,
            9.812,
            6.115,
            4.001,
            1.957,
            1.096,
            3.753e-1,
            1.813e-1,
            7.580e-2,
            4.868e-2,
            3.838e-2,
            3.339e-2,
            2.854e-2,
            2.597e-2,
            2.387e-2,
            2.247e-2,
            2.099e-2,
            2.051e-2,
            2.114e-2,
            2.206e-2,
            2.300e-2,
            2.477e-2,
            2.625e-2,
            2.869e-2,
            2.985e-2,
        ],
        [
            7.797e3,
            3.122e3,
            1.570e3,
            5.743e2,
            1.170e3,
            7.780e2,
            4.871e2,
            2.301e2,
            1.269e2,
            4.206e1,
            1.893e1,
            1.553e1,
            9.911,
            6.262,
            4.135,
            2.043,
            1.150,
            3.960e-1,
            1.913e-1,
            7.923e-2,
            5.031e-2,
            3.932e-2,
            3.398e-2,
            2.883e-2,
            2.615e-2,
            2.398e-2,
            2.254e-2,
            2.105e-2,
            2.060e-2,
            2.127e-2,
            2.223e-2,
            2.321e-2,
            2.502e-2,
            2.653e-2,
            2.903e-2,
            3.020e-2,
        ],
        [
            8.144e3,
            3.287e3,
            1.657e3,
            6.077e2,
            8.945e2,
            8.064e2,
            5.065e2,
            2.400e2,
            1.327e2,
            4.413e1,
            1.990e1,
            1.490e1,
            9.835,
            6.314,
            4.211,
            2.101,
            1.189,
            4.119e-1,
            1.990e-1,
            8.179e-2,
            5.138e-2,
            3.980e-2,
            3.417e-2,
            2.878e-2,
            2.601e-2,
            2.379e-2,
            2.233e-2,
            2.085e-2,
            2.044e-2,
            2.115e-2,
            2.213e-2,
            2.312e-2,
            2.496e-2,
            2.649e-2,
            2.901e-2,
            3.018e-2,
        ],
        [
            8.568e3,
            3.481e3,
            1.759e3,
            6.469e2,
            3.113e2,
            8.377e2,
            5.305e2,
            2.518e2,
            1.396e2,
            4.657e1,
            2.105e1,
            6.755,
            9.789,
            6.400,
            4.311,
            2.173,
            1.237,
            4.312e-1,
            2.084e-1,
            8.504e-2,
            5.288e-2,
            4.061e-2,
            3.465e-2,
            2.896e-2,
            2.608e-2,
            2.378e-2,
            2.230e-2,
            2.081e-2,
            2.043e-2,
            2.118e-2,
            2.219e-2,
            2.321e-2,
            2.509e-2,
            2.664e-2,
            2.920e-2,
            3.038e-2,
        ],
        [
            8.419e3,
            3.598e3,
            1.824e3,
            6.726e2,
            3.240e2,
            8.487e2,
            5.423e2,
            2.578e2,
            1.433e2,
            4.802e1,
            2.175e1,
            6.997,
            9.480,
            6.330,
            4.306,
            2.195,
            1.256,
            4.409e-1,
            2.132e-1,
            8.646e-2,
            5.326e-2,
            4.055e-2,
            3.440e-2,
            2.854e-2,
            2.559e-2,
            2.327e-2,
            2.179e-2,
            2.033e-2,
            1.998e-2,
            2.075e-2,
            2.177e-2,
            2.279e-2,
            2.466e-2,
            2.620e-2,
            2.873e-2,
            2.989e-2,
        ],
        [
            9.078e3,
            3.908e3,
            1.988e3,
            7.351e2,
            3.548e2,
            7.903e2,
            5.822e2,
            2.777e2,
            1.548e2,
            5.208e1,
            2.363e1,
            7.622,
            9.616,
            6.573,
            4.518,
            2.331,
            1.342,
            4.742e-1,
            2.295e-1,
            9.257e-2,
            5.650e-2,
            4.267e-2,
            3.598e-2,
            2.962e-2,
            2.646e-2,
            2.399e-2,
            2.243e-2,
            2.092e-2,
            2.059e-2,
            2.142e-2,
            2.250e-2,
            2.357e-2,
            2.553e-2,
            2.714e-2,
            2.980e-2,
            3.101e-2,
        ],
        [
            9.393e3,
            4.073e3,
            2.078e3,
            7.709e2,
            3.728e2,
            6.015e2,
            5.979e2,
            2.871e2,
            1.605e2,
            5.420e1,
            2.465e1,
            7.969,
            9.323,
            6.540,
            4.541,
            2.374,
            1.376,
            4.894e-1,
            2.373e-1,
            9.522e-2,
            5.761e-2,
            4.317e-2,
            3.617e-2,
            2.956e-2,
            2.630e-2,
            2.378e-2,
            2.221e-2,
            2.070e-2,
            2.042e-2,
            2.128e-2,
            2.240e-2,
            2.350e-2,
            2.553e-2,
            2.720e-2,
            3.002e-2,
            3.139e-2,
        ],
        [
            9.343e3,
            4.322e3,
            2.216e3,
            8.246e2,
            3.994e2,
            2.251e2,
            6.253e2,
            3.029e2,
            1.697e2,
            5.753e1,
            2.623e1,
            8.502,
            9.185,
            6.618,
            4.653,
            2.464,
            1.438,
            5.154e-1,
            2.502e-1,
            1.000e-1,
            6.003e-2,
            4.463e-2,
            3.717e-2,
            3.014e-2,
            2.671e-2,
            2.408e-2,
            2.246e-2,
            2.091e-2,
            2.064e-2,
            2.153e-2,
            2.268e-2,
            2.380e-2,
            2.583e-2,
            2.750e-2,
            3.026e-2,
            3.152e-2,
        ],
        [
            8.521e3,
            4.485e3,
            2.308e3,
            8.622e2,
            4.184e2,
            2.361e2,
            6.383e2,
            3.127e2,
            1.754e2,
            5.972e1,
            2.730e1,
            8.875,
            8.842,
            6.534,
            4.660,
            2.501,
            1.470,
            5.309e-1,
            2.583e-1,
            1.028e-1,
            6.125e-2,
            4.521e-2,
            3.743e-2,
            3.011e-2,
            2.657e-2,
            2.388e-2,
            2.224e-2,
            2.069e-2,
            2.044e-2,
            2.135e-2,
            2.250e-2,
            2.363e-2,
            2.566e-2,
            2.731e-2,
            3.003e-2,
            3.126e-2,
        ],
        [
            9.061e3,
            4.755e3,
            2.453e3,
            9.190e2,
            4.468e2,
            2.524e2,
            5.819e2,
            3.290e2,
            1.847e2,
            6.321e1,
            2.897e1,
            9.444,
            8.608,
            6.560,
            4.756,
            2.587,
            1.532,
            5.576e-1,
            2.718e-1,
            1.079e-1,
            6.382e-2,
            4.677e-2,
            3.849e-2,
            3.073e-2,
            2.700e-2,
            2.418e-2,
            2.249e-2,
            2.090e-2,
            2.068e-2,
            2.161e-2,
            2.280e-2,
            2.395e-2,
            2.602e-2,
            2.769e-2,
            3.043e-2,
            3.163e-2,
        ],
        [
            9.679e3,
            5.015e3,
            2.595e3,
            9.776e2,
            4.745e2,
            2.684e2,
            4.550e2,
            3.458e2,
            1.945e2,
            6.690e1,
            3.073e1,
            1.005e1,
            4.496,
            6.569,
            4.847,
            2.677,
            1.597,
            5.862e-1,
            2.865e-1,
            1.134e-1,
            6.664e-2,
            4.851e-2,
            3.970e-2,
            3.145e-2,
            2.750e-2,
            2.456e-2,
            2.281e-2,
            2.118e-2,
            2.096e-2,
            2.194e-2,
            2.316e-2,
            2.434e-2,
            2.645e-2,
            2.816e-2,
            3.094e-2,
            3.216e-2,
        ],
        [
            1.054e4,
            5.069e3,
            2.755e3,
            1.038e3,
            5.061e2,
            2.865e2,
            4.739e2,
            3.634e2,
            2.052e2,
            7.094e1,
            3.267e1,
            1.072e1,
            4.803,
            6.567,
            4.942,
            2.773,
            1.667,
            6.172e-1,
            3.025e-1,
            1.195e-1,
            6.980e-2,
            5.047e-2,
            4.107e-2,
            3.229e-2,
            2.811e-2,
            2.503e-2,
            2.320e-2,
            2.152e-2,
            2.131e-2,
            2.233e-2,
            2.359e-2,
            2.481e-2,
            2.697e-2,
            2.872e-2,
            3.155e-2,
            3.277e-2,
        ],
        [
            6.598e3,
            5.250e3,
            2.864e3,
            1.084e3,
            5.294e2,
            3.000e2,
            1.874e2,
            3.739e2,
            2.125e2,
            7.376e1,
            3.407e1,
            1.121e1,
            5.033,
            6.418,
            4.928,
            2.815,
            1.706,
            6.376e-1,
            3.133e-1,
            1.236e-1,
            7.177e-2,
            5.157e-2,
            4.174e-2,
            3.258e-2,
            2.823e-2,
            2.505e-2,
            2.318e-2,
            2.148e-2,
            2.129e-2,
            2.233e-2,
            2.360e-2,
            2.483e-2,
            2.701e-2,
            2.876e-2,
            3.159e-2,
            3.283e-2,
        ],
        [
            2.046e3,
            5.526e3,
            3.031e3,
            1.152e3,
            5.633e2,
            3.196e2,
            1.998e2,
            3.908e2,
            2.240e2,
            7.799e1,
            3.614e1,
            1.193e1,
            5.366,
            6.363,
            4.989,
            2.904,
            1.776,
            6.699e-1,
            3.302e-1,
            1.301e-1,
            7.517e-2,
            5.369e-2,
            4.323e-2,
            3.349e-2,
            2.889e-2,
            2.553e-2,
            2.360e-2,
            2.184e-2,
            2.166e-2,
            2.273e-2,
            2.405e-2,
            2.532e-2,
            2.754e-2,
            2.933e-2,
            3.222e-2,
            3.344e-2,
        ],
        [
            2.097e3,
            5.329e3,
            3.102e3,
            1.183e3,
            5.795e2,
            3.291e2,
            2.059e2,
            3.951e2,
            2.278e2,
            7.972e1,
            3.706e1,
            1.227e1,
            5.532,
            6.094,
            4.872,
            2.893,
            1.786,
            6.806e-1,
            3.366e-1,
            1.326e-1,
            7.620e-2,
            5.411e-2,
            4.334e-2,
            3.333e-2,
            2.862e-2,
            2.522e-2,
            2.325e-2,
            2.150e-2,
            2.133e-2,
            2.241e-2,
            2.372e-2,
            2.498e-2,
            2.719e-2,
            2.896e-2,
            3.180e-2,
            3.302e-2,
        ],
        [
            2.206e3,
            5.590e3,
            3.258e3,
            1.245e3,
            6.111e2,
            3.474e2,
            2.175e2,
            3.560e2,
            2.378e2,
            8.352e1,
            3.895e1,
            1.295e1,
            5.848,
            5.927,
            4.863,
            2.953,
            1.841,
            7.088e-1,
            3.518e-1,
            1.385e-1,
            7.927e-2,
            5.598e-2,
            4.462e-2,
            3.406e-2,
            2.912e-2,
            2.557e-2,
            2.353e-2,
            2.173e-2,
            2.158e-2,
            2.269e-2,
            2.404e-2,
            2.532e-2,
            2.758e-2,
            2.938e-2,
            3.228e-2,
            3.351e-2,
        ],
        [
            2.281e3,
            5.008e3,
            3.337e3,
            1.280e3,
            6.296e2,
            3.584e2,
            2.246e2,
            3.595e2,
            2.416e2,
            8.538e1,
            3.994e1,
            1.333e1,
            6.033,
            3.242,
            4.722,
            2.937,
            1.849,
            7.197e-1,
            3.584e-1,
            1.409e-1,
            8.039e-2,
            5.650e-2,
            4.483e-2,
            3.399e-2,
            2.893e-2,
            2.530e-2,
            2.325e-2,
            2.144e-2,
            2.129e-2,
            2.241e-2,
            2.374e-2,
            2.502e-2,
            2.725e-2,
            2.902e-2,
            3.188e-2,
            3.306e-2,
        ],
        [
            2.386e3,
            5.274e3,
            3.481e3,
            1.342e3,
            6.607e2,
            3.765e2,
            2.362e2,
            2.810e2,
            2.502e2,
            8.914e1,
            4.184e1,
            1.402e1,
            6.357,
            3.422,
            4.673,
            2.986,
            1.899,
            7.474e-1,
            3.736e-1,
            1.470e-1,
            8.354e-2,
            5.842e-2,
            4.614e-2,
            3.474e-2,
            2.942e-2,
            2.565e-2,
            2.352e-2,
            2.166e-2,
            2.151e-2,
            2.266e-2,
            2.402e-2,
            2.532e-2,
            2.758e-2,
            2.937e-2,
            3.224e-2,
            3.343e-2,
        ],
        [
            2.483e3,
            5.503e3,
            3.438e3,
            1.391e3,
            6.858e2,
            3.913e2,
            2.456e2,
            2.906e2,
            2.554e2,
            9.187e1,
            4.328e1,
            1.456e1,
            6.616,
            3.566,
            4.554,
            2.993,
            1.925,
            7.660e-1,
            3.846e-1,
            1.514e-1,
            8.578e-2,
            5.971e-2,
            4.694e-2,
            3.509e-2,
            2.958e-2,
            2.570e-2,
            2.352e-2,
            2.163e-2,
            2.149e-2,
            2.264e-2,
            2.401e-2,
            2.532e-2,
            2.758e-2,
            2.938e-2,
            3.223e-2,
            3.342e-2,
        ],
        [
            2.605e3,
            5.790e3,
            3.558e3,
            1.450e3,
            7.164e2,
            4.091e2,
            2.570e2,
            1.220e2,
            2.623e2,
            9.521e1,
            4.504e1,
            1.521e1,
            6.928,
            3.740,
            4.466,
            3.015,
            1.961,
            7.901e-1,
            3.984e-1,
            1.570e-1,
            8.869e-2,
            6.145e-2,
            4.811e-2,
            3.571e-2,
            2.997e-2,
            2.593e-2,
            2.369e-2,
            2.175e-2,
            2.161e-2,
            2.279e-2,
            2.417e-2,
            2.549e-2,
            2.777e-2,
            2.958e-2,
            3.245e-2,
            3.363e-2,
        ],
        [
            2.737e3,
            6.003e3,
            3.488e3,
            1.510e3,
            7.480e2,
            4.276e2,
            2.688e2,
            1.278e2,
            2.694e2,
            9.860e1,
            4.683e1,
            1.588e1,
            7.253,
            3.922,
            4.349,
            3.028,
            1.995,
            8.141e-1,
            4.125e-1,
            1.629e-1,
            9.173e-2,
            6.329e-2,
            4.934e-2,
            3.638e-2,
            3.040e-2,
            2.620e-2,
            2.388e-2,
            2.190e-2,
            2.176e-2,
            2.295e-2,
            2.435e-2,
            2.569e-2,
            2.799e-2,
            2.981e-2,
            3.268e-2,
            3.387e-2,
        ],
        [
            2.888e3,
            3.892e3,
            3.646e3,
            1.576e3,
            7.831e2,
            4.482e2,
            2.820e2,
            1.342e2,
            2.420e2,
            1.023e2,
            4.882e1,
            1.663e1,
            7.615,
            4.124,
            4.203,
            3.044,
            2.033,
            8.410e-1,
            4.283e-1,
            1.695e-1,
            9.522e-2,
            6.544e-2,
            5.081e-2,
            3.721e-2,
            3.095e-2,
            2.658e-2,
            2.417e-2,
            2.214e-2,
            2.199e-2,
            2.321e-2,
            2.463e-2,
            2.598e-2,
            2.832e-2,
            3.016e-2,
            3.305e-2,
            3.424e-2,
        ],
        [
            3.006e3,
            1.340e3,
            3.751e3,
            1.620e3,
            8.072e2,
            4.626e2,
            2.913e2,
            1.389e2,
            2.444e2,
            1.047e2,
            5.012e1,
            1.716e1,
            7.875,
            4.273,
            2.584,
            3.008,
            2.038,
            8.554e-1,
            4.381e-1,
            1.737e-1,
            9.741e-2,
            6.671e-2,
            5.159e-2,
            3.754e-2,
            3.107e-2,
            2.658e-2,
            2.413e-2,
            2.208e-2,
            2.191e-2,
            2.314e-2,
            2.457e-2,
            2.593e-2,
            2.826e-2,
            3.010e-2,
            3.302e-2,
            3.419e-2,
        ],
        [
            3.175e3,
            1.413e3,
            3.406e3,
            1.688e3,
            8.430e2,
            4.839e2,
            3.051e2,
            1.456e2,
            1.916e2,
            1.084e2,
            5.206e1,
            1.791e1,
            8.242,
            4.480,
            2.712,
            3.000,
            2.067,
            8.805e-1,
            4.534e-1,
            1.803e-1,
            1.009e-1,
            6.886e-2,
            5.306e-2,
            3.836e-2,
            3.161e-2,
            2.695e-2,
            2.441e-2,
            2.228e-2,
            2.212e-2,
            2.337e-2,
            2.481e-2,
            2.618e-2,
            2.853e-2,
            3.038e-2,
            3.329e-2,
            3.446e-2,
        ],
        [
            3.324e3,
            1.478e3,
            3.546e3,
            1.745e3,
            8.720e2,
            5.013e2,
            3.164e2,
            1.512e2,
            1.975e2,
            1.111e2,
            5.353e1,
            1.851e1,
            8.542,
            4.651,
            2.820,
            2.958,
            2.075,
            8.973e-1,
            4.645e-1,
            1.853e-1,
            1.035e-1,
            7.044e-2,
            5.409e-2,
            3.886e-2,
            3.188e-2,
            2.708e-2,
            2.447e-2,
            2.230e-2,
            2.212e-2,
            2.338e-2,
            2.483e-2,
            2.620e-2,
            2.855e-2,
            3.040e-2,
            3.330e-2,
            3.445e-2,
        ],
        [
            3.498e3,
            1.555e3,
            3.711e3,
            1.812e3,
            9.073e2,
            5.223e2,
            3.299e2,
            1.579e2,
            2.021e2,
            1.143e2,
            5.532e1,
            1.923e1,
            8.899,
            4.854,
            2.947,
            2.924,
            2.092,
            9.188e-1,
            4.784e-1,
            1.915e-1,
            1.069e-1,
            7.248e-2,
            5.545e-2,
            3.960e-2,
            3.235e-2,
            2.736e-2,
            2.468e-2,
            2.245e-2,
            2.227e-2,
            2.354e-2,
            2.499e-2,
            2.638e-2,
            2.874e-2,
            3.058e-2,
            3.349e-2,
            3.464e-2,
        ],
        [
            3.671e3,
            1.632e3,
            3.853e3,
            1.873e3,
            9.405e2,
            5.423e2,
            3.428e2,
            1.643e2,
            9.204e1,
            1.172e2,
            5.697e1,
            1.991e1,
            9.240,
            5.050,
            3.070,
            2.879,
            2.100,
            9.378e-1,
            4.913e-1,
            1.973e-1,
            1.100e-1,
            7.440e-2,
            5.673e-2,
            4.028e-2,
            3.276e-2,
            2.761e-2,
            2.484e-2,
            2.256e-2,
            2.236e-2,
            2.363e-2,
            2.510e-2,
            2.649e-2,
            2.886e-2,
            3.072e-2,
            3.360e-2,
            3.475e-2,
        ],
        [
            3.860e3,
            1.717e3,
            3.702e3,
            1.939e3,
            9.771e2,
            5.642e2,
            3.569e2,
            1.714e2,
            9.610e1,
            1.201e2,
            5.876e1,
            2.064e1,
            9.614,
            5.265,
            3.205,
            2.832,
            2.107,
            9.580e-1,
            5.054e-1,
            2.038e-1,
            1.135e-1,
            7.658e-2,
            5.822e-2,
            4.109e-2,
            3.327e-2,
            2.794e-2,
            2.508e-2,
            2.273e-2,
            2.251e-2,
            2.380e-2,
            2.527e-2,
            2.667e-2,
            2.906e-2,
            3.092e-2,
            3.382e-2,
            3.496e-2,
        ],
        [
            4.019e3,
            1.790e3,
            2.179e3,
            1.904e3,
            1.004e3,
            5.813e2,
            3.682e2,
            1.770e2,
            9.940e1,
            1.218e2,
            5.999e1,
            2.120e1,
            9.907,
            5.437,
            3.314,
            2.756,
            2.092,
            9.696e-1,
            5.150e-1,
            2.085e-1,
            1.161e-1,
            7.813e-2,
            5.923e-2,
            4.157e-2,
            3.351e-2,
            2.802e-2,
            2.511e-2,
            2.272e-2,
            2.248e-2,
            2.376e-2,
            2.523e-2,
            2.663e-2,
            2.901e-2,
            3.086e-2,
            3.375e-2,
            3.486e-2,
        ],
        [
            4.230e3,
            1.886e3,
            1.021e3,
            1.973e3,
            1.043e3,
            6.047e2,
            3.837e2,
            1.846e2,
            1.038e2,
            1.244e2,
            6.179e1,
            2.198e1,
            1.030e1,
            5.667,
            3.460,
            2.694,
            2.093,
            9.903e-1,
            5.290e-1,
            2.155e-1,
            1.199e-1,
            8.054e-2,
            6.088e-2,
            4.250e-2,
            3.412e-2,
            2.843e-2,
            2.541e-2,
            2.295e-2,
            2.269e-2,
            2.398e-2,
            2.546e-2,
            2.687e-2,
            2.927e-2,
            3.115e-2,
            3.405e-2,
            3.516e-2,
        ],
        [
            4.421e3,
            1.974e3,
            1.069e3,
            1.925e3,
            1.078e3,
            6.262e2,
            3.979e2,
            1.917e2,
            1.078e2,
            1.265e2,
            6.333e1,
            2.268e1,
            1.067e1,
            5.879,
            3.595,
            2.592,
            2.081,
            1.006,
            5.413e-1,
            2.216e-1,
            1.233e-1,
            8.265e-2,
            6.230e-2,
            4.325e-2,
            3.459e-2,
            2.871e-2,
            2.560e-2,
            2.307e-2,
            2.279e-2,
            2.408e-2,
            2.557e-2,
            2.699e-2,
            2.939e-2,
            3.127e-2,
            3.418e-2,
            3.529e-2,
        ],
        [
            4.639e3,
            2.076e3,
            1.125e3,
            2.005e3,
            1.120e3,
            6.512e2,
            4.143e2,
            1.999e2,
            1.126e2,
            1.294e2,
            6.522e1,
            2.349e1,
            1.109e1,
            6.124,
            3.751,
            1.720,
            2.074,
            1.026,
            5.563e-1,
            2.289e-1,
            1.274e-1,
            8.523e-2,
            6.409e-2,
            4.427e-2,
            3.525e-2,
            2.915e-2,
            2.593e-2,
            2.333e-2,
            2.302e-2,
            2.432e-2,
            2.582e-2,
            2.725e-2,
            2.968e-2,
            3.159e-2,
            3.450e-2,
            3.565e-2,
        ],
        [
            4.817e3,
            2.161e3,
            1.172e3,
            2.069e3,
            1.153e3,
            6.710e2,
            4.272e2,
            2.065e2,
            1.164e2,
            1.307e2,
            6.647e1,
            2.410e1,
            1.141e1,
            6.321,
            3.878,
            1.782,
            2.043,
            1.036,
            5.661e-1,
            2.342e-1,
            1.304e-1,
            8.711e-2,
            6.536e-2,
            4.493e-2,
            3.563e-2,
            2.936e-2,
            2.605e-2,
            2.339e-2,
            2.307e-2,
            2.436e-2,
            2.586e-2,
            2.730e-2,
            2.975e-2,
            3.165e-2,
            3.460e-2,
            3.576e-2,
        ],
        [
            4.995e3,
            2.247e3,
            1.219e3,
            2.135e3,
            1.185e3,
            6.900e2,
            4.398e2,
            2.131e2,
            1.202e2,
            1.154e2,
            6.761e1,
            2.467e1,
            1.173e1,
            6.513,
            4.003,
            1.844,
            2.007,
            1.044,
            5.753e-1,
            2.393e-1,
            1.334e-1,
            8.897e-2,
            6.661e-2,
            4.557e-2,
            3.600e-2,
            2.955e-2,
            2.616e-2,
            2.345e-2,
            2.309e-2,
            2.437e-2,
            2.587e-2,
            2.731e-2,
            2.975e-2,
            3.167e-2,
            3.463e-2,
            3.578e-2,
        ],
        [
            5.197e3,
            2.344e3,
            1.274e3,
            1.913e3,
            1.221e3,
            7.124e2,
            4.546e2,
            2.207e2,
            1.247e2,
            9.100e1,
            6.899e1,
            2.536e1,
            1.211e1,
            6.740,
            4.149,
            1.916,
            1.976,
            1.056,
            5.870e-1,
            2.455e-1,
            1.370e-1,
            9.128e-2,
            6.819e-2,
            4.644e-2,
            3.654e-2,
            2.988e-2,
            2.640e-2,
            2.360e-2,
            2.322e-2,
            2.449e-2,
            2.600e-2,
            2.744e-2,
            2.989e-2,
            3.181e-2,
            3.478e-2,
            3.595e-2,
        ],
        [
            5.427e3,
            2.455e3,
            1.336e3,
            1.996e3,
            1.263e3,
            7.386e2,
            4.721e2,
            2.295e2,
            1.298e2,
            9.358e1,
            7.060e1,
            2.617e1,
            1.255e1,
            7.004,
            4.320,
            1.999,
            1.951,
            1.071,
            6.014e-1,
            2.532e-1,
            1.414e-1,
            9.411e-2,
            7.017e-2,
            4.758e-2,
            3.730e-2,
            3.039e-2,
            2.678e-2,
            2.389e-2,
            2.347e-2,
            2.475e-2,
            2.626e-2,
            2.772e-2,
            3.020e-2,
            3.213e-2,
            3.514e-2,
            3.632e-2,
        ],
        [
            5.710e3,
            2.591e3,
            1.411e3,
            2.090e3,
            1.264e3,
            7.721e2,
            4.942e2,
            2.406e2,
            1.363e2,
            9.728e1,
            7.278e1,
            2.721e1,
            1.311e1,
            7.334,
            4.532,
            2.103,
            1.936,
            1.095,
            6.207e-1,
            2.630e-1,
            1.471e-1,
            9.781e-2,
            7.281e-2,
            4.916e-2,
            3.839e-2,
            3.117e-2,
            2.740e-2,
            2.438e-2,
            2.392e-2,
            2.521e-2,
            2.674e-2,
            2.822e-2,
            3.074e-2,
            3.271e-2,
            3.577e-2,
            3.694e-2,
        ],
        [
            5.854e3,
            2.717e3,
            1.482e3,
            2.178e3,
            1.240e3,
            8.025e2,
            5.146e2,
            2.509e2,
            1.423e2,
            1.008e2,
            7.446e1,
            2.812e1,
            1.361e1,
            7.637,
            4.729,
            2.200,
            1.897,
            1.112,
            6.369e-1,
            2.718e-1,
            1.522e-1,
            1.012e-1,
            7.517e-2,
            5.055e-2,
            3.934e-2,
            3.181e-2,
            2.791e-2,
            2.478e-2,
            2.427e-2,
            2.556e-2,
            2.710e-2,
            2.859e-2,
            3.113e-2,
            3.311e-2,
            3.619e-2,
            3.739e-2,
        ],
        [
            5.812e3,
            2.706e3,
            1.478e3,
            1.507e3,
            1.229e3,
            7.931e2,
            5.085e2,
            2.485e2,
            1.411e2,
            9.807e1,
            7.231e1,
            2.760e1,
            1.342e1,
            7.552,
            4.686,
            2.185,
            1.766,
            1.073,
            6.204e-1,
            2.668e-1,
            1.496e-1,
            9.941e-2,
            7.377e-2,
            4.942e-2,
            3.832e-2,
            3.089e-2,
            2.704e-2,
            2.396e-2,
            2.344e-2,
            2.469e-2,
            2.620e-2,
            2.766e-2,
            3.016e-2,
            3.216e-2,
            3.534e-2,
            3.670e-2,
        ],
        [
            6.224e3,
            2.833e3,
            1.549e3,
            1.928e3,
            1.281e3,
            8.238e2,
            5.285e2,
            2.588e2,
            1.471e2,
            5.174e1,
            7.395e1,
            2.849e1,
            1.391e1,
            7.851,
            4.881,
            2.283,
            1.261,
            1.087,
            6.351e-1,
            2.750e-1,
            1.542e-1,
            1.025e-1,
            7.597e-2,
            5.067e-2,
            3.920e-2,
            3.151e-2,
            2.752e-2,
            2.432e-2,
            2.372e-2,
            2.495e-2,
            2.644e-2,
            2.788e-2,
            3.033e-2,
            3.227e-2,
            3.525e-2,
            3.641e-2,
        ],
        [
            6.187e3,
            2.937e3,
            1.608e3,
            6.555e2,
            1.322e3,
            8.472e2,
            5.438e2,
            2.669e2,
            1.519e2,
            5.353e1,
            7.496e1,
            2.913e1,
            1.429e1,
            8.088,
            5.039,
            2.363,
            1.308,
            1.091,
            6.440e-1,
            2.811e-1,
            1.580e-1,
            1.050e-1,
            7.772e-2,
            5.165e-2,
            3.983e-2,
            3.191e-2,
            2.779e-2,
            2.452e-2,
            2.387e-2,
            2.509e-2,
            2.658e-2,
            2.802e-2,
            3.050e-2,
            3.245e-2,
            3.549e-2,
            3.668e-2,
        ],
        [
            6.455e3,
            3.069e3,
            1.683e3,
            6.870e2,
            1.377e3,
            8.408e2,
            5.641e2,
            2.773e2,
            1.580e2,
            5.583e1,
            7.645e1,
            3.000e1,
            1.479e1,
            8.396,
            5.242,
            2.465,
            1.367,
            1.100,
            6.581e-1,
            2.896e-1,
            1.632e-1,
            1.085e-1,
            8.018e-2,
            5.311e-2,
            4.080e-2,
            3.258e-2,
            2.831e-2,
            2.490e-2,
            2.419e-2,
            2.539e-2,
            2.688e-2,
            2.832e-2,
            3.079e-2,
            3.275e-2,
            3.575e-2,
            3.692e-2,
        ],
        [
            6.600e3,
            3.148e3,
            1.729e3,
            7.070e2,
            1.208e3,
            8.581e2,
            5.749e2,
            2.830e2,
            1.615e2,
            5.718e1,
            6.714e1,
            3.032e1,
            1.503e1,
            8.558,
            5.355,
            2.526,
            1.403,
            1.090,
            6.603e-1,
            2.931e-1,
            1.656e-1,
            1.101e-1,
            8.128e-2,
            5.366e-2,
            4.109e-2,
            3.269e-2,
            2.834e-2,
            2.487e-2,
            2.411e-2,
            2.528e-2,
            2.674e-2,
            2.817e-2,
            3.060e-2,
            3.253e-2,
            3.550e-2,
            3.664e-2,
        ],
        [
            6.515e3,
            3.313e3,
            1.821e3,
            7.444e2,
            1.265e3,
            8.454e2,
            6.004e2,
            2.958e2,
            1.690e2,
            6.000e1,
            5.486e1,
            3.146e1,
            1.567e1,
            8.950,
            5.612,
            2.655,
            1.477,
            1.106,
            6.792e-1,
            3.042e-1,
            1.723e-1,
            1.146e-1,
            8.453e-2,
            5.563e-2,
            4.247e-2,
            3.367e-2,
            2.911e-2,
            2.547e-2,
            2.463e-2,
            2.580e-2,
            2.727e-2,
            2.870e-2,
            3.117e-2,
            3.311e-2,
            3.609e-2,
            3.724e-2,
        ],
        [
            6.612e3,
            3.368e3,
            1.852e3,
            7.578e2,
            1.277e3,
            8.569e2,
            6.062e2,
            2.989e2,
            1.711e2,
            6.084e1,
            5.496e1,
            3.149e1,
            1.576e1,
            9.034,
            5.678,
            2.695,
            1.502,
            1.083,
            6.746e-1,
            3.050e-1,
            1.732e-1,
            1.152e-1,
            8.494e-2,
            5.574e-2,
            4.241e-2,
            3.351e-2,
            2.891e-2,
            2.523e-2,
            2.434e-2,
            2.546e-2,
            2.689e-2,
            2.829e-2,
            3.068e-2,
            3.259e-2,
            3.552e-2,
            3.662e-2,
        ],
    ]
)
# Hard-wire the table of each compton edge
# Z, Energy, mac low, mac high, meac low, meac high
edges = np.array(
    [
        [11, 0.0010721, 5.429e2, 6.435e3, 5.410e2, 6.320e3],
        [12, 0.001305, 4.530e2, 5.444e3, 4.509e2, 5.310e3],
        [13, 0.0015596, 3.621e2, 3.957e3, 3.600e2, 3.829e3],
        [14, 0.0018389, 3.092e2, 3.192e3, 3.070e2, 3.059e3],
        [15, 0.0021455, 2.494e2, 2.473e3, 2.473e2, 2.343e3],
        [16, 0.002472, 2.168e2, 2.070e3, 2.145e2, 1.935e3],
        [17, 0.0028224, 1.774e2, 1.637e3, 1.752e2, 1.506e3],
        [18, 0.0032029, 1.424e2, 1.275e3, 1.403e2, 1.153e3],
        [19, 0.0036074, 1.327e2, 1.201e3, 1.306e2, 1.065e3],
        [20, 0.0040381, 1.187e2, 1.023e3, 1.166e2, 8.887e2],
        [21, 0.0044928, 9.687e1, 8.148e2, 9.490e1, 6.911e2],
        [22, 0.0049664, 8.380e1, 6.878e2, 8.188e1, 5.684e2],
        [23, 0.0054651, 7.277e1, 5.870e2, 7.090e1, 4.717e2],
        [24, 0.0059892, 6.574e1, 5.160e2, 6.383e1, 4.027e2],
        [25, 0.006539, 5.803e1, 4.520e2, 5.619e1, 3.415e2],
        [26, 0.007112, 5.319e1, 4.076e2, 5.133e1, 2.978e2],
        [27, 0.0077089, 4.710e1, 3.555e2, 4.530e1, 2.507e2],
        [28, 0.0010081, 9.654e3, 1.099e4, 9.598e3, 1.093e4],
        [28, 0.0083328, 4.428e1, 3.294e2, 4.242e1, 2.240e2],
        [29, 0.0010961, 8.242e3, 9.347e3, 8.186e3, 9.282e3],
        [29, 0.0089789, 3.829e1, 2.784e2, 3.652e1, 1.824e2],
        [30, 0.0010197, 1.484e3, 3.804e3, 1.478e3, 3.777e3],
        [30, 0.0010428, 6.518e3, 8.274e3, 6.464e3, 8.202e3],
        [30, 0.0011936, 7.371e3, 8.396e3, 7.312e3, 8.328e3],
        [30, 0.0096586, 3.505e1, 2.536e2, 3.332e1, 1.599e2],
        [31, 0.0011154, 1.312e3, 3.990e3, 1.307e3, 3.955e3],
        [31, 0.0011423, 5.664e3, 7.405e3, 5.611e3, 7.332e3],
        [31, 0.0012977, 6.358e3, 7.206e3, 6.299e3, 7.139e3],
        [31, 0.0103671, 3.099e1, 2.214e2, 2.936e1, 1.344e2],
        [32, 0.0012167, 1.190e3, 4.389e3, 1.185e3, 4.343e3],
        [32, 0.0012478, 4.974e3, 6.698e3, 4.922e3, 6.622e3],
        [32, 0.0014143, 5.554e3, 6.287e3, 5.495e3, 6.221e3],
        [32, 0.0111031, 2.811e1, 1.981e2, 2.653e1, 1.157e2],
        [33, 0.0013231, 1.092e3, 4.513e3, 1.087e3, 4.459e3],
        [33, 0.0013586, 4.452e3, 6.093e3, 4.398e3, 6.015e3],
        [33, 0.0015265, 4.997e3, 5.653e3, 4.938e3, 5.585e3],
        [33, 0.0118667, 2.577e1, 1.792e2, 2.425e1, 1.008e2],
        [34, 0.0014358, 9.814e2, 4.347e3, 9.760e2, 4.287e3],
        [34, 0.0014762, 3.907e3, 5.186e3, 3.855e3, 5.112e3],
        [34, 0.0016539, 4.342e3, 4.915e3, 4.284e3, 4.849e3],
        [34, 0.0126578, 2.318e1, 1.589e2, 2.173e1, 8.599e1],
        [35, 0.0015499, 9.255e2, 4.289e3, 9.200e2, 4.223e3],
        [35, 0.001596, 3.587e3, 5.097e3, 3.534e3, 5.014e3],
        [35, 0.001782, 3.969e3, 4.495e3, 3.910e3, 4.427e3],
        [35, 0.0134737, 2.176e1, 1.471e2, 2.033e1, 7.668e1],
        [36, 0.0016749, 8.361e2, 3.909e3, 8.305e2, 3.842e3],
        [36, 0.0017272, 3.166e3, 4.566e3, 3.114e3, 4.484e3],
        [36, 0.001921, 3.482e3, 3.948e3, 3.425e3, 3.882e3],
        [36, 0.0143256, 1.971e1, 1.313e2, 1.836e1, 6.604e1],
        [37, 0.0018044, 7.782e2, 3.096e3, 7.726e2, 3.040e3],
        [37, 0.0018639, 2.861e3, 3.957e3, 2.810e3, 3.880e3],
        [37, 0.0020651, 3.153e3, 3.606e3, 3.096e3, 3.540e3],
        [37, 0.0151997, 1.842e1, 1.208e2, 1.709e1, 5.864e1],
        [38, 0.0019396, 7.207e2, 2.864e3, 7.152e2, 2.807e3],
        [38, 0.0020068, 2.571e3, 3.577e3, 2.521e3, 3.501e3],
        [38, 0.0022163, 2.842e3, 3.241e3, 2.786e3, 3.176e3],
        [38, 0.0161046, 1.714e1, 1.108e2, 1.585e1, 5.200e1],
        [39, 0.00208, 6.738e2, 2.627e3, 6.682e2, 2.569e3],
        [39, 0.0021555, 2.342e3, 3.264e3, 2.292e3, 3.187e3],
        [39, 0.0023725, 2.597e3, 2.962e3, 2.540e3, 2.897e3],
        [39, 0.0170384, 1.612e1, 1.029e2, 1.486e1, 4.672e1],
        [40, 0.0022223, 6.258e2, 2.392e3, 6.201e2, 2.335e3],
        [40, 0.0023067, 2.120e3, 2.953e3, 2.071e3, 2.878e3],
        [40, 0.0025316, 2.359e3, 2.691e3, 2.303e3, 2.627e3],
        [40, 0.0179976, 1.501e1, 9.470e1, 1.380e1, 4.164e1],
        [41, 0.0023705, 5.844e2, 2.181e3, 5.786e2, 2.125e3],
        [41, 0.0024647, 1.935e3, 2.694e3, 1.886e3, 2.619e3],
        [41, 0.0026977, 2.161e3, 2.470e3, 2.104e3, 2.405e3],
        [41, 0.0189856, 1.409e1, 8.784e1, 1.291e1, 3.746e1],
        [42, 0.0025202, 5.415e2, 1.979e3, 5.358e2, 1.924e3],
        [42, 0.0026251, 1.750e3, 2.433e3, 1.703e3, 2.360e3],
        [42, 0.0028655, 1.961e3, 2.243e3, 1.906e3, 2.179e3],
        [42, 0.0199995, 1.308e1, 8.055e1, 1.193e1, 3.293e1],
        [43, 0.0026769, 5.072e2, 1.812e3, 5.014e2, 1.758e3],
        [43, 0.0027932, 1.602e3, 2.223e3, 1.555e3, 2.151e3],
        [43, 0.0030425, 1.800e3, 2.059e3, 1.745e3, 1.995e3],
        [43, 0.021044, 1.229e1, 7.481e1, 1.117e1, 3.014e1],
        [44, 0.0028379, 4.704e2, 1.644e3, 4.646e2, 1.591e3],
        [44, 0.0029669, 1.452e3, 2.317e3, 1.407e3, 2.233e3],
        [44, 0.003224, 1.638e3, 1.874e3, 1.584e3, 1.811e3],
        [44, 0.0221172, 1.143e1, 6.876e1, 1.035e1, 2.700e1],
        [45, 0.0030038, 4.427e2, 1.513e3, 4.368e2, 1.461e3],
        [45, 0.0031461, 1.337e3, 1.847e3, 1.292e3, 1.777e3],
        [45, 0.0034119, 1.512e3, 1.731e3, 1.458e3, 1.669e3],
        [45, 0.0232199, 1.079e1, 6.414e1, 9.736, 2.458e1],
        [46, 0.0031733, 4.106e2, 1.355e3, 4.047e2, 1.305e3],
        [46, 0.0033303, 1.215e3, 1.664e3, 1.171e3, 1.597e3],
        [46, 0.0036043, 1.379e3, 1.582e3, 1.326e3, 1.520e3],
        [46, 0.0243503, 1.003e1, 5.898e1, 9.016, 2.208e1],
        [47, 0.0033511, 3.887e2, 1.274e3, 3.827e2, 1.223e3],
        [47, 0.0035237, 1.126e3, 1.547e3, 1.082e3, 1.479e3],
        [47, 0.0038058, 1.282e3, 1.468e3, 1.229e3, 1.406e3],
        [47, 0.025514, 9.527, 5.539e1, 8.534, 2.031e1],
        [48, 0.0035375, 3.575e2, 1.152e3, 3.517e2, 1.103e3],
        [48, 0.003727, 1.013e3, 1.389e3, 9.715e2, 1.324e3],
        [48, 0.004018, 1.157e3, 1.324e3, 1.106e3, 1.264e3],
        [48, 0.0267112, 8.809, 5.065e1, 7.863, 1.821e1],
        [49, 0.0037301, 3.356e2, 1.046e3, 3.298e2, 9.989e2],
        [49, 0.003938, 9.313e2, 1.261e3, 8.905e2, 1.199e3],
        [49, 0.0042375, 1.066e3, 1.223e3, 1.016e3, 1.164e3],
        [49, 0.0279399, 8.316, 4.733e1, 7.395, 1.670e1],
        [50, 0.0039288, 3.114e2, 9.285e2, 3.058e2, 8.845e2],
        [50, 0.0041561, 8.469e2, 1.145e3, 8.074e2, 1.084e3],
        [50, 0.0044647, 9.712e2, 1.117e3, 9.221e2, 1.059e3],
        [50, 0.0292001, 7.760, 4.360e1, 6.876, 1.514e1],
        [51, 0.0041322, 2.918e2, 8.691e2, 2.863e2, 8.252e2],
        [51, 0.0043804, 7.776e2, 1.050e3, 7.392e2, 9.906e2],
        [51, 0.0046983, 8.939e2, 1.029e3, 8.457e2, 9.725e2],
        [51, 0.0304912, 7.307, 4.073e1, 6.452, 1.391e1],
        [52, 0.001006, 8.326e3, 8.684e3, 8.311e3, 8.668e3],
        [52, 0.0043414, 2.678e2, 7.882e2, 2.625e2, 7.460e2],
        [52, 0.004612, 6.995e2, 9.445e2, 6.629e2, 8.880e2],
        [52, 0.0049392, 8.062e2, 9.292e2, 7.600e2, 8.744e2],
        [52, 0.0318138, 6.738, 3.719e1, 5.929, 1.251e1],
        [53, 0.0010721, 7.863e3, 8.198e3, 7.847e3, 8.181e3],
        [53, 0.0045571, 2.592e2, 7.550e2, 2.537e2, 7.121e2],
        [53, 0.0048521, 6.636e2, 8.943e2, 6.270e2, 8.375e2],
        [53, 0.0051881, 7.665e2, 8.837e2, 7.198e2, 8.283e2],
        [53, 0.0331694, 6.553, 3.582e1, 5.744, 1.188e1],
        [54, 0.001149, 7.035e3, 7.338e3, 7.019e3, 7.321e3],
        [54, 0.0047822, 2.408e2, 6.941e2, 2.355e2, 6.524e2],
        [54, 0.0051037, 6.044e2, 8.181e2, 5.693e2, 7.630e2],
        [54, 0.0054528, 6.991e2, 8.064e2, 6.539e2, 7.527e2],
        [54, 0.0345614, 6.129, 3.316e1, 5.352, 1.086e1],
        [55, 0.001065, 8.214e3, 8.685e3, 8.194e3, 8.663e3],
        [55, 0.0012171, 6.584e3, 6.888e3, 6.567e3, 6.870e3],
        [55, 0.0050119, 2.290e2, 6.674e2, 2.237e2, 6.248e2],
        [55, 0.0053594, 5.645e2, 7.692e2, 5.299e2, 7.142e2],
        [55, 0.0057143, 6.556e2, 7.547e2, 6.108e2, 7.015e2],
        [55, 0.0359846, 5.863, 3.143e1, 5.102, 1.017e1],
        [56, 0.0010622, 7.465e3, 8.547e3, 7.445e3, 8.524e3],
        [56, 0.0011367, 7.404e3, 7.837e3, 7.384e3, 7.815e3],
        [56, 0.0012928, 5.985e3, 6.255e3, 5.968e3, 6.237e3],
        [56, 0.005247, 2.135e2, 6.098e2, 2.084e2, 5.689e2],
        [56, 0.0056236, 5.169e2, 7.016e2, 4.835e2, 6.486e2],
        [56, 0.0059888, 6.013e2, 6.930e2, 5.577e2, 6.412e2],
        [56, 0.0374406, 5.498, 2.919e1, 4.768, 9.346],
        [57, 0.0011234, 7.000e3, 8.025e3, 6.979e3, 8.001e3],
        [57, 0.0012044, 6.911e3, 7.321e3, 6.890e3, 7.298e3],
        [57, 0.0013613, 5.652e3, 5.905e3, 5.634e3, 5.886e3],
        [57, 0.0054827, 2.039e2, 5.764e2, 1.988e2, 5.356e2],
        [57, 0.0058906, 4.846e2, 6.545e2, 4.517e2, 6.023e2],
        [57, 0.0062663, 5.654e2, 6.518e2, 5.221e2, 6.003e2],
        [57, 0.0389246, 5.271, 2.772e1, 4.554, 8.785],
        [58, 0.0011854, 6.563e3, 7.545e3, 6.541e3, 7.519e3],
        [58, 0.0012728, 6.465e3, 6.853e3, 6.442e3, 6.829e3],
        [58, 0.0014366, 5.293e3, 5.532e3, 5.273e3, 5.512e3],
        [58, 0.0057234, 1.943e2, 5.454e2, 1.892e2, 5.046e2],
        [58, 0.0061642, 4.554e2, 6.188e2, 4.228e2, 5.665e2],
        [58, 0.0065488, 5.332e2, 6.149e2, 4.899e2, 5.633e2],
        [58, 0.040443, 5.066, 2.635e1, 4.359, 8.272],
        [59, 0.0012422, 6.278e3, 7.224e3, 6.254e3, 7.196e3],
        [59, 0.0013374, 6.142e3, 6.513e3, 6.118e3, 6.487e3],
        [59, 0.001511, 5.006e3, 5.235e3, 4.986e3, 5.214e3],
        [59, 0.0059643, 1.868e2, 5.214e2, 1.816e2, 4.802e2],
        [59, 0.0064404, 4.310e2, 5.857e2, 3.984e2, 5.333e2],
        [59, 0.0068348, 5.060e2, 5.836e2, 4.625e2, 5.317e2],
        [59, 0.0419906, 4.892, 2.518e1, 4.192, 7.833],
        [60, 0.001005, 6.949e3, 8.554e3, 6.918e3, 8.516e3],
        [60, 0.0012974, 5.933e3, 6.833e3, 5.908e3, 6.803e3],
        [60, 0.0014028, 5.744e3, 6.093e3, 5.719e3, 6.066e3],
        [60, 0.0015753, 4.738e3, 4.951e3, 4.717e3, 4.929e3],
        [60, 0.0062079, 1.767e2, 4.892e2, 1.715e2, 4.484e2],
        [60, 0.0067215, 4.013e2, 5.456e2, 3.694e2, 4.939e2],
        [60, 0.007126, 4.723e2, 5.448e2, 4.293e2, 4.936e2],
        [60, 0.0435689, 4.642, 2.366e1, 3.962, 7.296],
        [61, 0.0010269, 1.959e3, 2.729e3, 1.949e3, 2.715e3],
        [61, 0.0010515, 5.830e3, 7.242e3, 5.801e3, 7.205e3],
        [61, 0.0013569, 5.687e3, 6.555e3, 5.660e3, 6.524e3],
        [61, 0.0014714, 5.466e3, 5.799e3, 5.439e3, 5.770e3],
        [61, 0.001653, 4.497e3, 4.699e3, 4.474e3, 4.676e3],
        [61, 0.0064593, 1.702e2, 4.678e2, 1.649e2, 4.267e2],
        [61, 0.0070128, 3.805e2, 5.174e2, 3.487e2, 4.657e2],
        [61, 0.0074279, 4.494e2, 5.184e2, 4.062e2, 4.669e2],
        [61, 0.045184, 4.491, 2.265e1, 3.816, 6.930],
        [62, 0.0010802, 1.827e3, 2.635e3, 1.817e3, 2.620e3],
        [62, 0.001106, 5.613e3, 6.852e3, 5.582e3, 6.814e3],
        [62, 0.0014198, 5.262e3, 6.072e3, 5.234e3, 6.039e3],
        [62, 0.0015407, 5.046e3, 5.355e3, 5.018e3, 5.325e3],
        [62, 0.0017228, 4.189e3, 4.376e3, 4.165e3, 4.352e3],
        [62, 0.0067162, 1.587e2, 4.334e2, 1.536e2, 3.933e2],
        [62, 0.0073118, 3.496e2, 4.756e2, 3.189e2, 4.255e2],
        [62, 0.0077368, 4.141e2, 4.777e2, 3.721e2, 4.276e2],
        [62, 0.0468342, 4.208, 2.100e1, 3.562, 6.378],
        [63, 0.0011309, 1.763e3, 2.443e3, 1.753e3, 2.428e3],
        [63, 0.0011606, 5.416e3, 6.540e3, 5.382e3, 6.498e3],
        [63, 0.0014806, 5.031e3, 5.810e3, 5.001e3, 5.774e3],
        [63, 0.0016139, 4.771e3, 5.064e3, 4.742e3, 5.034e3],
        [63, 0.0018, 3.980e3, 4.158e3, 3.955e3, 4.132e3],
        [63, 0.0069769, 1.522e2, 4.127e2, 1.471e2, 3.725e2],
        [63, 0.0076171, 3.302e2, 4.492e2, 2.998e2, 3.993e2],
        [63, 0.008052, 3.921e2, 4.524e2, 3.502e2, 4.024e2],
        [63, 0.048519, 4.051, 2.001e1, 3.414, 6.036],
        [64, 0.0011852, 1.668e3, 1.931e3, 1.658e3, 1.919e3],
        [64, 0.0012172, 3.961e3, 4.764e3, 3.934e3, 4.731e3],
        [64, 0.001544, 4.701e3, 5.432e3, 4.670e3, 5.395e3],
        [64, 0.0016883, 4.421e3, 4.694e3, 4.391e3, 4.662e3],
        [64, 0.0018808, 3.691e3, 3.854e3, 3.666e3, 3.829e3],
        [64, 0.0072428, 1.429e2, 3.844e2, 1.379e2, 3.452e2],
        [64, 0.0079303, 3.049e2, 4.149e2, 2.755e2, 3.665e2],
        [64, 0.0083756, 3.631e2, 4.190e2, 3.223e2, 3.702e2],
        [64, 0.0502391, 3.812, 1.864e1, 3.199, 5.585],
        [65, 0.0012412, 1.591e3, 2.337e3, 1.581e3, 2.321e3],
        [65, 0.001275, 5.023e3, 5.928e3, 4.984e3, 5.881e3],
        [65, 0.0016113, 4.464e3, 5.164e3, 4.431e3, 5.125e3],
        [65, 0.0017677, 4.166e3, 4.424e3, 4.135e3, 4.391e3],
        [65, 0.0019675, 3.482e3, 3.638e3, 3.456e3, 3.611e3],
        [65, 0.007514, 1.368e2, 3.658e2, 1.318e2, 3.266e2],
        [65, 0.0082516, 2.881e2, 3.925e2, 2.590e2, 3.443e2],
        [65, 0.008708, 3.441e2, 3.970e2, 3.033e2, 3.483e2],
        [65, 0.0519957, 3.672, 1.777e1, 3.068, 5.291],
        [66, 0.0012949, 1.521e3, 2.173e3, 1.511e3, 2.156e3],
        [66, 0.0013325, 4.745e3, 5.551e3, 4.704e3, 5.502e3],
        [66, 0.0016756, 4.229e3, 4.896e3, 4.194e3, 4.855e3],
        [66, 0.0018418, 3.924e3, 4.168e3, 3.892e3, 4.133e3],
        [66, 0.0020468, 3.286e3, 3.433e3, 3.259e3, 3.404e3],
        [66, 0.0077901, 1.299e2, 3.437e2, 1.249e2, 3.051e2],
        [66, 0.0085806, 2.695e2, 3.672e2, 2.410e2, 3.198e2],
        [66, 0.0090458, 3.228e2, 3.725e2, 2.826e2, 3.245e2],
        [66, 0.0537885, 3.500, 1.676e1, 2.911, 4.961],
        [67, 0.0013514, 1.462e3, 2.108e3, 1.452e3, 2.091e3],
        [67, 0.0013915, 4.528e3, 5.239e3, 4.485e3, 5.187e3],
        [67, 0.0017412, 4.038e3, 4.677e3, 4.001e3, 4.633e3],
        [67, 0.0019228, 3.703e3, 3.934e3, 3.669e3, 3.898e3],
        [67, 0.0021283, 3.127e3, 3.266e3, 3.099e3, 3.236e3],
        [67, 0.0080711, 1.242e2, 3.283e2, 1.192e2, 2.897e2],
        [67, 0.0089178, 2.540e2, 3.463e2, 2.260e2, 2.994e2],
        [67, 0.0093942, 3.051e2, 3.520e2, 2.652e2, 3.044e2],
        [67, 0.0556177, 3.361, 1.592e1, 2.783, 4.697],
        [68, 0.0014093, 1.408e3, 2.069e3, 1.397e3, 2.051e3],
        [68, 0.0014533, 4.339e3, 4.952e3, 4.293e3, 4.898e3],
        [68, 0.0018118, 3.841e3, 4.452e3, 3.802e3, 4.406e3],
        [68, 0.0020058, 3.499e3, 3.717e3, 3.464e3, 3.680e3],
        [68, 0.0022065, 2.995e3, 3.127e3, 2.965e3, 3.096e3],
        [68, 0.0083579, 1.190e2, 3.126e2, 1.140e2, 2.741e2],
        [68, 0.0092643, 2.397e2, 3.271e2, 2.121e2, 2.806e2],
        [68, 0.0097513, 2.886e2, 3.330e2, 2.491e2, 2.858e2],
        [68, 0.0574855, 3.232, 1.514e1, 2.664, 4.442],
        [69, 0.0014677, 1.362e3, 1.919e3, 1.352e3, 1.901e3],
        [69, 0.0015146, 4.145e3, 4.830e3, 4.098e3, 4.773e3],
        [69, 0.0018845, 3.668e3, 4.254e3, 3.627e3, 4.206e3],
        [69, 0.0020898, 3.326e3, 3.534e3, 3.290e3, 3.495e3],
        [69, 0.0023068, 2.821e3, 2.945e3, 2.791e3, 2.914e3],
        [69, 0.008648, 1.146e2, 2.991e2, 1.096e2, 2.606e2],
        [69, 0.0096169, 2.274e2, 3.101e2, 2.001e2, 2.640e2],
        [69, 0.0101157, 2.745e2, 3.167e2, 2.351e2, 2.697e2],
        [69, 0.0593896, 3.122, 1.460e1, 2.562, 4.721],
        [70, 0.0015278, 1.300e3, 1.965e3, 1.289e3, 1.944e3],
        [70, 0.0015763, 3.908e3, 4.540e3, 3.859e3, 4.482e3],
        [70, 0.0019498, 3.495e3, 4.054e3, 3.453e3, 4.004e3],
        [70, 0.002173, 3.128e3, 3.323e3, 3.091e3, 3.284e3],
        [70, 0.0023981, 2.652e3, 2.769e3, 2.621e3, 2.737e3],
        [70, 0.0089436, 1.088e2, 2.824e2, 1.039e2, 2.444e2],
        [70, 0.0099782, 2.128e2, 2.906e2, 1.862e2, 2.455e2],
        [70, 0.0104864, 2.577e2, 2.973e2, 2.189e2, 2.512e2],
        [70, 0.0613323, 2.975, 1.365e1, 2.432, 3.964],
        [71, 0.0015885, 1.264e3, 1.597e3, 1.253e3, 1.581e3],
        [71, 0.0016394, 3.442e3, 3.935e3, 3.396e3, 3.881e3],
        [71, 0.0020236, 3.352e3, 3.890e3, 3.307e3, 3.838e3],
        [71, 0.0022635, 2.969e3, 3.155e3, 2.931e3, 3.115e3],
        [71, 0.0024912, 2.531e3, 2.640e3, 2.499e3, 2.607e3],
        [71, 0.0092441, 1.049e2, 2.703e2, 9.994e1, 2.324e2],
        [71, 0.0103486, 2.019e2, 2.757e2, 1.756e2, 2.310e2],
        [71, 0.0108704, 2.450e2, 2.826e2, 2.065e2, 2.369e2],
        [71, 0.0633138, 2.874, 1.305e1, 2.339, 3.770],
        [72, 0.0016617, 1.203e3, 1.505e3, 1.192e3, 1.489e3],
        [72, 0.0017164, 3.273e3, 3.682e3, 3.225e3, 3.628e3],
        [72, 0.0021076, 3.152e3, 3.659e3, 3.108e3, 3.607e3],
        [72, 0.0023654, 2.769e3, 2.943e3, 2.731e3, 2.903e3],
        [72, 0.0026009, 2.363e3, 2.465e3, 2.331e3, 2.432e3],
        [72, 0.0095607, 9.997e1, 2.557e2, 9.510e1, 2.184e2],
        [72, 0.0107394, 1.894e2, 2.589e2, 1.639e2, 2.151e2],
        [72, 0.0112707, 2.306e2, 2.659e2, 1.928e2, 2.212e2],
        [72, 0.0653508, 2.751, 1.237e1, 2.228, 3.557],
        [73, 0.0017351, 1.154e3, 1.417e3, 1.144e3, 1.401e3],
        [73, 0.0017932, 3.082e3, 3.421e3, 3.034e3, 3.367e3],
        [73, 0.002194, 2.985e3, 3.464e3, 2.939e3, 3.411e3],
        [73, 0.0024687, 2.604e3, 2.768e3, 2.566e3, 2.727e3],
        [73, 0.002708, 2.233e3, 2.329e3, 2.201e3, 2.296e3],
        [73, 0.0098811, 9.599e1, 2.443e2, 9.117e1, 2.073e2],
        [73, 0.0111361, 1.791e2, 2.449e2, 1.540e2, 2.018e2],
        [73, 0.0116815, 2.182e2, 2.518e2, 1.811e2, 2.077e2],
        [73, 0.0674164, 2.652, 1.180e1, 2.139, 3.379],
        [74, 0.0018092, 1.108e3, 1.327e3, 1.097e3, 1.311e3],
        [74, 0.0018716, 2.901e3, 3.170e3, 2.853e3, 3.116e3],
        [74, 0.002281, 2.828e3, 3.279e3, 2.781e3, 3.226e3],
        [74, 0.0025749, 2.445e3, 2.599e3, 2.407e3, 2.558e3],
        [74, 0.0028196, 2.104e3, 2.194e3, 2.071e3, 2.160e3],
        [74, 0.0102068, 9.201e1, 2.334e2, 8.724e1, 1.966e2],
        [74, 0.011544, 1.689e2, 2.312e2, 1.444e2, 1.889e2],
        [74, 0.0120998, 2.065e2, 2.382e2, 1.699e2, 1.948e2],
        [74, 0.069525, 2.552, 1.123e1, 2.049, 3.212],
        [75, 0.0018224, 1.147e3, 1.152e3, 1.135e3, 1.141e3],
        [75, 0.0019489, 2.689e3, 3.802e3, 2.642e3, 3.730e3],
        [75, 0.0023673, 2.696e3, 3.124e3, 2.648e3, 3.069e3],
        [75, 0.0026816, 2.309e3, 2.454e3, 2.270e3, 2.412e3],
        [75, 0.0029317, 1.992e3, 2.078e3, 1.959e3, 2.043e3],
        [75, 0.0105353, 8.858e1, 2.234e2, 8.386e1, 1.869e2],
        [75, 0.0119587, 1.600e2, 2.191e2, 1.360e2, 1.776e2],
        [75, 0.0125267, 1.961e2, 2.262e2, 1.600e2, 1.834e2],
        [75, 0.0716764, 2.464, 1.073e1, 1.970, 3.058],
        [76, 0.0019601, 1.023e3, 2.003e3, 1.012e3, 1.969e3],
        [76, 0.0020308, 2.622e3, 2.864e3, 2.573e3, 2.810e3],
        [76, 0.0024572, 2.546e3, 2.948e3, 2.498e3, 2.893e3],
        [76, 0.0027922, 2.161e3, 2.296e3, 2.123e3, 2.255e3],
        [76, 0.0030485, 1.869e3, 1.949e3, 1.836e3, 1.915e3],
        [76, 0.0108709, 8.458e1, 2.121e2, 7.994e1, 1.762e2],
        [76, 0.012385, 1.503e2, 2.060e2, 1.271e2, 1.654e2],
        [76, 0.012968, 1.846e2, 2.129e2, 1.494e2, 1.711e2],
        [76, 0.0738708, 2.360, 1.016e1, 1.879, 2.888],
        [77, 0.0020404, 9.882e2, 1.066e3, 9.771e2, 1.053e3],
        [77, 0.0021161, 2.478e3, 2.608e3, 2.429e3, 2.556e3],
        [77, 0.0025507, 2.424e3, 2.800e3, 2.376e3, 2.744e3],
        [77, 0.0029087, 2.041e3, 2.166e3, 2.002e3, 2.125e3],
        [77, 0.0031737, 1.767e3, 1.843e3, 1.734e3, 1.809e3],
        [77, 0.0112154, 8.155e1, 2.038e2, 7.695e1, 1.681e2],
        [77, 0.0128241, 1.426e2, 1.959e2, 1.199e2, 1.559e2],
        [77, 0.0134185, 1.756e2, 2.025e2, 1.409e2, 1.613e2],
        [77, 0.076111, 2.284, 9.728, 1.810, 2.758],
        [78, 0.0021216, 9.506e2, 1.034e3, 9.393e2, 1.021e3],
        [78, 0.0022019, 2.341e3, 2.487e3, 2.292e3, 2.434e3],
        [78, 0.0026454, 2.307e3, 2.663e3, 2.258e3, 2.606e3],
        [78, 0.0030265, 1.923e3, 2.041e3, 1.884e3, 2.000e3],
        [78, 0.003296, 1.671e3, 1.742e3, 1.637e3, 1.707e3],
        [78, 0.0115637, 7.844e1, 1.946e2, 7.388e1, 1.594e2],
        [78, 0.0132726, 1.349e2, 1.853e2, 1.127e2, 1.463e2],
        [78, 0.0138799, 1.666e2, 1.921e2, 1.325e2, 1.517e2],
        [78, 0.0783948, 2.203, 9.301, 1.738, 2.627],
        [79, 0.0022057, 9.187e2, 9.971e2, 9.074e2, 9.836e2],
        [79, 0.0022911, 2.258e3, 2.389e3, 2.208e3, 2.336e3],
        [79, 0.002743, 2.203e3, 2.541e3, 2.154e3, 2.484e3],
        [79, 0.0031478, 1.822e3, 1.933e3, 1.783e3, 1.892e3],
        [79, 0.0034249, 1.585e3, 1.652e3, 1.552e3, 1.618e3],
        [79, 0.0119187, 7.582e1, 1.870e2, 7.129e1, 1.521e2],
        [79, 0.0137336, 1.283e2, 1.764e2, 1.066e2, 1.379e2],
        [79, 0.0143528, 1.588e2, 1.830e2, 1.252e2, 1.432e2],
        [79, 0.0807249, 2.137, 8.904, 1.678, 2.512],
        [80, 0.0022949, 8.773e2, 9.925e2, 8.660e2, 9.778e2],
        [80, 0.0023849, 2.151e3, 2.316e3, 2.101e3, 2.261e3],
        [80, 0.0028471, 2.080e3, 2.400e3, 2.030e3, 2.343e3],
        [80, 0.0032785, 1.704e3, 1.808e3, 1.666e3, 1.767e3],
        [80, 0.0035616, 1.486e3, 1.549e3, 1.454e3, 1.515e3],
        [80, 0.0122839, 7.266e1, 1.780e2, 6.821e1, 1.437e2],
        [80, 0.0142087, 1.209e2, 1.663e2, 9.988e1, 1.289e2],
        [80, 0.0148393, 1.501e2, 1.728e2, 1.173e2, 1.340e2],
        [80, 0.0831023, 2.055, 8.464, 1.607, 2.384],
        [81, 0.0023893, 8.352e2, 1.136e3, 8.240e2, 1.115e3],
        [81, 0.0024851, 2.049e3, 2.364e3, 1.999e3, 2.303e3],
        [81, 0.0029566, 1.958e3, 2.267e3, 1.910e3, 2.210e3],
        [81, 0.0034157, 1.591e3, 1.687e3, 1.553e3, 1.647e3],
        [81, 0.0037041, 1.392e3, 1.452e3, 1.360e3, 1.419e3],
        [81, 0.0126575, 6.957e1, 1.693e2, 6.521e1, 1.357e2],
        [81, 0.0146979, 1.139e2, 1.572e2, 9.356e1, 1.207e2],
        [81, 0.0153467, 1.416e2, 1.632e2, 1.097e2, 1.254e2],
        [81, 0.0855304, 1.976, 8.046, 1.539, 2.264],
        [82, 0.002484, 8.006e2, 1.397e3, 7.895e2, 1.366e3],
        [82, 0.0025856, 1.944e3, 2.458e3, 1.895e3, 2.390e3],
        [82, 0.0030664, 1.857e3, 2.146e3, 1.808e3, 2.090e3],
        [82, 0.0035542, 1.496e3, 1.585e3, 1.459e3, 1.546e3],
        [82, 0.0038507, 1.311e3, 1.368e3, 1.279e3, 1.335e3],
        [82, 0.0130352, 6.701e1, 1.621e2, 6.270e1, 1.291e2],
        [82, 0.0152, 1.078e2, 1.485e2, 8.807e1, 1.131e2],
        [82, 0.0158608, 1.344e2, 1.548e2, 1.032e2, 1.180e2],
        [82, 0.0880045, 1.910, 7.683, 1.482, 2.160],
        [83, 0.0025796, 7.724e2, 1.777e3, 7.612e2, 1.731e3],
        [83, 0.0026876, 1.852e3, 2.576e3, 1.802e3, 2.500e3],
        [83, 0.0031769, 1.774e3, 2.048e3, 1.725e3, 1.992e3],
        [83, 0.0036963, 1.415e3, 1.498e3, 1.378e3, 1.460e3],
        [83, 0.0039991, 1.243e3, 1.297e3, 1.211e3, 1.264e3],
        [83, 0.0134186, 6.491e1, 1.560e2, 6.064e1, 1.234e2],
        [83, 0.0157111, 1.027e2, 1.416e2, 8.346e1, 1.069e2],
        [83, 0.0163875, 1.282e2, 1.478e2, 9.769e1, 1.116e2],
        [83, 0.0905259, 1.856, 7.380, 1.434, 2.073],
        [84, 0.002683, 7.482e2, 2.206e3, 7.369e2, 2.142e3],
        [84, 0.002798, 1.775e3, 2.711e3, 1.726e3, 2.625e3],
        [84, 0.0033019, 1.693e3, 1.956e3, 1.645e3, 1.900e3],
        [84, 0.0038541, 1.339e3, 1.419e3, 1.303e3, 1.381e3],
        [84, 0.0041494, 1.190e3, 1.242e3, 1.158e3, 1.209e3],
        [84, 0.0138138, 6.337e1, 1.513e2, 5.910e1, 1.189e2],
        [84, 0.0162443, 9.849e1, 1.361e2, 7.965e1, 1.019e2],
        [84, 0.0169393, 1.232e2, 1.420e2, 9.308e1, 1.063e2],
        [84, 0.093105, 1.820, 7.140, 1.400, 2.005],
        [85, 0.001042, 5.435e3, 5.551e3, 5.420e3, 5.537e3],
        [85, 0.0027867, 7.225e2, 2.431e3, 7.112e2, 2.355e3],
        [85, 0.0029087, 1.686e3, 2.763e3, 1.638e3, 2.671e3],
        [85, 0.003426, 1.614e3, 1.866e3, 1.566e3, 1.811e3],
        [85, 0.004008, 1.269e3, 1.345e3, 1.233e3, 1.308e3],
        [85, 0.004317, 1.126e3, 1.175e3, 1.095e3, 1.142e3],
        [85, 0.0142135, 6.162e1, 1.461e2, 5.738e1, 1.140e2],
        [85, 0.0167847, 9.417e1, 1.302e2, 7.576e1, 9.670e1],
        [85, 0.017493, 1.181e2, 1.360e2, 8.847e1, 1.010e2],
        [85, 0.0957299, 1.777, 6.895, 1.361, 1.935],
        [86, 0.001097, 4.909e3, 5.013e3, 4.895e3, 5.000e3],
        [86, 0.0028924, 6.634e2, 2.319e3, 6.526e2, 2.243e3],
        [86, 0.0030215, 1.524e3, 2.470e3, 1.479e3, 2.384e3],
        [86, 0.003538, 1.479e3, 1.710e3, 1.433e3, 1.657e3],
        [86, 0.004159, 1.148e3, 1.217e3, 1.115e3, 1.182e3],
        [86, 0.004482, 1.017e3, 1.061e3, 9.877e2, 1.031e3],
        [86, 0.0146194, 5.697e1, 1.344e2, 5.296e1, 1.042e2],
        [86, 0.0173371, 8.557e1, 1.185e2, 6.851e1, 8.724e1],
        [86, 0.018049, 1.077e2, 1.241e2, 8.002e1, 9.130e1],
        [86, 0.098404, 1.649, 6.371, 1.258, 1.779],
        [87, 0.001153, 4.673e3, 4.772e3, 4.659e3, 4.758e3],
        [87, 0.0029999, 6.414e2, 1.995e3, 6.306e2, 1.929e3],
        [87, 0.0031362, 1.449e3, 2.255e3, 1.405e3, 2.175e3],
        [87, 0.003663, 1.415e3, 1.641e3, 1.370e3, 1.588e3],
        [87, 0.004327, 1.086e3, 1.153e3, 1.053e3, 1.118e3],
        [87, 0.004652, 9.666e2, 1.008e3, 9.377e2, 9.780e2],
        [87, 0.0150312, 5.544e1, 1.304e2, 5.146e1, 1.003e2],
        [87, 0.0179065, 8.184e1, 1.137e2, 6.521e1, 8.299e1],
        [87, 0.018639, 1.031e2, 1.187e2, 7.602e1, 8.666e1],
        [87, 0.101137, 1.610, 6.089, 1.224, 1.710],
        [88, 0.0010576, 5.602e3, 5.683e3, 5.588e3, 5.669e3],
        [88, 0.0012084, 4.424e3, 4.516e3, 4.411e3, 4.502e3],
        [88, 0.0031049, 6.169e2, 1.715e3, 6.061e2, 1.657e3],
        [88, 0.0032484, 1.374e3, 2.039e3, 1.331e3, 1.965e3],
        [88, 0.0037918, 1.342e3, 1.558e3, 1.297e3, 1.506e3],
        [88, 0.0044895, 1.024e3, 1.086e3, 9.917e2, 1.052e3],
        [88, 0.004822, 9.129e2, 9.522e2, 8.846e2, 9.228e2],
        [88, 0.0154444, 5.355e1, 1.253e2, 4.962e1, 9.581e1],
        [88, 0.0184843, 7.766e1, 1.081e2, 6.160e1, 7.835e1],
        [88, 0.0192367, 9.799e1, 1.128e2, 7.175e1, 8.172e1],
        [88, 0.103922, 1.560, 5.826, 1.181, 1.638],
        [89, 0.00108, 5.622e3, 5.702e3, 5.608e3, 5.688e3],
        [89, 0.001269, 4.203e3, 4.289e3, 4.190e3, 4.275e3],
        [89, 0.003219, 5.959e2, 1.537e3, 5.851e2, 1.485e3],
        [89, 0.0033702, 1.307e3, 1.892e3, 1.264e3, 1.822e3],
        [89, 0.003909, 1.296e3, 1.504e3, 1.252e3, 1.453e3],
        [89, 0.004656, 9.745e2, 1.034e3, 9.428e2, 1.000e3],
        [89, 0.005002, 8.678e2, 9.051e2, 8.399e2, 8.761e2],
        [89, 0.015871, 5.213e1, 1.214e2, 4.823e1, 9.224e1],
        [89, 0.0190832, 7.426e1, 1.036e2, 5.865e1, 7.448e1],
        [89, 0.01984, 9.403e1, 1.082e2, 6.831e1, 7.774e1],
        [89, 0.106756, 1.525, 5.622, 1.150, 1.582],
        [90, 0.0011683, 4.976e3, 5.048e3, 4.962e3, 5.034e3],
        [90, 0.0013295, 3.937e3, 4.017e3, 3.924e3, 4.003e3],
        [90, 0.003332, 5.671e2, 1.394e3, 5.565e2, 1.346e3],
        [90, 0.0034908, 1.226e3, 1.749e3, 1.185e3, 1.683e3],
        [90, 0.0040461, 1.217e3, 1.415e3, 1.174e3, 1.364e3],
        [90, 0.0048304, 9.103e2, 9.655e2, 8.797e2, 9.330e2],
        [90, 0.0051823, 8.129e2, 8.477e2, 7.859e2, 8.196e2],
        [90, 0.0163003, 4.991e1, 1.156e2, 4.611e1, 8.732e1],
        [90, 0.0196932, 6.984e1, 9.527e1, 5.492e1, 6.836e1],
        [90, 0.0204721, 8.851e1, 1.018e2, 6.383e1, 7.259e1],
        [90, 0.109651, 1.465, 5.336, 1.100, 1.502],
        [91, 0.0010067, 6.451e3, 6.868e3, 6.437e3, 6.853e3],
        [91, 0.0012243, 4.794e3, 4.863e3, 4.780e3, 4.848e3],
        [91, 0.0013871, 3.815e3, 3.891e3, 3.801e3, 3.877e3],
        [91, 0.0034418, 5.548e2, 1.363e3, 5.440e2, 1.314e3],
        [91, 0.0036112, 1.185e3, 1.695e3, 1.144e3, 1.628e3],
        [91, 0.0041738, 1.182e3, 1.374e3, 1.139e3, 1.324e3],
        [91, 0.0050009, 8.755e2, 9.288e2, 8.450e2, 8.964e2],
        [91, 0.0053669, 7.810e2, 8.144e2, 7.541e2, 7.864e2],
        [91, 0.0167331, 4.903e1, 1.130e2, 4.522e1, 8.483e1],
        [91, 0.0203137, 6.747e1, 9.452e1, 5.284e1, 6.704e1],
        [91, 0.0211046, 8.576e1, 9.861e1, 6.153e1, 6.990e1],
        [91, 0.112601, 1.445, 5.198, 1.081, 1.466],
        [92, 0.0010449, 6.127e3, 6.519e3, 6.112e3, 6.504e3],
        [92, 0.0012726, 4.526e3, 4.589e3, 4.511e3, 4.575e3],
        [92, 0.0014408, 3.598e3, 3.668e3, 3.584e3, 3.654e3],
        [92, 0.0035517, 5.257e2, 1.266e3, 5.151e2, 1.220e3],
        [92, 0.0037276, 1.112e3, 1.582e3, 1.072e3, 1.517e3],
        [92, 0.0043034, 1.110e3, 1.292e3, 1.068e3, 1.242e3],
        [92, 0.0051822, 8.118e2, 8.611e2, 7.825e2, 8.301e2],
        [92, 0.005548, 7.282e2, 7.592e2, 7.022e2, 7.322e2],
        [92, 0.0171663, 4.663e1, 1.070e2, 4.293e1, 7.980e1],
        [92, 0.0209476, 6.300e1, 8.838e1, 4.914e1, 6.222e1],
        [92, 0.0217574, 8.023e1, 9.222e1, 5.715e1, 6.487e1],
        [92, 0.115606, 1.378, 4.893, 1.027, 1.382],
        [93, 1.087e-3, 6.00e3, 6.38e3, 0, 0],
        [93, 1.328e-3, 4.38e3, 4.44e3, 0, 0],
        [93, 1.501e-3, 3.49e3, 3.55e3, 0, 0],
        [93, 3.666e-3, 5.15e2, 1.22e3, 0, 0],
        [93, 3.850e-3, 1.08e3, 1.52e3, 0, 0],
        [93, 4.435e-3, 1.08e3, 1.26e3, 0, 0],
        [93, 5.366e-3, 7.80e2, 8.27e2, 0, 0],
        [93, 5.723e-3, 7.06e2, 7.36e2, 0, 0],
        [93, 1.761e-2, 4.59e1, 1.05e2, 0, 0],
        [93, 2.160e-2, 6.08e1, 8.55e1, 0, 0],
        [93, 2.243e-2, 7.76e1, 8.92e1, 0, 0],
        [93, 1.187e-1, 1.36, 4.77, 0, 0],
        [94, 1.115e-3, 5.94e3, 6.32e3, 0, 0],
        [94, 1.372e-3, 4.27e3, 4.32e3, 0, 0],
        [94, 1.559e-3, 3.35e3, 3.42e3, 0, 0],
        [94, 3.778e-3, 4.99e2, 1.18e3, 0, 0],
        [94, 3.973e-3, 1.03e3, 1.40e3, 0, 0],
        [94, 4.557e-3, 1.04e3, 1.21e3, 0, 0],
        [94, 5.541e-3, 7.43e2, 7.88e2, 0, 0],
        [94, 5.933e-3, 6.67e2, 6.95e2, 0, 0],
        [94, 1.806e-2, 4.45e1, 1.01e2, 0, 0],
        [94, 2.227e-2, 5.80e1, 8.17e1, 0, 0],
        [94, 2.310e-2, 7.44e1, 8.54e1, 0, 0],
        [94, 1.218e-1, 1.32, 4.59, 0, 0],
        [95, 1.14e-03, 5.90e03, 6.27e03, 0, 0],  # 5-N3
        [95, 1.41e-03, 4.15e03, 4.20e03, 0, 0],  # 95-N2
        [95, 1.62e-03, 3.20e03, 3.26e03, 0, 0],  # 95-N1
        [95, 3.89e-03, 4.81e02, 1.11e03, 0, 0],  # 95-M5
        [95, 4.09e-03, 9.85e02, 1.39e03, 0, 0],  # 95-M4
        [95, 4.67e-03, 1.01e03, 1.17e03, 0, 0],  # 95-M3
        [95, 5.71e-03, 7.07e02, 7.49e02, 0, 0],  # 95-M2
        [95, 6.12e-03, 6.32e02, 6.58e02, 0, 0],  # 95-M1
        [95, 1.85e-02, 4.30e01, 9.70e01, 0, 0],  # 95-L3
        [95, 2.29e-02, 5.50e01, 7.75e01, 0, 0],  # 95-L2
        [95, 2.38e-02, 7.07e01, 8.12e01, 0, 0],  # 95-L1
        [95, 1.25e-01, 1.28e00, 4.38e00, 0, 0],  # 95-K
        [96, 1.15e-03, 5.88e03, 6.24e03, 0, 0],  # 96-N3
        [96, 1.44e-03, 4.10e03, 4.19e03, 0, 0],  # 96-N2
        [96, 1.64e-03, 3.18e03, 3.24e03, 0, 0],  # 96-N1
        [96, 3.97e-03, 4.71e02, 1.05e03, 0, 0],  # 96-M5
        [96, 4.23e-03, 9.32e02, 1.30e03, 0, 0],  # 96-M4
        [96, 4.80e-03, 9.65e02, 1.12e03, 0, 0],  # 96-M3
        [96, 5.90e-03, 6.69e02, 7.09e02, 0, 0],  # 96-M2
        [96, 6.29e-03, 6.05e02, 6.30e02, 0, 0],  # 96-M1
        [96, 1.89e-02, 4.16e01, 9.35e01, 0, 0],  # 96-L3
        [96, 2.38e-02, 5.12e01, 7.22e01, 0, 0],  # 96-L2
        [96, 2.45e-02, 6.73e01, 7.72e01, 0, 0],  # 96-L1
        [96, 1.28e-01, 1.24e00, 4.18e00, 0, 0],  # 96-K
        [97, 1.24e-03, 5.41e03, 5.75e03, 0, 0],  # 97-N3
        [97, 1.55e-03, 3.68e03, 3.73e03, 0, 0],  # 97-N2
        [97, 1.76e-03, 2.90e03, 2.96e03, 0, 0],  # 97-N1
        [97, 4.13e-03, 4.50e02, 9.93e02, 0, 0],  # 97-M5
        [97, 4.37e-03, 8.97e02, 1.24e03, 0, 0],  # 97-M4
        [97, 4.98e-03, 9.16e02, 1.07e03, 0, 0],  # 97-M3
        [97, 6.15e-03, 6.28e02, 6.65e02, 0, 0],  # 97-M2
        [97, 6.56e-03, 5.68e02, 5.91e02, 0, 0],  # 97-M1
        [97, 1.95e-02, 4.05e01, 9.09e01, 0, 0],  # 97-L3
        [97, 2.44e-02, 5.00e01, 7.07e01, 0, 0],  # 97-L2
        [97, 2.53e-02, 6.43e01, 7.38e01, 0, 0],  # 97-L1
        [97, 1.32e-01, 1.22e00, 4.06e00, 0, 0],  # 97-K
        [98, 1.28e-03, 5.20e03, 5.54e03, 0, 0],  # 98-N3
        [98, 1.62e-03, 3.50e03, 3.54e03, 0, 0],  # 98-N2
        [98, 1.80e-03, 2.84e03, 2.89e03, 0, 0],  # 98-N1
        [98, 4.25e-03, 4.32e02, 9.55e02, 0, 0],  # 98-M5
        [98, 4.50e-03, 8.55e02, 1.18e03, 0, 0],  # 98-M4
        [98, 5.11e-03, 8.79e02, 1.02e03, 0, 0],  # 98-M3
        [98, 6.36e-03, 5.90e02, 6.25e02, 0, 0],  # 98-M2
        [98, 6.75e-03, 5.39e02, 5.61e02, 0, 0],  # 98-M1
        [98, 1.99e-02, 3.91e01, 8.61e01, 0, 0],  # 98-L3
        [98, 2.53e-02, 4.66e01, 6.60e01, 0, 0],  # 98-L2
        [98, 2.61e-02, 6.06e01, 6.95e01, 0, 0],  # 98-L1
        [98, 1.36e-01, 1.16e00, 3.81e00, 0, 0],  # 98-K
        [99, 1.03e-03, 7.41e03, 7.64e03, 0, 0],  # 99-N4
        [99, 1.32e-03, 5.08e03, 5.41e03, 0, 0],  # 99-N3
        [99, 1.68e-03, 3.36e03, 3.40e03, 0, 0],  # 99-N2
        [99, 1.87e-03, 2.73e03, 2.77e03, 0, 0],  # 99-N1
        [99, 4.37e-03, 4.21e02, 9.16e02, 0, 0],  # 99-M5
        [99, 4.63e-03, 8.24e02, 1.14e03, 0, 0],  # 99-M4
        [99, 5.25e-03, 8.49e02, 9.90e02, 0, 0],  # 99-M3
        [99, 6.57e-03, 5.63e02, 5.96e02, 0, 0],  # 99-M2
        [99, 6.98e-03, 5.15e02, 5.36e02, 0, 0],  # 99-M1
        [99, 2.04e-02, 3.81e01, 8.46e01, 0, 0],  # 99-L3
        [99, 2.60e-02, 4.46e01, 6.33e01, 0, 0],  # 99-L2
        [99, 2.69e-02, 5.81e01, 6.67e01, 0, 0],  # 99-L1
        [99, 1.40e-01, 1.13e00, 3.68e00, 0, 0],  # 99-K
        [100, 1.00e-03, 7.11e03, 7.42e03, 0, 0],  # [100-N5
        [100, 1.07e-03, 7.11e03, 7.32e03, 0, 0],  # [100-N4
        [100, 1.37e-03, 4.87e03, 5.18e03, 0, 0],  # [100-N3
        [100, 1.75e-03, 3.17e03, 3.21e03, 0, 0],  # [100-N2
        [100, 1.94e-03, 2.58e03, 2.63e03, 0, 0],  # [100-N1
        [100, 4.50e-03, 4.03e02, 8.66e02, 0, 0],  # [100-M5
        [100, 4.77e-03, 7.83e02, 1.07e03, 0, 0],  # [100-M4
        [100, 5.40e-03, 8.09e02, 9.43e02, 0, 0],  # [100-M3
        [100, 6.79e-03, 5.28e02, 5.59e02, 0, 0],  # [100-M2
        [100, 7.21e-03, 4.83e02, 5.03e02, 0, 0],  # [100-M1
        [100, 2.09e-02, 3.66e01, 8.10e01, 0, 0],  # [100-L3
        [100, 2.68e-02, 4.21e01, 5.98e01, 0, 0],  # [100-L2
        [100, 2.77e-02, 5.50e01, 6.30e01, 0, 0],  # 100-L1
        [100, 1.43e-01, 1.09e00, 3.50e00, 0, 0],
    ]
)  # [100-K
# Table of physical properties of elements
# Z/A, Density, Names
PropsEl = np.array(
    [
        [0.99212, 8.375e-005, "H", "Hydrogen"],
        [0.49968, 1.663e-004, "He", "Helium"],
        [0.43221, 5.340e-001, "Li", "Lithium"],
        [0.44384, 1.848e000, "Be", "Beryllium"],
        [0.46245, 2.370e000, "B", "Boron"],
        [0.49954, 1.700e000, "C", "Carbon"],
        [0.49976, 1.165e-003, "N", "Nitrogen"],
        [0.50002, 1.332e-003, "O", "Oxygen"],
        [0.47372, 1.580e-003, "F", "Fluorine"],
        [0.49555, 8.385e-004, "Ne", "Neon"],
        [0.47847, 9.710e-001, "Na", "Sodium"],
        [0.49373, 1.740e000, "Mg", "Magnesium"],
        [0.48181, 2.699e000, "Al", "Aluminum"],
        [0.49848, 2.330e000, "Si", "Silicon"],
        [0.48428, 2.200e000, "P", "Phosphorus"],
        [0.49897, 2.000e000, "S", "Sulfur"],
        [0.47951, 2.995e-003, "Cl", "Chlorine"],
        [0.45059, 1.662e-003, "Ar", "Argon"],
        [0.48595, 8.620e-001, "K", "Potassium"],
        [0.49903, 1.550e000, "Ca", "Calcium"],
        [0.46712, 2.989e000, "Sc", "Scandium"],
        [0.45948, 4.540e000, "Ti", "Titanium"],
        [0.45150, 6.110e000, "V", "Vanadium"],
        [0.46157, 7.180e000, "Cr", "Chromium"],
        [0.45506, 7.440e000, "Mn", "Manganese"],
        [0.46556, 7.874e000, "Fe", "Iron"],
        [0.45815, 8.900e000, "Co", "Cobalt"],
        [0.47708, 8.902e000, "Ni", "Nickel"],
        [0.45636, 8.960e000, "Cu", "Copper"],
        [0.45879, 7.133e000, "Zn", "Zinc"],
        [0.44462, 5.904e000, "Ga", "Gallium"],
        [0.44071, 5.323e000, "Ge", "Germanium"],
        [0.44046, 5.730e000, "As", "Arsenic"],
        [0.43060, 4.500e000, "Se", "Selenium"],
        [0.43803, 7.072e-003, "Br", "Bromine"],
        [0.42959, 3.478e-003, "Kr", "Krypton"],
        [0.43291, 1.532e000, "Rb", "Rubidium"],
        [0.43369, 2.540e000, "Sr", "Strontium"],
        [0.43867, 4.469e000, "Y", "Yttrium"],
        [0.43848, 6.506e000, "Zr", "Zirconium"],
        [0.44130, 8.570e000, "Nb", "Niobium"],
        [0.43777, 1.022e001, "Mo", "Molybdenum"],
        [0.43919, 1.150e001, "Tc", "Technetium"],
        [0.43534, 1.241e001, "Ru", "Ruthenium"],
        [0.43729, 1.241e001, "Rh", "Rhodium"],
        [0.43225, 1.202e001, "Pd", "Palladium"],
        [0.43572, 1.050e001, "Ag", "Silver"],
        [0.42700, 8.650e000, "Cd", "Cadmium"],
        [0.42676, 7.310e000, "In", "Indium"],
        [0.42120, 7.310e000, "Sn", "Tin"],
        [0.41889, 6.691e000, "Sb", "Antimony"],
        [0.40752, 6.240e000, "Te", "Tellurium"],
        [0.41764, 4.930e000, "I", "Iodine"],
        [0.41130, 5.485e-003, "Xe", "Xenon"],
        [0.41383, 1.873e000, "Cs", "Cesium"],
        [0.40779, 3.500e000, "Ba", "Barium"],
        [0.41035, 6.154e000, "La", "Lanthanum"],
        [0.41395, 6.657e000, "Ce", "Cerium"],
        [0.41871, 6.710e000, "Pr", "Praseodymium"],
        [0.41597, 6.900e000, "Nd", "Neodymium"],
        [0.42094, 7.220e000, "Pm", "Promethium"],
        [0.41234, 7.460e000, "Sm", "Samarium"],
        [0.41457, 5.243e000, "Eu", "Europium"],
        [0.40699, 7.900e000, "Gd", "Gadolinium"],
        [0.40900, 8.229e000, "Tb", "Terbium"],
        [0.40615, 8.550e000, "Dy", "Dysprosium"],
        [0.40623, 8.795e000, "Ho", "Holmium"],
        [0.40655, 9.066e000, "Er", "Erbium"],
        [0.40844, 9.321e000, "Tm", "Thulium"],
        [0.40453, 6.730e000, "Yb", "Ytterbium"],
        [0.40579, 9.840e000, "Lu", "Lutetium"],
        [0.40338, 1.331e001, "Hf", "Hafnium"],
        [0.40343, 1.665e001, "Ta", "Tantalum"],
        [0.40250, 1.930e001, "W", "Tungsten"],
        [0.40278, 2.102e001, "Re", "Rhenium"],
        [0.39958, 2.257e001, "Os", "Osmium"],
        [0.40058, 2.242e001, "Ir", "Iridium"],
        [0.39984, 2.145e001, "Pt", "Platinum"],
        [0.40108, 1.932e001, "Au", "Gold"],
        [0.39882, 1.355e001, "Hg", "Mercury"],
        [0.39631, 1.172e001, "Tl", "Thallium"],
        [0.39575, 1.135e001, "Pb", "Lead"],
        [0.39717, 9.747e000, "Bi", "Bismuth"],
        [0.40195, 9.320e000, "Po", "Polonium"],
        [0.40479, 1.000e001, "At", "Astatine"],
        [0.38736, 9.066e-003, "Rn", "Radon"],
        [0.39010, 1.000e001, "Fr", "Francium"],
        [0.38934, 5.000e000, "Ra", "Radium"],
        [0.39202, 1.007e001, "Ac", "Actinium"],
        [0.38787, 1.172e001, "Th", "Thorium"],
        [0.39388, 1.537e001, "Pa", "Protactinium"],
        [0.38651, 1.895e001, "U", "Uranium"],
        [0.39233, 2.030e001, "Np", "Neptunium"],
        [0.38514, 1.984e001, "Pu", "Plutonium"],
        [0.39085, 1.370e001, "Am", "Americium"],
        [0.38855, 1.350e001, "Cm", "Curium"],
        [0.39260, 1.400e001, "Bk", "Berkelium"],
        [0.39031, 1.000e001, "Cf", "Californium"],
        [0.39273, 8.840e000, "Es", "Einsteinium"],
        [0.38896, 0, "Fm", "Fermium"],
    ]
)  # last element
# Table of physical properties of some compounds and mixtures.
# 48 substances of dosimetric interest (NIST) are included.
# Z/A, Density, Names, Composition
PropsMix = np.array(
    [
        [
            0.54903,
            1.127e000,
            "A-150",
            "A-150 TISSUE-EQUIVALENT PLASTIC",
            "H(0.101327)C(0.775501)N(0.035057)O(0.052316)F(0.017422)Ca(0.018378)",
        ],
        [0.55097, 7.899e-001, "", "ACETONE", "C3H6O"],
        [0.53768, 1.097e-003, "", "ACETYLENE", "C2H2"],
        [0.51803, 1.350e000, "", "ADENINE", "C5H5N5"],
        [
            0.55847,
            9.500e-001,
            "ADIPOSE TISSUE",
            "ADIPOSE TISSUE (ICRP)",
            "H(0.119477)C(0.637240)N(0.007970)O(0.232333)Na(0.000500)Mg(0.000020)P(0.000160)S(0.000730)Cl(0.001190)K(0.000320)Ca(0.000020)Fe(0.000020)Zn(0.000020)",
        ],
        [
            0.49919,
            1.205e-003,
            "Air",
            "AIR, DRY (NEAR SEA LEVEL)",
            "C(0.000124)N(0.755267)O(0.231781)Ar(0.012827)",
        ],
        [0.53876, 1.420e000, "", "ALANINE", "C3H7NO2"],
        [0.49038, 3.970e000, "", "ALUMINUM OXIDE", "Al2O3"],
        [0.55178, 1.100e000, "", "AMBER", "C10H16O"],
        [0.51129, 8.260e-004, "", "AMMONIA", "NH3"],
        [0.53690, 1.024e000, "", "ANILINE", "C6H7N"],
        [0.52740, 1.283e000, "", "ANTHRACENE", "C14H10"],
        [
            0.52740,
            1.450e000,
            "B-100",
            "B-100 BONE-EQUIVALENT PLASTIC",
            "H(0.065471)C(0.536945)N(0.021500)O(0.032085)F(0.167411)Ca(0.176589)",
        ],
        [0.52792, 1.250e000, "", "BAKELITE", "H(0.057441)C(0.774591)O(0.167968)"],
        [0.42207, 4.890e000, "", "BARIUM FLUORIDE", "BaF2"],
        [0.44561, 4.500e000, "", "BARIUM SULFATE", "BaSO4"],
        [0.53768, 8.787e-001, "", "BENZENE", "C6H6"],
        [0.47978, 3.010e000, "", "BERYLLIUM OXIDE", "BeO"],
        [0.40961, 7.130e000, "BGO", "BISMUTH GERMANIUM OXIDE", "Bi12GeO20"],
        [
            0.54995,
            1.060e000,
            "Blood",
            "BLOOD (ICRP)",
            "H(0.101866)C(0.100020)N(0.029640)O(0.759414)Na(0.001850)Mg(0.000040)Si(0.000030)P(0.000350)S(0.001850)Cl(0.002780)K(0.001630)Ca(0.000060)Fe(0.000460)Zn(0.000010)",
        ],
        [
            0.53010,
            1.850e000,
            "COMPACT BONE",
            "BONE, COMPACT (ICRU)",
            "H(0.063984)C(0.278000)N(0.027000)O(0.410016)Mg(0.002000)P(0.070000)S(0.002000)Ca(0.147000)",
        ],
        [
            0.52130,
            1.850e000,
            "CORTICAL BONE",
            "BONE, CORTICAL (ICRP)",
            "H(0.047234)C(0.144330)N(0.041990)O(0.446096)Mg(0.002200)P(0.104970)S(0.003150)Ca(0.209930)Zn(0.000100)",
        ],
        [
            0.53010,
            1.920e000,
            "RIB BONE",
            "BONE, RIB",
            "H(0.034000)C(0.155000)N(0.042000)O(0.435000)Mg(0.002000)P(0.103000)S(0.003000)Ca(0.225000)",
        ],
        [0.47058, 2.520e000, "", "BORON CARBIDE", "B4C"],
        [0.48838, 1.812e000, "", "BORON OXIDE", "B2O3"],
        [
            0.55423,
            1.040e000,
            "Brain",
            "BRAIN (ICRP)",
            "H(0.110667)C(0.125420)N(0.013280)O(0.737723)Na(0.001840)Mg(0.000150)P(0.003540)S(0.001770)Cl(0.002360)K(0.003100)Ca(0.000090)Fe(0.000050)Zn(0.000010)",
        ],
        [
            0.55196,
            1.020e000,
            "Breast",
            "Breast Tissue (ICRU)",
            "H(0.106)C(0.332)N(0.03)O(0.527)Na(0.001)P(0.001)S(0.002)Cl(0.001)",
        ],
        [0.58497, 2.493e-003, "", "BUTANE", "C4H10"],
        [0.56663, 8.098e-001, "n-BUTANOL", "N-BUTYL ALCOHOL", "C4H10O"],
        [
            0.49969,
            1.760e000,
            "C-552",
            "C-552 AIR-EQUIVALENT PLASTIC",
            "H(0.024680)C(0.501610)O(0.004527)F(0.465209)Si(0.003973)",
        ],
        [0.41665, 6.200e000, "CdTe", "CADMIUM TELLURIDE", "Cd(0.46836)Te(0.53164)"],
        [0.40749, 7.900e000, "CWO", "CADMIUM TUNGSTATE", "CdWO4"],
        [0.49955, 2.800e000, "", "CALCIUM CARBONATE", "CaCO3"],
        [0.48670, 3.180e000, "", "CALCIUM FLUORIDE", "CaF2"],
        [0.49929, 3.300e000, "", "CALCIUM OXIDE", "O(0.285299)Ca(0.714701)"],
        [0.49950, 2.960e000, "", "CALCIUM SULFATE", "CaSO4"],
        [0.40936, 6.062e000, "", "CALCIUM TUNGSTATE", "CaWO4"],
        [0.49989, 1.842e-003, "", "CARBON DIOXIDE", "CO2"],
        [0.48107, 1.594e000, "", "CARBON TETRACHLORIDE", "CCl4"],
        [0.53040, 1.420e000, "CELLOPHANE", "CELLULOSE ACETATE, CELLOPHANE", "C6H10O5"],
        [0.53279, 1.200e000, "CAB", "CELLULOSE ACETATE BUTYRATE", "C15H22O8"],
        [0.51424, 1.490e000, "Nitrocellulose", "CELLULOSE NITRATE", "C6H8N2O9"],
        [
            0.55278,
            1.030e000,
            "",
            "CERIC SULFATE DOSIMETER SOLUTION",
            "H(0.107596)N(0.000800)O(0.874976)S(0.014627)Ce(0.002001)",
        ],
        [0.42132, 4.115e000, "", "CESIUM FLUORIDE", "CsF"],
        [0.41569, 4.510e000, "", "CESIUM IODIDE", "CsI"],
        [0.48734, 1.106e000, "", "CHLOROBENZENE", "C6H5Cl"],
        [0.51498, 1.483e000, "", "CHLOROFORM", "CHCl3"],
        [
            0.50274,
            2.300e000,
            "Portland Concrete",
            "CONCRETE, PORTLAND",
            "H(0.010000)C(0.001000)O(0.529107)Na(0.016000)Mg(0.002000)Al(0.033872)Si(0.337021)K(0.013000)Ca(0.044000)Fe(0.014000)",
        ],
        [
            0.50932,
            2.300e000,
            "Concrete",
            "Concrete, Ordinary",
            "H(0.0221)C(0.002484)O(0.57493)Na(0.015208)Mg(0.001266)Al(0.019953)Si(0.304627)K(0.010045)Ca(0.042951)Fe(0.006435)",
        ],
        [
            0.45714,
            3.350e000,
            "Barite Concrete",
            "Concrete, Barite",
            "H(0.003585)O(0.311622)Mg(0.001195)Al(0.004183)Si(0.010457)S(0.107858)Ca(0.050194)Fe(0.047505)Ba(0.4634)",
        ],
        [0.57034, 7.790e-001, "", "CYCLOHEXANE", "C6H12"],
        [
            0.49098,
            1.305e000,
            "ortho-dichlorobenzene",
            "1, 2-DICHLOROBENZENE",
            "C6H4Cl2",
        ],
        [0.48616, 1.220e000, "DCDE", "DICHLORODIETHYL ETHER", "C4H8Cl2O"],
        [0.48853, 1.235e000, "EDC", "1, 2-DICHLOROETHANE", "C2H4Cl2"],
        [0.56663, 7.138e-001, "", "DIETHYL ETHER", "C4H10O"],
        [0.54724, 9.487e-001, "", "N,N-DIMETHYL FORMAMIDE", "C3H7NO"],
        [0.53757, 1.101e000, "DMSO", "DIMETHYL SULFOXIDE", "C2H6OS"],
        [0.59862, 1.253e-003, "", "ETHANE", "C2H6"],
        [0.56437, 7.893e-001, "Ethanol", "ETHYL ALCOHOL", "C2H6O"],
        [0.54405, 1.130e000, "", "ETHYL CELLULOSE", "C12H22O5"],
        [0.57034, 1.175e-003, "", "ETHYLENE", "C2H4"],
        [
            0.54877,
            1.100e000,
            "EYE LENS",
            "EYE LENS (ICRP)",
            "H(0.099269)C(0.193710)N(0.053270)O(0.653751)",
        ],
        [0.47592, 5.200e000, "Iron(III) oxide", "FERRIC OXIDE", "Fe2O3"],
        [0.46507, 7.150e000, "", "FERROBORIDE", "FeB"],
        [0.47323, 5.700e000, "Iron(II) oxide", "FERROUS OXIDE", "FeO"],
        [
            0.55328,
            1.024e000,
            "",
            "FERROUS SULFATE DOSIMETER SOLUTION",
            "H(0.108259)N(0.000027)O(0.878636)Na(0.000022)S(0.012968)Cl(0.000034)Fe(0.000054)",
        ],
        [0.47968, 1.120e000, "Dichlorodifluoromethane", "FREON-12", "CCl2F2"],
        [0.44801, 1.800e000, "Dibromodifluoromethane", "FREON-12B2", "CBr2F2"],
        [0.47866, 9.500e-001, "", "FREON-13", "CClF3"],
        [0.45665, 1.500e000, "", "FREON-13B1", "CBrF3"],
        [0.42262, 1.800e000, "", "FREON-13I1", "CIF3"],
        [0.42266, 7.440e000, "", "GADOLINIUM OXYSULFIDE", "Gd2O2S"],
        [0.44247, 5.310e000, "", "GALLIUM ARSENIDE", "GaAs"],
        [
            0.53973,
            1.291e000,
            "",
            "GEL IN PHOTOGRAPHIC EMULSION",
            "H(0.081180)C(0.416060)N(0.111240)O(0.380640)S(0.010880)",
        ],
        [
            0.49707,
            2.230e000,
            "Pyrex Glass",
            "Glass, Borosilicate",
            "B(0.040064)O(0.539562)Na(0.028191)Al(0.011644)Si(0.377220)K(0.003321)",
        ],
        [
            0.42101,
            6.220e000,
            "Lead Glass",
            "GLASS, LEAD",
            "O(0.156453)Si(0.080866)Ti(0.008092)As(0.002651)Pb(0.751938)",
        ],
        [
            0.49731,
            2.400e000,
            "Plate Glass",
            "GLASS, PLATE",
            "O(0.459800)Na(0.096441)Si(0.336553)Ca(0.107205)",
        ],
        [0.53489, 1.540e000, "GLc", "GLUCOSE", "C6H14O7"],
        [0.53371, 1.460e000, "", "GLUTAMINE", "C5H10N2O3"],
        [0.54292, 1.261e000, "Glycerin", "GLYCEROL", "C3H8O3"],
        [0.51612, 1.580e000, "", "GUANINE", "C5H5N5O"],
        [0.50039, 2.320e000, "GYPSUM", "GYPSUM, PLASTER OF PARIS", "H4CaSO6"],
        [0.57882, 6.838e-001, "HEPTANE", "N-HEPTANE", "C7H16"],
        [0.58020, 6.603e-001, "HEXANE", "N-HEXANE", "C6H14"],
        [0.51264, 1.420e000, "", "KAPTON POLYIMIDE FILM", "C22H10N2O5"],
        [0.42588, 6.280e000, "", "LANTHANUM OXYBROMIDE", "LaOBr"],
        [0.42706, 5.860e000, "", "LANTHANUM OXYSULFIDE", "La2OS"],
        [0.40323, 9.530e000, "", "LEAD OXIDE", "PbO"],
        [0.50052, 1.178e000, "", "LITHIUM AMIDE", "LiNH2"],
        [0.48720, 2.110e000, "", "LITHIUM CARBONATE", "Li2CO3"],
        [0.46262, 2.635e000, "", "LITHIUM FLUORIDE", "LiF"],
        [0.50321, 8.200e-001, "", "LITHIUM HYDRIDE", "LiH"],
        [0.41839, 3.494e000, "", "LITHIUM IODIDE", "LiI"],
        [0.46852, 2.013e000, "", "LITHIUM OXIDE", "Li2O"],
        [0.48487, 2.440e000, "", "LITHIUM TETRABORATE", "Li2B4O7"],
        [
            0.54965,
            1.050e000,
            "Lung",
            "LUNG (ICRP)",
            "H(0.101278)C(0.102310)N(0.028650)O(0.757072)Na(0.001840)Mg(0.000730)P(0.000800)S(0.002250)Cl(0.002660)K(0.001940)Ca(0.000090)Fe(0.000370)Zn(0.000010)",
        ],
        [
            0.54965,
            0.260e000,
            "G4Lung",
            "LUNG (G4)",
            "H(0.103000)C(0.105000)N(0.031000)O(0.749000)Na(0.002000)P(0.002000)S(0.003000)Cl(0.003000)K(0.002000)",
        ],
        [
            0.55512,
            1.050e000,
            "",
            "M3 WAX",
            "H(0.114318)C(0.655823)O(0.092183)Mg(0.134792)Ca(0.002883)",
        ],
        [0.49814, 2.958e000, "", "MAGNESIUM CARBONATE", "MgCO3"],
        [0.48153, 3.000e000, "", "MAGNESIUM FLUORIDE", "MgF2"],
        [0.49622, 3.580e000, "", "MAGNESIUM OXIDE", "MgO"],
        [0.49014, 2.530e000, "", "MAGNESIUM TETRABORATE", "MgB4O7"],
        [0.40933, 6.360e000, "", "MERCURIC IODIDE", "HgI2"],
        [0.62334, 6.672e-004, "", "METHANE", "CH4"],
        [0.56176, 7.914e-001, "", "METHANOL", "CH4O"],
        [
            0.56479,
            9.900e-001,
            "",
            "MIX D WAX",
            "H(0.134040)C(0.777960)O(0.035020)Mg(0.038594)Ti(0.014386)",
        ],
        [
            0.53886,
            1.000e000,
            "",
            "MS20 TISSUE SUBSTITUTE",
            "H(0.081192)C(0.583442)N(0.017798)O(0.186381)Mg(0.130287)Cl(0.000900)",
        ],
        [
            0.54938,
            1.050e000,
            "SKELETAL MUSCLE",
            "MUSCLE, SKELETAL (ICRP)",
            "H(0.100637)C(0.107830)N(0.027680)O(0.754773)Na(0.000750)Mg(0.000190)P(0.001800)S(0.002410)Cl(0.000790)K(0.003020)Ca(0.000030)Fe(0.000040)Zn(0.000050)",
        ],
        [
            0.55005,
            1.040e000,
            "STRIATED MUSCLE",
            "MUSCLE, STRIATED (ICRU)",
            "H(0.101997)C(0.123000)N(0.035000)O(0.729003)Na(0.000800)Mg(0.000200)P(0.002000)S(0.005000)K(0.003000)",
        ],
        [
            0.54828,
            1.110e000,
            "",
            "MUSCLE-EQUIVALENT LIQUID, WITH SUCROSE",
            "H(0.098234)C(0.156214)N(0.035451)O(0.710100)",
        ],
        [
            0.55014,
            1.070e000,
            "",
            "MUSCLE-EQUIVALENT LIQUID, WITHOUT SUCROSE",
            "H(0.101969)C(0.120058)N(0.035451)O(0.742522)",
        ],
        [0.53053, 1.145e000, "", "NAPHTHALENE", "C10H8"],
        [0.51986, 1.199e000, "", "NITROBENZENE", "C6H5NO2"],
        [0.49985, 1.831e-003, "", "NITROUS OXIDE", "N2O"],
        [
            0.55063,
            1.080e000,
            "",
            "NYLON, DU PONT ELVAMIDE 8062",
            "H(0.103509)C(0.648415)N(0.099536)O(0.148539)",
        ],
        [0.54790, 1.140e000, "", "NYLON, TYPE 6 AND TYPE 6/6", "C12H22O2N2"],
        [0.55236, 1.140e000, "", "NYLON, TYPE 6/10", "C8H15ON"],
        [0.55649, 1.425e000, "", "NYLON, TYPE 11 (RILSAN)", "C11H21ON"],
        [0.57778, 7.026e-001, "Liquid Octane", "OCTANE, LIQUID", "C8H18"],
        [
            0.55149,
            2.200e000,
            "",
            "Ovary",
            "H(0.105)C(0.093)N(0.024)O(0.768)Na(0.002)P(0.002)S(0.002)Cl(0.002)K(0.002)",
        ],
        [0.57275, 9.300e-001, "PARAFFIN", "PARAFFIN WAX", "C25H52"],
        [0.58212, 6.262e-001, "PENTANE", "N-PENTANE", "C5H12"],
        [
            0.48176,
            3.820e000,
            "Kodak Photo Emulsion",
            "Photographic Emulsion (Kodak Type AA)",
            "H(0.0305)C(0.2107)N(0.0721)O(0.1632)Br(0.2228)Ag(0.3007)",
        ],
        [
            0.45453,
            1.030e000,
            "Nuclear Photo Emulsion",
            "Photographic Emulsion (Standard Nuclear)",
            "H(0.0141)C(0.072261)N(0.01932)O(0.066101)S(0.00189)Br(0.349104)Ag(0.474105)I(0.00312)",
        ],
        [
            0.45453,
            3.815e000,
            "",
            "PHOTOGRAPHIC EMULSION",
            "H(0.0141)C(0.072261)N(0.01932)O(0.066101)S(0.00189)Br(0.349103)Ag(0.474105)I(0.00312)",
        ],
        [
            0.54141,
            1.032e000,
            "VINYLTOLUENE",
            "PLASTIC SCINTILLATOR (VINYLTOLUENE BASED)",
            "C9H10",
        ],
        [0.38879, 1.146e001, "", "PLUTONIUM DIOXIDE", "PuO2"],
        [0.52767, 1.170e000, "PAN", "POLYACRYLONITRILE", "C3H3N"],
        [0.52697, 1.200e000, "MAKROLON", "POLYCARBONATE (MAKROLON, LEXAN)", "C16H14O3"],
        [0.48558, 1.300e000, "", "POLYCHLOROSTYRENE", "C17H18Cl2"],
        [0.57034, 9.400e-001, "", "POLYETHYLENE", "C2H4"],
        [0.52037, 1.400e000, "", "POLYETHYLENE TEREPHTHALATE (MYLAR)", "C10H8O4"],
        [
            0.53937,
            1.190e000,
            "PLEXIGLASS",
            "POLYMETHYL METHACRALATE (LUCITE, PERSPEX, PLEXIGLASS)",
            "C5H8O2",
        ],
        [0.51183, 1.425e000, "", "POLYOXYMETHYLENE", "H2CO"],
        [0.57034, 9.000e-001, "", "POLYPROPYLENE", "C3H6"],
        [0.53768, 1.060e000, "", "POLYSTYRENE", "CH"],
        [0.47992, 2.200e000, "Teflon", "POLYTETRAFLUOROETHYLENE (TEFLON)", "C2F4"],
        [0.48081, 2.100e000, "", "POLYTRIFLUOROCHLOROETHYLENE", "C2F3Cl"],
        [0.53432, 1.190e000, "PVA", "POLYVINYL ACETATE", "C4H6O2"],
        [0.54480, 1.300e000, "PVOH", "POLYVINYL ALCOHOL", "C2H4O"],
        [0.54537, 1.120e000, "PVB", "POLYVINYL BUTYRAL", "C8H13O2"],
        [0.48710, 1.300e000, "PVC", "POLYVINYL CHLORIDE", "C2H3Cl"],
        [0.49513, 1.700e000, "SARAN", "POLYVINYLIDENE CHLORIDE", "CHCl"],
        [0.49973, 1.760e000, "Kynar", "POLYVINYLIDENE FLUORIDE", "C2H2F2"],
        [0.53984, 1.250e000, "PVP", "POLYVINYL PYRROLIDONE", "C6H9NO"],
        [0.43373, 3.130e000, "", "POTASSIUM IODIDE", "KI"],
        [0.48834, 2.320e000, "", "POTASSIUM OXIDE", "K2O"],
        [0.58962, 1.879e-003, "", "PROPANE", "C3H8"],
        [0.58962, 4.300e-001, "LIQUID PROPANE", "PROPANE, LIQUID", "C3H8"],
        [0.56576, 8.035e-001, "1-Propanol", "N-PROPYL ALCOHOL", "C3H8O"],
        [0.53097, 9.819e-001, "Azine", "PYRIDINE", "C5H5N"],
        [0.57034, 9.200e-001, "BUTYL", "RUBBER, BUTYL", "C4H8"],
        [0.55785, 9.200e-001, "Latex", "RUBBER, NATURAL", "C5H8"],
        [0.48605, 1.230e000, "NEOPRENE", "RUBBER, NEOPRENE", "C4H5Cl"],
        [0.49930, 2.320e000, "", "SILICON DIOXIDE", "SiO2"],
        [0.43670, 6.473e000, "", "SILVER BROMIDE", "AgBr"],
        [0.44655, 5.560e000, "", "SILVER CHLORIDE", "AgCl"],
        [
            0.43663,
            6.470e000,
            "",
            "SILVER HALIDES IN PHOTOGRAPHIC EMULSION",
            "Br([422895)Ag(0.573748)I(0.003357)",
        ],
        [0.42594, 6.010e000, "", "SILVER IODIDE", "AgI"],
        [
            0.54932,
            1.100e000,
            "Skin",
            "SKIN (ICRP)",
            "H(0.100588)C(0.228250)N(0.046420)O(0.619002)Na(0.000070)Mg(0.000060)P(0.000330)S(0.001590)Cl(0.002670)K(0.000850)Ca(0.000150)Fe(0.000010)Zn(0.000010)",
        ],
        [0.49062, 2.532e000, "Washing soda", "SODIUM CARBONATE", "Na2CO3"],
        [0.42697, 3.667e000, "", "SODIUM IODIDE", "NaI"],
        [0.48403, 2.270e000, "", "SODIUM MONOXIDE", "Na2O"],
        [0.49415, 2.261e000, "", "SODIUM NITRATE", "NaNO3"],
        [0.53260, 9.707e-001, "trans-1, 2-diphenylethylene", "STILBENE", "C14H12"],
        [0.53170, 1.581e000, "Sugar", "SUCROSE", "C12H22O11"],
        [0.52148, 1.234e000, "p-Terphenyl", "TERPHENYL", "C18H10"],
        [
            0.55108,
            1.040e000,
            "TESTES",
            "TESTES (ICRP)",
            "H(0.104166)C(0.092270)N(0.019940)O(0.773884)Na(0.002260)Mg(0.000110)P(0.001250)S(0.001460)Cl(0.002440)K(0.002080)Ca(0.000100)Fe(0.000020)Zn(0.000020)",
        ],
        [0.48241, 1.625e000, "PCE", "TETRACHLOROETHYLENE", "C2Cl4"],
        [0.40861, 7.004e000, "", "THALLIUM CHLORIDE", "TlCl"],
        [
            0.55121,
            1.000e000,
            "Soft Tissue",
            "TISSUE, SOFT (ICRP)",
            "H(0.104472)C(0.232190)N(0.024880)O(0.630238)Na(0.001130)Mg(0.000130)P(0.001330)S(0.001990)Cl(0.001340)K(0.001990)Ca(0.000230)Fe(0.000050)Zn(0.000030)",
        ],
        [
            0.54975,
            1.000e000,
            "4 component soft tissue",
            "TISSUE, SOFT (ICRP four components)",
            "H(0.101172)C(0.111000)N(0.026000)O(0.761828)",
        ],
        [
            0.54993,
            1.064e-003,
            "",
            "TISSUE-EQUIVALENT GAS (METHANE BASED)",
            "H(0.101869)C(0.456179)N(0.035172)O(0.406780)",
        ],
        [
            0.55027,
            1.826e-003,
            "",
            "TISSUE-EQUIVALENT GAS (PROPANE BASED)",
            "H(0.102672)C(0.568940)N(0.035022)O(0.293366)",
        ],
        [0.46528, 4.260e000, "", "TITANIUM DIOXIDE", "TiO2"],
        [0.54265, 8.669e-001, "methylbenzene", "TOLUENE", "C7H8"],
        [0.48710, 1.460e000, "TCE", "TRICHLOROETHYLENE", "Cl3C2H"],
        [0.52404, 1.070e000, "phosphoric acid", "TRIETHYL PHOSPHATE", "C6H15PO4"],
        [0.40371, 2.400e000, "Tungsten(VI) fluoride", "TUNGSTEN HEXAFLUORIDE", "WF6"],
        [0.39687, 1.128e001, "", "URANIUM DICARBIDE", "UC2"],
        [0.39194, 1.363e001, "Uranium carbide", "URANIUM MONOCARBIDE", "UC"],
        [0.39996, 1.096e001, "Uranium dioxide", "URANIUM OXIDE", "UO2"],
        [0.53284, 1.323e000, "Diaminomethanal", "UREA", "N2H4CO"],
        [0.54632, 1.230e000, "Val", "VALINE", "C5H11NO2"],
        [0.52772, 1.800e000, "Viton", "VITON FLUOROELASTOMER", "C5H2F8"],
        [0.55509, 1.000e000, "Water", "WATER, LIQUID", "H(0.119)O(0.881)"],
        [0.55509, 7.562e-004, "Steam", "WATER VAPOR", "H2O"],
        [0.55509, 0.897e000, "Ice", "WATER, ICE", "H2O"],
        [0.54631, 8.700e-001, "", "XYLENE", "C8H10"],
        [0.38930, 2.055, "", "Yellowcake", "U3O8"],
        [0.55493, 0.93, "BPE", "Borated Polyethylene, 5%", "B(5)H(11.6)C(61.2)O(22.2)"],
        [0.55012, 1.03, "BPE-10", "Borated Polyethylene, 10%", "B(10)H(11)C(58)O(21)"],
        [
            0.46556,
            7.86,
            "Steel",
            "Steel, ASTM A 366",
            "C(8.5E-4)P(1.5E-4)S(1.75E-4)Mn(0.003)Fe(0.996)",
        ],
        [0, 8.53, "Brass", "Cartridge Brass alloy 260", "Cu(0.70)Zn(0.30)"],
        [
            0.5325,
            1.34,
            "CB230",
            "CB230",
            "H(0.0668)C(0.5348)N(0.0212)O(0.2561)Cl(0.0011)Ca(0.1201)",
        ],
        [
            0.5231,
            1.56,
            "CB250",
            "CB250",
            "H(0.0477)C(0.4163)N(0.0152)O(0.3200)Cl(0.0008)Ca(0.2002)",
        ],
    ]
)


# Linear interpolation with extrapolation outside the boundaries.
def extrap(x, xp, yp):
    """np.interp function with linear extrapolation"""
    y = interp1d(xp, yp, kind="linear")(x)
    if isinstance(x, list):
        y[x < xp[0]] = yp[0] + (x[x < xp[0]] - xp[0]) * (yp[0] - yp[1]) / (
            xp[0] - xp[1]
        )
        y[x > xp[-1]] = yp[-1] + (x[x > xp[-1]] - xp[-1]) * (yp[-1] - yp[-2]) / (
            xp[-1] - xp[-2]
        )
    else:
        if x < xp[0]:
            y = yp[0] + (x - xp[0]) * (yp[0] - yp[1]) / (xp[0] - xp[1])
        elif x > xp[-1]:
            y = yp[-1] + (x - xp[-1]) * (yp[-1] - yp[-2]) / (xp[-1] - xp[-2])
    return y


# Let's start!
def PhotonAttenuationEl(Element, Energy, Option):
    CompEdge = []
    u = 1.6605402e-24  # atomic mass unit (1/12 of the mass of C-12)
    barns = 1e24  # barns
    x = (energy).T
    Energy = np.log(Energy)
    if any([Option == 1, Option == 3, Option == 4]):
        y = (mac[Element - 1, :]).T  # mass attenuation coefficient
    elif Option == 2:
        y = (meac[Element - 1, :]).T  # mass energy absorption coefficient
    elif Option > 4:
        print("Error! Only four outputs are possible!")
        return ["Set the function inputs again"]
    if Element > 10:  # check if there are compton edges
        ed = edges[edges[:, 0] == Element, :]  # check if Element has edges
        nEdge = len(ed)  # number of compton edges for Element
        e = ed[:, 1]  # energy of compton edges
        d = 4 * np.spacing(
            e
        )  # computes the positive distance from abs(X) to the next larger in magnitude floating point number of the same precision as X.
        xx = [
            e - d,
            e + d,
        ]  # d is the offset to create 2 different energies for upper and lower end of the edge. xx are the energies.
        w = np.concatenate(
            [np.zeros(len(x)), np.ones(2 * nEdge)]
        )  # array to help keep track of edges
        if any([Option == 1, Option == 3, Option == 4]):
            yy = (ed[:, [2, 3]]).T  # mac values
        elif Option == 2:
            yy = (ed[:, [4, 5]]).T  # meac values
        x = np.append(np.log(x), np.log(xx))
        y = np.append(np.log(y), np.log(yy))
        ix = np.argsort(x)  # merge compton data with other data
        x = x[ix]
        y = y[ix]
        w = w[ix]  # array with '0' for grid points and '1' for compton edge points
        w = (
            np.convolve(w, [1, 1, 1], "same") > 0
        )  # neighbors of edges will be marked with '1' too
        b1 = extrap(
            Energy, x, y
        )  # extrap function is equivalent to the Matlab interp1 function with extrap ON.
        b2 = extrap(Energy, x, w)
        a = pchip_interpolate(x, y, Energy)  # log-log pchip interpolation
        #        a = extrap(Energy,x,y) # log-log linear interpolation
        v = b2
        b = b1
        a = (
            a * (1 - v) + b * v
        )  # smoothly merge curves using linear near edges and cubic otherwise
        CompEdge = np.column_stack(((np.arange(1, nEdge + 1)).T, np.flipud(ed)))
    else:
        a = pchip_interpolate(
            np.log(x), np.log(y), Energy
        )  # log-log pchip interpolation
    #        a = extrap(Energy,np.log(x),np.log(y)) # log-log linear interpolation

    if any([Option == 1, Option == 3, Option == 4]):
        MAttCoef = np.exp(a)
    elif Option == 2:
        EAbsCoef = np.exp(a)
    # Select the desired output
    if Option == 1:  # mass attenuation coefficient
        coef = MAttCoef
    elif Option == 2:  # mass energy absorption coefficient
        coef = EAbsCoef
    elif Option == 3:  # linear attenuation coefficient (only for elements)
        coef = MAttCoef * np.float(PropsEl[Element - 1, 1])  # mac * density
    elif Option == 4:  # cross section in barns/atom
        coef = MAttCoef * (
            barns * u * (Element / np.float(PropsEl[Element - 1, 0]))
        )  # mac * (barns*u*A) A = Z/(Z/A)
    return [coef]


## Run these examples to test the function
# result = PhotonAttenuationEl(30,0.025,1)
# print result
# result = PhotonAttenuationEl(30,0.025,2)
# print result
# result = PhotonAttenuationEl(30,0.025,3)
# print result
# result = PhotonAttenuationEl(30,0.025,4)
# print result
# result = PhotonAttenuationEl(30,0.025,5)
# print result

## Extract the murho data of human tissues in the CT imaging range
# Z = np.arange(4,26,1) # Human tissues range
# Z = Z.astype(float)
# E = np.arange(0.001,0.151,0.001) # CT imaging range: from 1 keV to 150 keV
# murho = [ [ 0 for i in range(len(E)) ] for j in range(len(Z)) ]
# murho[11][149]
# for i in range(0,len(Z)):
#    for j in range(0,len(E)):
#        murho[i][j] = PhotonAttenuationEl(Z[i],E[j],1)
# sio.savemat('murhoPyLogLogPchip.mat', {'murhoPyLogLogPchip': murho})
# print 'Done!'


def ChComposition(Mixture):
    # function to extract the fraction by weight of each element of the mixture
    ChComp = PropsMix[
        PropsMix[:, 2] == Mixture, 4
    ]  # string array containing the elemental composition
    contents = str(ChComp)
    w = re.findall(
        r"[-+]?\d*\.*\d+", contents
    )  # contains the fraction by weight of each element of the mixture
    s = " ".join(re.findall("[a-zA-Z]+", contents))
    El = s.split()
    return w, El


# Example:
# [wSoftTissue, ElSoftTissue] = ChComposition('Soft Tissue')
# print wSoftTissue
# print ElSoftTissue
# [wBone, ElwBone] = ChComposition('CORTICAL BONE')
# print wBone
# print ElwBone
